@@ -1,7 +1,7 @@
 var _ogre_terrain_material_shader_helpers_8h =
 [
     [ "ShaderHelper", "class_ogre_1_1_shader_helper.html", "class_ogre_1_1_shader_helper" ],
-    [ "ShaderHelperCg", "class_ogre_1_1_shader_helper_cg.html", "class_ogre_1_1_shader_helper_cg" ],
-    [ "ShaderHelperGLSL", "class_ogre_1_1_shader_helper_g_l_s_l.html", "class_ogre_1_1_shader_helper_g_l_s_l" ],
+    [ "ShaderHelperCg", "struct_ogre_1_1_shader_helper_cg.html", "struct_ogre_1_1_shader_helper_cg" ],
+    [ "ShaderHelperGLSL", "struct_ogre_1_1_shader_helper_g_l_s_l.html", "struct_ogre_1_1_shader_helper_g_l_s_l" ],
     [ "SM2Profile", "_ogre_terrain_material_shader_helpers_8h.html#a09ac7d69c6fbb892b4445f53b67f747a", null ]
 ];
\ No newline at end of file
