@@ -3,11 +3,13 @@ var _runtime__shader__generation =
     [ "RTSS: Run Time Shader System", "rtss.html", [
       [ "Core features of the system", "rtss.html#core-feats", null ],
       [ "System overview", "rtss.html#rtss_overview", [
-        [ "Customising the RTSS using the API", "rtss.html#rtss_custom_api", null ],
-        [ "Customizing the RTSS using Material Scripts", "rtss.html#rtss_custom_mat", null ]
+        [ "Customizing the RTSS using Material Scripts", "rtss.html#rtss_custom_mat", null ],
+        [ "Customising the RTSS using the API", "rtss.html#rtss_custom_api", null ]
       ] ],
       [ "The RTSS in Depth", "rtss.html#rtss_indepth", [
         [ "Main components", "rtss.html#rtss__components", null ],
+        [ "Creating shader based technique", "rtss.html#rtssTech", null ],
+        [ "Runtime shader generation", "rtss.html#rtssGenerate", null ],
         [ "Creating custom shader extensions", "rtss.html#creating-extensions", null ],
         [ "Tips for debugging shaders", "rtss.html#debugging", null ]
       ] ]
