@@ -9,8 +9,10 @@ var class_ogre_1_1_d3_d9_render_system =
     [ "D3D9RenderSystem", "class_ogre_1_1_d3_d9_render_system.html#a14dbc5ade147a1ff11f7f7e2dff70053", null ],
     [ "~D3D9RenderSystem", "class_ogre_1_1_d3_d9_render_system.html#a5fcc5cf6ff472ea542bb69aeb48b9b01", null ],
     [ "initConfigOptions", "class_ogre_1_1_d3_d9_render_system.html#a7c380aa6256e6ad8cd0278cfd4108515", null ],
+    [ "getFixedFunctionParams", "class_ogre_1_1_d3_d9_render_system.html#aa6c6889714561cedbe356fbc81121471", null ],
+    [ "applyFixedFunctionParams", "class_ogre_1_1_d3_d9_render_system.html#a2b34d795def221a7cc257b9d4b8f4589", null ],
     [ "validateConfigOptions", "class_ogre_1_1_d3_d9_render_system.html#ac674dcd0e1b47a07723fe341f06eef6d", null ],
-    [ "_initialise", "class_ogre_1_1_d3_d9_render_system.html#adbab61a827e8d9fd7c669ae7824d1b4f", null ],
+    [ "_initialise", "class_ogre_1_1_d3_d9_render_system.html#a95b3da61f86ad7af000ca9c971efcdac", null ],
     [ "_createRenderWindow", "class_ogre_1_1_d3_d9_render_system.html#a35c27788a6eedcc44b520fc17077f770", null ],
     [ "_createRenderWindows", "class_ogre_1_1_d3_d9_render_system.html#af2e127de3a611d547520a667fe067f29", null ],
     [ "_createDepthBufferFor", "class_ogre_1_1_d3_d9_render_system.html#abd43de1c83a36316e1c62cda7d2ef31f", null ],
@@ -33,13 +35,10 @@ var class_ogre_1_1_d3_d9_render_system =
     [ "setStencilCheckEnabled", "class_ogre_1_1_d3_d9_render_system.html#a17c198d30e84af9d8456b3f9198df09e", null ],
     [ "setStencilBufferParams", "class_ogre_1_1_d3_d9_render_system.html#a8aad4909174796d54e9b1b56784c4baf", null ],
     [ "setNormaliseNormals", "class_ogre_1_1_d3_d9_render_system.html#aec42c90e719c2c1d2581a906e5120ff7", null ],
-    [ "_useLights", "class_ogre_1_1_d3_d9_render_system.html#a1ed8dc6bed45eea7372025d8c8b7a67a", null ],
-    [ "_setWorldMatrix", "class_ogre_1_1_d3_d9_render_system.html#a736da4898f04646bfc42e7b7d70e0ca7", null ],
-    [ "_setViewMatrix", "class_ogre_1_1_d3_d9_render_system.html#af879a2bcdca5a9c4e944cb2976786a40", null ],
-    [ "_setProjectionMatrix", "class_ogre_1_1_d3_d9_render_system.html#a1fd0bcf3a5888f44e241e964a0532c98", null ],
-    [ "_setSurfaceParams", "class_ogre_1_1_d3_d9_render_system.html#a868c258f27f871c839f24505c1542caa", null ],
+    [ "_useLights", "class_ogre_1_1_d3_d9_render_system.html#a0c5c4da0ef6d3a0c6185930c1a7dbc44", null ],
+    [ "_setSurfaceTracking", "class_ogre_1_1_d3_d9_render_system.html#aa2a9f9542037e5d2afda5d1f744f847d", null ],
     [ "_setPointSpritesEnabled", "class_ogre_1_1_d3_d9_render_system.html#a8087fcbe4777015df90f574b61fdfa67", null ],
-    [ "_setPointParameters", "class_ogre_1_1_d3_d9_render_system.html#a82e47ef0c94c5f7d87199151ca811ff5", null ],
+    [ "_setPointParameters", "class_ogre_1_1_d3_d9_render_system.html#abf7b4f0bb3c5b3343adc4e76a24cfb35", null ],
     [ "_setTexture", "class_ogre_1_1_d3_d9_render_system.html#acc8659aa8149972ca8c1175199110d7d", null ],
     [ "_setSampler", "class_ogre_1_1_d3_d9_render_system.html#a7319688813f35bb96dadbf22075b900b", null ],
     [ "_setVertexTexture", "class_ogre_1_1_d3_d9_render_system.html#a349ff5d559210fe9d1b733add4ddd350", null ],
@@ -48,8 +47,6 @@ var class_ogre_1_1_d3_d9_render_system =
     [ "_setTextureCoordCalculation", "class_ogre_1_1_d3_d9_render_system.html#aa54b0c2ad942d41897c0b8a0a8e44166", null ],
     [ "_setTextureBlendMode", "class_ogre_1_1_d3_d9_render_system.html#ad0ce107404650d8b2ba8fcfba1448b60", null ],
     [ "_setTextureAddressingMode", "class_ogre_1_1_d3_d9_render_system.html#a6d7e92fba6760452e19d7a414ccc8672", null ],
-    [ "_setTextureBorderColour", "class_ogre_1_1_d3_d9_render_system.html#a8f2284cd8c24afda7c14f9570f400698", null ],
-    [ "_setTextureMipmapBias", "class_ogre_1_1_d3_d9_render_system.html#a4f573f2b71583712a1dac603f6917f98", null ],
     [ "_setTextureMatrix", "class_ogre_1_1_d3_d9_render_system.html#aaf51e7092d88a781953f3d0d0048eb52", null ],
     [ "_setSeparateSceneBlending", "class_ogre_1_1_d3_d9_render_system.html#aebfca89852cb822a7dcfe3aa5288999f", null ],
     [ "_setAlphaRejectSettings", "class_ogre_1_1_d3_d9_render_system.html#ab63c18908e608834b601298afd2da197", null ],
@@ -65,17 +62,10 @@ var class_ogre_1_1_d3_d9_render_system =
     [ "_setDepthBufferWriteEnabled", "class_ogre_1_1_d3_d9_render_system.html#aa44f574d9b7aeec5be3b652dbae21d79", null ],
     [ "_setDepthBufferFunction", "class_ogre_1_1_d3_d9_render_system.html#a87d8a1dde9baf36fdc68f5a36c983383", null ],
     [ "_setDepthBias", "class_ogre_1_1_d3_d9_render_system.html#a7830b7940977d3ad920d0984c06113be", null ],
-    [ "_setFog", "class_ogre_1_1_d3_d9_render_system.html#a1e32bbf6fff565726a5e10ed5431691f", null ],
+    [ "_setFog", "class_ogre_1_1_d3_d9_render_system.html#a1702436e6653d2102443599326bca7e3", null ],
     [ "_convertProjectionMatrix", "class_ogre_1_1_d3_d9_render_system.html#acdd1a102566c67c2ce3426f06179cdae", null ],
-    [ "_makeProjectionMatrix", "class_ogre_1_1_d3_d9_render_system.html#aee210728f2dbf51a5c3d44aef97b97f8", null ],
-    [ "_makeProjectionMatrix", "class_ogre_1_1_d3_d9_render_system.html#ae1446d8242022a9861ba1df3e34fdbff", null ],
-    [ "_makeOrthoMatrix", "class_ogre_1_1_d3_d9_render_system.html#ae3fd00aee60751f2bb937a0d1f619520", null ],
-    [ "_applyObliqueDepthProjection", "class_ogre_1_1_d3_d9_render_system.html#a1d48fd6f7eb6b12f9297f41d1a12a48c", null ],
     [ "_setPolygonMode", "class_ogre_1_1_d3_d9_render_system.html#a0d5d7d3f33d4a8a6ee1ce2e416d7320a", null ],
     [ "_setTextureUnitFiltering", "class_ogre_1_1_d3_d9_render_system.html#a2844693c27bb55b93af8098fd658fb38", null ],
-    [ "_setTextureUnitCompareFunction", "class_ogre_1_1_d3_d9_render_system.html#a9e34d9fe95dbca71ec671b6372c0c5a8", null ],
-    [ "_setTextureUnitCompareEnabled", "class_ogre_1_1_d3_d9_render_system.html#a497f1ce8b52f61c024848f513f2a7456", null ],
-    [ "_setTextureLayerAnisotropy", "class_ogre_1_1_d3_d9_render_system.html#a665c77f780de89e0af79c3d774d9c2f6", null ],
     [ "setVertexDeclaration", "class_ogre_1_1_d3_d9_render_system.html#a014e9b7fe6828806a7234f3115d029b8", null ],
     [ "setVertexDeclaration", "class_ogre_1_1_d3_d9_render_system.html#ad11519e92283a6cb4186dc618e037eec", null ],
     [ "setVertexBufferBinding", "class_ogre_1_1_d3_d9_render_system.html#a1819f0182b2c7ee533cf1032786d6d08", null ],
@@ -112,7 +102,6 @@ var class_ogre_1_1_d3_d9_render_system =
     [ "_checkTextureFilteringSupported", "class_ogre_1_1_d3_d9_render_system.html#a09b739bb7b2d3c3aff1fecece56e9baa", null ],
     [ "determineFSAASettings", "class_ogre_1_1_d3_d9_render_system.html#abeb5bc1a5691a572c5dc2f4775cf76c5", null ],
     [ "getDisplayMonitorCount", "class_ogre_1_1_d3_d9_render_system.html#a44795018c7a6f424849c23cb3947a240", null ],
-    [ "hasAnisotropicMipMapFilter", "class_ogre_1_1_d3_d9_render_system.html#a659cb3dfd72379833b0b4898d99f9a48", null ],
     [ "beginProfileEvent", "class_ogre_1_1_d3_d9_render_system.html#ac5910601e68f4c7c08370e2b74066d9b", null ],
     [ "endProfileEvent", "class_ogre_1_1_d3_d9_render_system.html#ae849367c0ad6d28ecc8db5d95b3e56d7", null ],
     [ "markProfileEvent", "class_ogre_1_1_d3_d9_render_system.html#a489d99fe770e4c105434ed13911ce350", null ],
@@ -121,13 +110,15 @@ var class_ogre_1_1_d3_d9_render_system =
     [ "setDrawBuffer", "class_ogre_1_1_d3_d9_render_system.html#a869123f35563093de0f4fe68321b9b4b", null ],
     [ "createStereoDriver", "class_ogre_1_1_d3_d9_render_system.html#a296a4b8cb73c61dced451b6e23e95919", null ],
     [ "_cleanupDepthBuffers", "class_ogre_1_1_d3_d9_render_system.html#a568dd8e5d75fc7eef649dda6d14d447d", null ],
-    [ "getConfigOptions", "class_ogre_1_1_d3_d9_render_system.html#a4415ece805ed62ee16c8343c96766231", null ],
+    [ "getConfigOptions", "class_ogre_1_1_d3_d9_render_system.html#aca550d0c75935c7f11b1b8ef6ae0a69b", null ],
+    [ "getRenderWindowDescription", "class_ogre_1_1_d3_d9_render_system.html#aa6e8e2994c6b93d4a075e93223d2def1", null ],
     [ "destroyHardwareOcclusionQuery", "class_ogre_1_1_d3_d9_render_system.html#ac4c60bf4c5d4347fd2b9346a90545e2b", null ],
     [ "getMutableCapabilities", "class_ogre_1_1_d3_d9_render_system.html#ab0aa0cedf1898f8cc70e290703b428c7", null ],
     [ "useCustomRenderSystemCapabilities", "class_ogre_1_1_d3_d9_render_system.html#afc69e09f59064b79f3bfd4402617d07a", null ],
-    [ "setAmbientLight", "class_ogre_1_1_d3_d9_render_system.html#af2364f8648585cd4fb7bb16761b35b2d", null ],
-    [ "setWBufferEnabled", "class_ogre_1_1_d3_d9_render_system.html#a01c339f6e89d82b526fb7725424a4263", null ],
-    [ "getWBufferEnabled", "class_ogre_1_1_d3_d9_render_system.html#a644d2fd38872cf323c50f63148d27d02", null ],
+    [ "_setProjectionMatrix", "class_ogre_1_1_d3_d9_render_system.html#a12183f0e2538e4c65e0ec775eeafde68", null ],
+    [ "_setViewMatrix", "class_ogre_1_1_d3_d9_render_system.html#acf464521f1b593f9c1bc89467e195691", null ],
+    [ "_setWorldMatrix", "class_ogre_1_1_d3_d9_render_system.html#a3b31342c80388e10155c5e6e4d91fc2d", null ],
+    [ "_setSceneBlending", "class_ogre_1_1_d3_d9_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
     [ "destroyRenderWindow", "class_ogre_1_1_d3_d9_render_system.html#a65ddf1db4aa3f463e0479c240ffc3dc5", null ],
     [ "destroyRenderTexture", "class_ogre_1_1_d3_d9_render_system.html#a354ceaa02574d1cf68dcb5999b34df50", null ],
     [ "attachRenderTarget", "class_ogre_1_1_d3_d9_render_system.html#ac7ce258ff899b1694a18e1d51e1a3ba0", null ],
@@ -140,14 +131,11 @@ var class_ogre_1_1_d3_d9_render_system =
     [ "getGlobalNumberOfInstances", "class_ogre_1_1_d3_d9_render_system.html#af41e08cc1bc54e34d0314f4c9ffa58f6", null ],
     [ "setGlobalNumberOfInstances", "class_ogre_1_1_d3_d9_render_system.html#a3e31b243ba86e2114925a99b2c2825e1", null ],
     [ "setDepthBufferFor", "class_ogre_1_1_d3_d9_render_system.html#a63c23bbd80d6862a54d471754d9bccf0", null ],
-    [ "areFixedFunctionLightsInViewSpace", "class_ogre_1_1_d3_d9_render_system.html#a008131b65568c0bf072ae3a96203d6c0", null ],
     [ "_setTextureUnitSettings", "class_ogre_1_1_d3_d9_render_system.html#ad504623eff0678f9f79b075f32673414", null ],
-    [ "_setBindingType", "class_ogre_1_1_d3_d9_render_system.html#ae197c344b0b2dce1739e3c566c280f8c", null ],
     [ "_disableTextureUnitsFrom", "class_ogre_1_1_d3_d9_render_system.html#a68e0ecb23c3eba58b5aeb06d646ce4cd", null ],
     [ "_setLineWidth", "class_ogre_1_1_d3_d9_render_system.html#a40f99785cb4f728763712169cec19f29", null ],
     [ "_setTextureUnitFiltering", "class_ogre_1_1_d3_d9_render_system.html#adbc64c669661f87ee2f8db8dd18a0fe5", null ],
     [ "setColourBlendState", "class_ogre_1_1_d3_d9_render_system.html#a46abac034b2217b91ae66b334e1ca42f", null ],
-    [ "_setSceneBlending", "class_ogre_1_1_d3_d9_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
     [ "_setTextureProjectionRelativeTo", "class_ogre_1_1_d3_d9_render_system.html#a91e7ee7dd1f244ffa9a0681efb6fae6c", null ],
     [ "_cleanupDepthBuffers", "class_ogre_1_1_d3_d9_render_system.html#a568dd8e5d75fc7eef649dda6d14d447d", null ],
     [ "_getViewport", "class_ogre_1_1_d3_d9_render_system.html#aa0cf9dc2df0748f3076c5f8f1f8064db", null ],
@@ -164,8 +152,6 @@ var class_ogre_1_1_d3_d9_render_system =
     [ "isGpuProgramBound", "class_ogre_1_1_d3_d9_render_system.html#a6077b61e7511ae56887c67498f5282a1", null ],
     [ "getNativeShadingLanguageVersion", "class_ogre_1_1_d3_d9_render_system.html#a9d89d5e2e2f0c2c30e72032eae4482ec", null ],
     [ "setClipPlanes", "class_ogre_1_1_d3_d9_render_system.html#a23cc0a7d87b77ec3d0a34e92335bec1a", null ],
-    [ "addClipPlane", "class_ogre_1_1_d3_d9_render_system.html#abe36b06513ccdd9daca4c6443144bcfc", null ],
-    [ "resetClipPlanes", "class_ogre_1_1_d3_d9_render_system.html#a844d233fa4ba66a95e56c086f76287f9", null ],
     [ "_initRenderTargets", "class_ogre_1_1_d3_d9_render_system.html#aacdaca375b0736ea8b9fe660f17405ab", null ],
     [ "_notifyCameraRemoved", "class_ogre_1_1_d3_d9_render_system.html#aad4ebe6f669319f83fc44cf9d5a8f9cc", null ],
     [ "_updateAllRenderTargets", "class_ogre_1_1_d3_d9_render_system.html#a8ef6bbe5a63769cfe73319ac418624a8", null ],
