@@ -5,21 +5,18 @@ var class_ogre_1_1_g_l3_plus_render_system =
     [ "GL3PlusRenderSystem", "class_ogre_1_1_g_l3_plus_render_system.html#aa440f3ea9d58a00a3485f379bc08dfe8", null ],
     [ "~GL3PlusRenderSystem", "class_ogre_1_1_g_l3_plus_render_system.html#a719eb89bc2a3687b3a6894bb4ae26b72", null ],
     [ "getName", "class_ogre_1_1_g_l3_plus_render_system.html#afe3aad3f49ac3459fbaf34dd9a4dc2f7", null ],
-    [ "_initialise", "class_ogre_1_1_g_l3_plus_render_system.html#a1dcb84b7f2d21a99ed16dc6d0bb89d55", null ],
+    [ "_initialise", "class_ogre_1_1_g_l3_plus_render_system.html#a87045d100de454fa45bb14d190366164", null ],
     [ "createRenderSystemCapabilities", "class_ogre_1_1_g_l3_plus_render_system.html#a42809b6d8c221fb2b904e031773cc3b7", null ],
     [ "initialiseFromRenderSystemCapabilities", "class_ogre_1_1_g_l3_plus_render_system.html#a57b81c037738fac77f4317e3dac89afa", null ],
     [ "shutdown", "class_ogre_1_1_g_l3_plus_render_system.html#abf7098c116afdd2eeb9104f38d97e51d", null ],
     [ "_createRenderWindow", "class_ogre_1_1_g_l3_plus_render_system.html#a58bd63e25d907657dbf88bcc9e50763d", null ],
     [ "_createRenderWindows", "class_ogre_1_1_g_l3_plus_render_system.html#aff4699cef4312475502c48747099d531", null ],
     [ "_createDepthBufferFor", "class_ogre_1_1_g_l3_plus_render_system.html#a64596af7355b8c95a252255d58034f0a", null ],
-    [ "_getDepthStencilFormatFor", "class_ogre_1_1_g_l3_plus_render_system.html#a98c23effa8e7a111375bc0a27e9b2f89", null ],
     [ "createMultiRenderTarget", "class_ogre_1_1_g_l3_plus_render_system.html#afd00f0bccdd8832500e5ed52eee5be77", null ],
     [ "destroyRenderWindow", "class_ogre_1_1_g_l3_plus_render_system.html#a092487e8ab8ffe42bce344fb7a4c4541", null ],
     [ "_setTexture", "class_ogre_1_1_g_l3_plus_render_system.html#a2ccdbd25f783a9c64aadc234aac93d87", null ],
     [ "_setSampler", "class_ogre_1_1_g_l3_plus_render_system.html#ab36aea7b8542a98a870b7de244117849", null ],
     [ "_setTextureAddressingMode", "class_ogre_1_1_g_l3_plus_render_system.html#abd0559da33ca6ff32315dccd7966f696", null ],
-    [ "_setTextureBorderColour", "class_ogre_1_1_g_l3_plus_render_system.html#a0b952b0373f8cdaaf7acac5e15e60570", null ],
-    [ "_setTextureMipmapBias", "class_ogre_1_1_g_l3_plus_render_system.html#a3fa41dc5a8234641fa6246e71b4875d5", null ],
     [ "_setLineWidth", "class_ogre_1_1_g_l3_plus_render_system.html#ad924907f88f5ea789bc82d97149ebaf4", null ],
     [ "_setViewport", "class_ogre_1_1_g_l3_plus_render_system.html#ab79848eaef011562689f47e7e8b2c64e", null ],
     [ "_beginFrame", "class_ogre_1_1_g_l3_plus_render_system.html#a18cda8becf7351ef83cceae55ad3eb7b", null ],
@@ -35,9 +32,6 @@ var class_ogre_1_1_g_l3_plus_render_system =
     [ "setStencilCheckEnabled", "class_ogre_1_1_g_l3_plus_render_system.html#aecaf1d0a4293b0090f398c8aadab1114", null ],
     [ "setStencilBufferParams", "class_ogre_1_1_g_l3_plus_render_system.html#a4a4e9c2a588d49197612685060d1c3a8", null ],
     [ "_setTextureUnitFiltering", "class_ogre_1_1_g_l3_plus_render_system.html#a746bcda2b88ef48ef7c4114b65abae15", null ],
-    [ "_setTextureUnitCompareFunction", "class_ogre_1_1_g_l3_plus_render_system.html#ac068003fa440b1ff68f059d4aef58cb2", null ],
-    [ "_setTextureUnitCompareEnabled", "class_ogre_1_1_g_l3_plus_render_system.html#a36297395bb547a7980809cfb4535fec9", null ],
-    [ "_setTextureLayerAnisotropy", "class_ogre_1_1_g_l3_plus_render_system.html#ab29f91b7d53b86b2bc74273e5077d40a", null ],
     [ "_dispatchCompute", "class_ogre_1_1_g_l3_plus_render_system.html#a30bac3e9059a8681fc63ee66556a5a0b", null ],
     [ "_render", "class_ogre_1_1_g_l3_plus_render_system.html#ad6b5f3d0029b6a7add41aa0833b4aea0", null ],
     [ "setScissorTest", "class_ogre_1_1_g_l3_plus_render_system.html#aa82fcefbb2e338be7037734d1d3dbc44", null ],
@@ -67,7 +61,6 @@ var class_ogre_1_1_g_l3_plus_render_system =
     [ "_setSeparateSceneBlending", "class_ogre_1_1_g_l3_plus_render_system.html#a302fe1c87b6d7f4de2bbdaad6648a006", null ],
     [ "_setAlphaRejectSettings", "class_ogre_1_1_g_l3_plus_render_system.html#a4f4bff652fc2b85d7803dc54f0fb59e3", null ],
     [ "getDisplayMonitorCount", "class_ogre_1_1_g_l3_plus_render_system.html#a1526bb1c290815e1c6541f53782c7ff6", null ],
-    [ "hasAnisotropicMipMapFilter", "class_ogre_1_1_g_l3_plus_render_system.html#ad65affaed7e771573042e2cbb206c047", null ],
     [ "beginProfileEvent", "class_ogre_1_1_g_l3_plus_render_system.html#aead888edc98d11905cbf8f40815dfebb", null ],
     [ "endProfileEvent", "class_ogre_1_1_g_l3_plus_render_system.html#a86f08fb580b6e1d8c064e96da2935b17", null ],
     [ "markProfileEvent", "class_ogre_1_1_g_l3_plus_render_system.html#a3512c6f462bef8e8dde5f8e997f1e903", null ],
@@ -85,22 +78,23 @@ var class_ogre_1_1_g_l3_plus_render_system =
     [ "getColourVertexElementType", "class_ogre_1_1_g_l3_plus_render_system.html#a98654d465668da5979ba19970f340c6c", null ],
     [ "reinitialise", "class_ogre_1_1_g_l3_plus_render_system.html#ae7f49f141ecbec19ae167a1f41410831", null ],
     [ "_convertProjectionMatrix", "class_ogre_1_1_g_l3_plus_render_system.html#a659737b922eab484406ba4185bbdba11", null ],
-    [ "_makeProjectionMatrix", "class_ogre_1_1_g_l3_plus_render_system.html#a83b79138c5a836ff9e9b64b9034411ba", null ],
-    [ "_makeProjectionMatrix", "class_ogre_1_1_g_l3_plus_render_system.html#aa0bed8165409135364a650970823076e", null ],
-    [ "_makeOrthoMatrix", "class_ogre_1_1_g_l3_plus_render_system.html#a29f04ca5283c108f347abea792acda4c", null ],
-    [ "_applyObliqueDepthProjection", "class_ogre_1_1_g_l3_plus_render_system.html#a5396bb98e10b98f63d919125393e6cf8", null ],
+    [ "_getDepthStencilFormatFor", "class_ogre_1_1_g_l3_plus_render_system.html#adea4ea5c6eeab804929dde6e1f8e6f9c", null ],
     [ "_completeDeferredVaoFboDestruction", "class_ogre_1_1_g_l3_plus_render_system.html#a4e1583bcb013072db22095835eda8d64", null ],
-    [ "getConfigOptions", "class_ogre_1_1_g_l3_plus_render_system.html#a4415ece805ed62ee16c8343c96766231", null ],
+    [ "getConfigOptions", "class_ogre_1_1_g_l3_plus_render_system.html#aca550d0c75935c7f11b1b8ef6ae0a69b", null ],
+    [ "getRenderWindowDescription", "class_ogre_1_1_g_l3_plus_render_system.html#aa6e8e2994c6b93d4a075e93223d2def1", null ],
     [ "destroyHardwareOcclusionQuery", "class_ogre_1_1_g_l3_plus_render_system.html#ac4c60bf4c5d4347fd2b9346a90545e2b", null ],
     [ "isStaticBufferLockable", "class_ogre_1_1_g_l3_plus_render_system.html#a319564dc746b19bb9a1490a473227b20", null ],
     [ "getMutableCapabilities", "class_ogre_1_1_g_l3_plus_render_system.html#ab0aa0cedf1898f8cc70e290703b428c7", null ],
     [ "useCustomRenderSystemCapabilities", "class_ogre_1_1_g_l3_plus_render_system.html#afc69e09f59064b79f3bfd4402617d07a", null ],
-    [ "setAmbientLight", "class_ogre_1_1_g_l3_plus_render_system.html#af0237b668f88b5f31d17f830dfe78cac", null ],
-    [ "setAmbientLight", "class_ogre_1_1_g_l3_plus_render_system.html#af2364f8648585cd4fb7bb16761b35b2d", null ],
+    [ "getFixedFunctionParams", "class_ogre_1_1_g_l3_plus_render_system.html#acdad3c2838c8607b0f8416fb92b95df4", null ],
+    [ "_setProjectionMatrix", "class_ogre_1_1_g_l3_plus_render_system.html#a12183f0e2538e4c65e0ec775eeafde68", null ],
+    [ "_setViewMatrix", "class_ogre_1_1_g_l3_plus_render_system.html#acf464521f1b593f9c1bc89467e195691", null ],
+    [ "_setWorldMatrix", "class_ogre_1_1_g_l3_plus_render_system.html#a3b31342c80388e10155c5e6e4d91fc2d", null ],
+    [ "_setFog", "class_ogre_1_1_g_l3_plus_render_system.html#a07c349edc8c94711ff3c6869eefbcbf5", null ],
+    [ "_setSceneBlending", "class_ogre_1_1_g_l3_plus_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
+    [ "applyFixedFunctionParams", "class_ogre_1_1_g_l3_plus_render_system.html#a5821d9920dedc3760ce5733aa8e34a8a", null ],
     [ "setShadingType", "class_ogre_1_1_g_l3_plus_render_system.html#a9eb67835b105be674c152a95ca83b631", null ],
     [ "setLightingEnabled", "class_ogre_1_1_g_l3_plus_render_system.html#ad461073e0f430324258f136da3f281c5", null ],
-    [ "setWBufferEnabled", "class_ogre_1_1_g_l3_plus_render_system.html#a01c339f6e89d82b526fb7725424a4263", null ],
-    [ "getWBufferEnabled", "class_ogre_1_1_g_l3_plus_render_system.html#a644d2fd38872cf323c50f63148d27d02", null ],
     [ "destroyRenderTexture", "class_ogre_1_1_g_l3_plus_render_system.html#a354ceaa02574d1cf68dcb5999b34df50", null ],
     [ "destroyRenderTarget", "class_ogre_1_1_g_l3_plus_render_system.html#a43a03671d1c7efd7e95100d77080eb8c", null ],
     [ "attachRenderTarget", "class_ogre_1_1_g_l3_plus_render_system.html#ac7ce258ff899b1694a18e1d51e1a3ba0", null ],
@@ -114,18 +108,12 @@ var class_ogre_1_1_g_l3_plus_render_system =
     [ "getGlobalNumberOfInstances", "class_ogre_1_1_g_l3_plus_render_system.html#af41e08cc1bc54e34d0314f4c9ffa58f6", null ],
     [ "setGlobalNumberOfInstances", "class_ogre_1_1_g_l3_plus_render_system.html#a3e31b243ba86e2114925a99b2c2825e1", null ],
     [ "setDepthBufferFor", "class_ogre_1_1_g_l3_plus_render_system.html#a63c23bbd80d6862a54d471754d9bccf0", null ],
-    [ "_useLights", "class_ogre_1_1_g_l3_plus_render_system.html#afe87000fc9e5619f4f17fd77b37a212f", null ],
-    [ "areFixedFunctionLightsInViewSpace", "class_ogre_1_1_g_l3_plus_render_system.html#a008131b65568c0bf072ae3a96203d6c0", null ],
-    [ "_setWorldMatrix", "class_ogre_1_1_g_l3_plus_render_system.html#ae8d7a587d3a8d15102f73b65bbceb56e", null ],
-    [ "_setViewMatrix", "class_ogre_1_1_g_l3_plus_render_system.html#a1a7926fe7b59598fdb7b7e743efdae6c", null ],
-    [ "_setProjectionMatrix", "class_ogre_1_1_g_l3_plus_render_system.html#ab72ff6224be9aebbc957b49919edf271", null ],
+    [ "_useLights", "class_ogre_1_1_g_l3_plus_render_system.html#a17c2108d7e7efac07fe235a6ab3f70b0", null ],
     [ "_setTextureUnitSettings", "class_ogre_1_1_g_l3_plus_render_system.html#ad504623eff0678f9f79b075f32673414", null ],
-    [ "_setBindingType", "class_ogre_1_1_g_l3_plus_render_system.html#ae197c344b0b2dce1739e3c566c280f8c", null ],
     [ "_disableTextureUnit", "class_ogre_1_1_g_l3_plus_render_system.html#a058d6805142fce7ec095a018447cbe33", null ],
     [ "_disableTextureUnitsFrom", "class_ogre_1_1_g_l3_plus_render_system.html#a68e0ecb23c3eba58b5aeb06d646ce4cd", null ],
-    [ "_setSurfaceParams", "class_ogre_1_1_g_l3_plus_render_system.html#aac94d165075a7431fcac95c95a430b4e", null ],
     [ "_setPointSpritesEnabled", "class_ogre_1_1_g_l3_plus_render_system.html#a0bf5a91059d6da3b9dc4cebaf3284d23", null ],
-    [ "_setPointParameters", "class_ogre_1_1_g_l3_plus_render_system.html#ae6da7b41093d1a7b7acc7af4c686b1cd", null ],
+    [ "_setPointParameters", "class_ogre_1_1_g_l3_plus_render_system.html#a018624e558a652005ee4bbdbd3bb6330", null ],
     [ "_setVertexTexture", "class_ogre_1_1_g_l3_plus_render_system.html#af40bfb084b051d8433b0893921613ba7", null ],
     [ "_setTextureCoordSet", "class_ogre_1_1_g_l3_plus_render_system.html#addfea71a41353277fa57585cda4d6627", null ],
     [ "_setTextureCoordCalculation", "class_ogre_1_1_g_l3_plus_render_system.html#a10fdc4a81a69fd6d9fb0bb62f3a3cece", null ],
@@ -133,14 +121,12 @@ var class_ogre_1_1_g_l3_plus_render_system =
     [ "_setTextureUnitFiltering", "class_ogre_1_1_g_l3_plus_render_system.html#adbc64c669661f87ee2f8db8dd18a0fe5", null ],
     [ "_setTextureMatrix", "class_ogre_1_1_g_l3_plus_render_system.html#a6512839a2f001e463c0d46e07993192c", null ],
     [ "setColourBlendState", "class_ogre_1_1_g_l3_plus_render_system.html#a46abac034b2217b91ae66b334e1ca42f", null ],
-    [ "_setSceneBlending", "class_ogre_1_1_g_l3_plus_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
     [ "_setTextureProjectionRelativeTo", "class_ogre_1_1_g_l3_plus_render_system.html#a91e7ee7dd1f244ffa9a0681efb6fae6c", null ],
     [ "_cleanupDepthBuffers", "class_ogre_1_1_g_l3_plus_render_system.html#a568dd8e5d75fc7eef649dda6d14d447d", null ],
     [ "_pauseFrame", "class_ogre_1_1_g_l3_plus_render_system.html#a9893de6903d77fe231da1135f5ee00db", null ],
     [ "_resumeFrame", "class_ogre_1_1_g_l3_plus_render_system.html#abe9b7d178eb5d0ea90c7b9a35f612f91", null ],
     [ "_getViewport", "class_ogre_1_1_g_l3_plus_render_system.html#aa0cf9dc2df0748f3076c5f8f1f8064db", null ],
     [ "_getCullingMode", "class_ogre_1_1_g_l3_plus_render_system.html#acc15a085c3fc5970d5c028c79eadead3", null ],
-    [ "_setFog", "class_ogre_1_1_g_l3_plus_render_system.html#abdf6101c5d6cc993b8cd160b174ddca1", null ],
     [ "_beginGeometryCount", "class_ogre_1_1_g_l3_plus_render_system.html#a385581061b5d8d9af914d0439392aa62", null ],
     [ "_getFaceCount", "class_ogre_1_1_g_l3_plus_render_system.html#abef8777c6302b9747a0caa97482a87f4", null ],
     [ "_getBatchCount", "class_ogre_1_1_g_l3_plus_render_system.html#ac419ed21d6b2427b142a81fbfcde2be3", null ],
@@ -153,8 +139,6 @@ var class_ogre_1_1_g_l3_plus_render_system =
     [ "isGpuProgramBound", "class_ogre_1_1_g_l3_plus_render_system.html#a6077b61e7511ae56887c67498f5282a1", null ],
     [ "getNativeShadingLanguageVersion", "class_ogre_1_1_g_l3_plus_render_system.html#a9d89d5e2e2f0c2c30e72032eae4482ec", null ],
     [ "setClipPlanes", "class_ogre_1_1_g_l3_plus_render_system.html#a23cc0a7d87b77ec3d0a34e92335bec1a", null ],
-    [ "addClipPlane", "class_ogre_1_1_g_l3_plus_render_system.html#abe36b06513ccdd9daca4c6443144bcfc", null ],
-    [ "resetClipPlanes", "class_ogre_1_1_g_l3_plus_render_system.html#a844d233fa4ba66a95e56c086f76287f9", null ],
     [ "_initRenderTargets", "class_ogre_1_1_g_l3_plus_render_system.html#aacdaca375b0736ea8b9fe660f17405ab", null ],
     [ "_notifyCameraRemoved", "class_ogre_1_1_g_l3_plus_render_system.html#aad4ebe6f669319f83fc44cf9d5a8f9cc", null ],
     [ "_updateAllRenderTargets", "class_ogre_1_1_g_l3_plus_render_system.html#a8ef6bbe5a63769cfe73319ac418624a8", null ],
