@@ -5,20 +5,17 @@ var class_ogre_1_1_g_l_e_s2_render_system =
     [ "GLES2RenderSystem", "group___g_l_e_s2.html#ga13b7c3c278327f19329404c7619859e6", null ],
     [ "~GLES2RenderSystem", "group___g_l_e_s2.html#gae5dc13a455bc024db98ae1ed309f0e13", null ],
     [ "getName", "group___g_l_e_s2.html#ga911c9c38118fee9fbf1220dbb9a2d4e1", null ],
-    [ "_initialise", "group___g_l_e_s2.html#gabb6817d185f2ebe29984e15de2b7e24a", null ],
+    [ "_initialise", "group___g_l_e_s2.html#ga6f06220516633a145f37a6779027929b", null ],
     [ "createRenderSystemCapabilities", "group___g_l_e_s2.html#ga5306bcbd9bc9cea046118189bcf01b55", null ],
     [ "initialiseFromRenderSystemCapabilities", "group___g_l_e_s2.html#ga9dc71e053c89ccced5784362a3ca44ce", null ],
     [ "shutdown", "group___g_l_e_s2.html#ga9d4668eb748e9093af39c95a1684aa2a", null ],
     [ "_createRenderWindow", "group___g_l_e_s2.html#gab53a6487fef2fd00eee17b860c3f2c2f", null ],
     [ "_createDepthBufferFor", "group___g_l_e_s2.html#ga81eaa5b50d6e63709e3b49a70fa16c08", null ],
-    [ "_getDepthStencilFormatFor", "group___g_l_e_s2.html#ga234e49f5469846344bd7ed4973d0b5f6", null ],
     [ "createMultiRenderTarget", "group___g_l_e_s2.html#ga485ebebda97e764bef335abadc04fb14", null ],
     [ "destroyRenderWindow", "group___g_l_e_s2.html#ga31201c00d107451d7f7ff264f3559a2e", null ],
     [ "_setTexture", "group___g_l_e_s2.html#ga066f9dbe0f422cd350d22c563896e6c7", null ],
     [ "_setSampler", "group___g_l_e_s2.html#ga2a53c1abeeaaf7d7732571266b85d3bf", null ],
     [ "_setTextureAddressingMode", "group___g_l_e_s2.html#ga9986214ed4d4bee60f62deef52659692", null ],
-    [ "_setTextureBorderColour", "group___g_l_e_s2.html#ga8f7d75c7234f300c1d6fdb09d019a3bc", null ],
-    [ "_setTextureMipmapBias", "group___g_l_e_s2.html#ga9120c932b874e1fb8645035bbf22b65e", null ],
     [ "_setLineWidth", "group___g_l_e_s2.html#ga55c3aaee65dee3249d3294a49d21e9d4", null ],
     [ "_setViewport", "group___g_l_e_s2.html#ga9e85e1cc3f1c220959768593e0017f40", null ],
     [ "_beginFrame", "group___g_l_e_s2.html#ga0f0d14adfe963f86bbcc624e9e948aa8", null ],
@@ -33,12 +30,8 @@ var class_ogre_1_1_g_l_e_s2_render_system =
     [ "_setPolygonMode", "group___g_l_e_s2.html#gabcac20ccef713d00075e7938e8afd343", null ],
     [ "setStencilCheckEnabled", "group___g_l_e_s2.html#gaecdd103b0c6243287f6dfb1be8bc4e08", null ],
     [ "setStencilBufferParams", "group___g_l_e_s2.html#ga50035b687daf76d52a11bf6b851bb902", null ],
-    [ "_setTextureUnitCompareFunction", "group___g_l_e_s2.html#ga2107cd1bce2156d694ebcb65c6602534", null ],
-    [ "_setTextureUnitCompareEnabled", "group___g_l_e_s2.html#gaeddf29413cf26ba1a7a16acdefef2dcb", null ],
     [ "_setTextureUnitFiltering", "group___g_l_e_s2.html#gaf28d1fa286f453317a1e889e6fc7de04", null ],
     [ "_setTextureUnitFiltering", "group___g_l_e_s2.html#ga521693302023af1900f5bebacfb01a42", null ],
-    [ "_setTextureLayerAnisotropy", "group___g_l_e_s2.html#gaab7cdbfb7eaa8ded535cf1adfd5983fb", null ],
-    [ "hasAnisotropicMipMapFilter", "group___g_l_e_s2.html#ga4c41d253fd2a38b8d2289fd0bd67fb74", null ],
     [ "_render", "group___g_l_e_s2.html#ga36e40f27ab6ce44b53e4ef94b08a46aa", null ],
     [ "setScissorTest", "group___g_l_e_s2.html#gaa8d7e5faf05d5d865573294c48db9a73", null ],
     [ "clearFrameBuffer", "group___g_l_e_s2.html#gaab180fa4a2aba714e22ff30d22511d30", null ],
@@ -85,22 +78,23 @@ var class_ogre_1_1_g_l_e_s2_render_system =
     [ "getColourVertexElementType", "class_ogre_1_1_g_l_e_s2_render_system.html#a98654d465668da5979ba19970f340c6c", null ],
     [ "reinitialise", "class_ogre_1_1_g_l_e_s2_render_system.html#ae7f49f141ecbec19ae167a1f41410831", null ],
     [ "_convertProjectionMatrix", "class_ogre_1_1_g_l_e_s2_render_system.html#a659737b922eab484406ba4185bbdba11", null ],
-    [ "_makeProjectionMatrix", "class_ogre_1_1_g_l_e_s2_render_system.html#a83b79138c5a836ff9e9b64b9034411ba", null ],
-    [ "_makeProjectionMatrix", "class_ogre_1_1_g_l_e_s2_render_system.html#aa0bed8165409135364a650970823076e", null ],
-    [ "_makeOrthoMatrix", "class_ogre_1_1_g_l_e_s2_render_system.html#a29f04ca5283c108f347abea792acda4c", null ],
-    [ "_applyObliqueDepthProjection", "class_ogre_1_1_g_l_e_s2_render_system.html#a5396bb98e10b98f63d919125393e6cf8", null ],
+    [ "_getDepthStencilFormatFor", "class_ogre_1_1_g_l_e_s2_render_system.html#adea4ea5c6eeab804929dde6e1f8e6f9c", null ],
     [ "_completeDeferredVaoFboDestruction", "class_ogre_1_1_g_l_e_s2_render_system.html#a4e1583bcb013072db22095835eda8d64", null ],
-    [ "getConfigOptions", "class_ogre_1_1_g_l_e_s2_render_system.html#a4415ece805ed62ee16c8343c96766231", null ],
+    [ "getConfigOptions", "class_ogre_1_1_g_l_e_s2_render_system.html#aca550d0c75935c7f11b1b8ef6ae0a69b", null ],
+    [ "getRenderWindowDescription", "class_ogre_1_1_g_l_e_s2_render_system.html#aa6e8e2994c6b93d4a075e93223d2def1", null ],
     [ "destroyHardwareOcclusionQuery", "class_ogre_1_1_g_l_e_s2_render_system.html#ac4c60bf4c5d4347fd2b9346a90545e2b", null ],
     [ "isStaticBufferLockable", "class_ogre_1_1_g_l_e_s2_render_system.html#a319564dc746b19bb9a1490a473227b20", null ],
     [ "getMutableCapabilities", "class_ogre_1_1_g_l_e_s2_render_system.html#ab0aa0cedf1898f8cc70e290703b428c7", null ],
     [ "useCustomRenderSystemCapabilities", "class_ogre_1_1_g_l_e_s2_render_system.html#afc69e09f59064b79f3bfd4402617d07a", null ],
-    [ "setAmbientLight", "class_ogre_1_1_g_l_e_s2_render_system.html#af0237b668f88b5f31d17f830dfe78cac", null ],
-    [ "setAmbientLight", "class_ogre_1_1_g_l_e_s2_render_system.html#af2364f8648585cd4fb7bb16761b35b2d", null ],
+    [ "getFixedFunctionParams", "class_ogre_1_1_g_l_e_s2_render_system.html#acdad3c2838c8607b0f8416fb92b95df4", null ],
+    [ "_setProjectionMatrix", "class_ogre_1_1_g_l_e_s2_render_system.html#a12183f0e2538e4c65e0ec775eeafde68", null ],
+    [ "_setViewMatrix", "class_ogre_1_1_g_l_e_s2_render_system.html#acf464521f1b593f9c1bc89467e195691", null ],
+    [ "_setWorldMatrix", "class_ogre_1_1_g_l_e_s2_render_system.html#a3b31342c80388e10155c5e6e4d91fc2d", null ],
+    [ "_setFog", "class_ogre_1_1_g_l_e_s2_render_system.html#a07c349edc8c94711ff3c6869eefbcbf5", null ],
+    [ "_setSceneBlending", "class_ogre_1_1_g_l_e_s2_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
+    [ "applyFixedFunctionParams", "class_ogre_1_1_g_l_e_s2_render_system.html#a5821d9920dedc3760ce5733aa8e34a8a", null ],
     [ "setShadingType", "class_ogre_1_1_g_l_e_s2_render_system.html#a9eb67835b105be674c152a95ca83b631", null ],
     [ "setLightingEnabled", "class_ogre_1_1_g_l_e_s2_render_system.html#ad461073e0f430324258f136da3f281c5", null ],
-    [ "setWBufferEnabled", "class_ogre_1_1_g_l_e_s2_render_system.html#a01c339f6e89d82b526fb7725424a4263", null ],
-    [ "getWBufferEnabled", "class_ogre_1_1_g_l_e_s2_render_system.html#a644d2fd38872cf323c50f63148d27d02", null ],
     [ "_createRenderWindows", "class_ogre_1_1_g_l_e_s2_render_system.html#a203cb728002804209829a563902f73d5", null ],
     [ "destroyRenderTexture", "class_ogre_1_1_g_l_e_s2_render_system.html#a354ceaa02574d1cf68dcb5999b34df50", null ],
     [ "destroyRenderTarget", "class_ogre_1_1_g_l_e_s2_render_system.html#a43a03671d1c7efd7e95100d77080eb8c", null ],
@@ -115,32 +109,24 @@ var class_ogre_1_1_g_l_e_s2_render_system =
     [ "getGlobalNumberOfInstances", "class_ogre_1_1_g_l_e_s2_render_system.html#af41e08cc1bc54e34d0314f4c9ffa58f6", null ],
     [ "setGlobalNumberOfInstances", "class_ogre_1_1_g_l_e_s2_render_system.html#a3e31b243ba86e2114925a99b2c2825e1", null ],
     [ "setDepthBufferFor", "class_ogre_1_1_g_l_e_s2_render_system.html#a63c23bbd80d6862a54d471754d9bccf0", null ],
-    [ "_useLights", "class_ogre_1_1_g_l_e_s2_render_system.html#afe87000fc9e5619f4f17fd77b37a212f", null ],
-    [ "areFixedFunctionLightsInViewSpace", "class_ogre_1_1_g_l_e_s2_render_system.html#a008131b65568c0bf072ae3a96203d6c0", null ],
-    [ "_setWorldMatrix", "class_ogre_1_1_g_l_e_s2_render_system.html#ae8d7a587d3a8d15102f73b65bbceb56e", null ],
-    [ "_setViewMatrix", "class_ogre_1_1_g_l_e_s2_render_system.html#a1a7926fe7b59598fdb7b7e743efdae6c", null ],
-    [ "_setProjectionMatrix", "class_ogre_1_1_g_l_e_s2_render_system.html#ab72ff6224be9aebbc957b49919edf271", null ],
+    [ "_useLights", "class_ogre_1_1_g_l_e_s2_render_system.html#a17c2108d7e7efac07fe235a6ab3f70b0", null ],
     [ "_setTextureUnitSettings", "class_ogre_1_1_g_l_e_s2_render_system.html#ad504623eff0678f9f79b075f32673414", null ],
-    [ "_setBindingType", "class_ogre_1_1_g_l_e_s2_render_system.html#ae197c344b0b2dce1739e3c566c280f8c", null ],
     [ "_disableTextureUnit", "class_ogre_1_1_g_l_e_s2_render_system.html#a058d6805142fce7ec095a018447cbe33", null ],
     [ "_disableTextureUnitsFrom", "class_ogre_1_1_g_l_e_s2_render_system.html#a68e0ecb23c3eba58b5aeb06d646ce4cd", null ],
-    [ "_setSurfaceParams", "class_ogre_1_1_g_l_e_s2_render_system.html#aac94d165075a7431fcac95c95a430b4e", null ],
     [ "_setPointSpritesEnabled", "class_ogre_1_1_g_l_e_s2_render_system.html#a0bf5a91059d6da3b9dc4cebaf3284d23", null ],
-    [ "_setPointParameters", "class_ogre_1_1_g_l_e_s2_render_system.html#ae6da7b41093d1a7b7acc7af4c686b1cd", null ],
+    [ "_setPointParameters", "class_ogre_1_1_g_l_e_s2_render_system.html#a018624e558a652005ee4bbdbd3bb6330", null ],
     [ "_setVertexTexture", "class_ogre_1_1_g_l_e_s2_render_system.html#af40bfb084b051d8433b0893921613ba7", null ],
     [ "_setTextureCoordSet", "class_ogre_1_1_g_l_e_s2_render_system.html#addfea71a41353277fa57585cda4d6627", null ],
     [ "_setTextureCoordCalculation", "class_ogre_1_1_g_l_e_s2_render_system.html#a10fdc4a81a69fd6d9fb0bb62f3a3cece", null ],
     [ "_setTextureBlendMode", "class_ogre_1_1_g_l_e_s2_render_system.html#ac3e1b9a4c8499932b010d531b21e20ac", null ],
     [ "_setTextureMatrix", "class_ogre_1_1_g_l_e_s2_render_system.html#a6512839a2f001e463c0d46e07993192c", null ],
     [ "setColourBlendState", "class_ogre_1_1_g_l_e_s2_render_system.html#a46abac034b2217b91ae66b334e1ca42f", null ],
-    [ "_setSceneBlending", "class_ogre_1_1_g_l_e_s2_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
     [ "_setTextureProjectionRelativeTo", "class_ogre_1_1_g_l_e_s2_render_system.html#a91e7ee7dd1f244ffa9a0681efb6fae6c", null ],
     [ "_cleanupDepthBuffers", "class_ogre_1_1_g_l_e_s2_render_system.html#a568dd8e5d75fc7eef649dda6d14d447d", null ],
     [ "_pauseFrame", "class_ogre_1_1_g_l_e_s2_render_system.html#a9893de6903d77fe231da1135f5ee00db", null ],
     [ "_resumeFrame", "class_ogre_1_1_g_l_e_s2_render_system.html#abe9b7d178eb5d0ea90c7b9a35f612f91", null ],
     [ "_getViewport", "class_ogre_1_1_g_l_e_s2_render_system.html#aa0cf9dc2df0748f3076c5f8f1f8064db", null ],
     [ "_getCullingMode", "class_ogre_1_1_g_l_e_s2_render_system.html#acc15a085c3fc5970d5c028c79eadead3", null ],
-    [ "_setFog", "class_ogre_1_1_g_l_e_s2_render_system.html#abdf6101c5d6cc993b8cd160b174ddca1", null ],
     [ "_beginGeometryCount", "class_ogre_1_1_g_l_e_s2_render_system.html#a385581061b5d8d9af914d0439392aa62", null ],
     [ "_getFaceCount", "class_ogre_1_1_g_l_e_s2_render_system.html#abef8777c6302b9747a0caa97482a87f4", null ],
     [ "_getBatchCount", "class_ogre_1_1_g_l_e_s2_render_system.html#ac419ed21d6b2427b142a81fbfcde2be3", null ],
@@ -154,8 +140,6 @@ var class_ogre_1_1_g_l_e_s2_render_system =
     [ "isGpuProgramBound", "class_ogre_1_1_g_l_e_s2_render_system.html#a6077b61e7511ae56887c67498f5282a1", null ],
     [ "getNativeShadingLanguageVersion", "class_ogre_1_1_g_l_e_s2_render_system.html#a9d89d5e2e2f0c2c30e72032eae4482ec", null ],
     [ "setClipPlanes", "class_ogre_1_1_g_l_e_s2_render_system.html#a23cc0a7d87b77ec3d0a34e92335bec1a", null ],
-    [ "addClipPlane", "class_ogre_1_1_g_l_e_s2_render_system.html#abe36b06513ccdd9daca4c6443144bcfc", null ],
-    [ "resetClipPlanes", "class_ogre_1_1_g_l_e_s2_render_system.html#a844d233fa4ba66a95e56c086f76287f9", null ],
     [ "_initRenderTargets", "class_ogre_1_1_g_l_e_s2_render_system.html#aacdaca375b0736ea8b9fe660f17405ab", null ],
     [ "_notifyCameraRemoved", "class_ogre_1_1_g_l_e_s2_render_system.html#aad4ebe6f669319f83fc44cf9d5a8f9cc", null ],
     [ "_updateAllRenderTargets", "class_ogre_1_1_g_l_e_s2_render_system.html#a8ef6bbe5a63769cfe73319ac418624a8", null ],
