@@ -48,18 +48,9 @@ var class_ogre_1_1_g_l_s_l_e_s_cg_program =
     [ "bindProgramPassIterationParameters", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#aadd1cfe6227cd0d0054d63fcd4ea679a", null ],
     [ "calculateSize", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a38b1e199aa035d123c049fe797f36db4", null ],
     [ "getAttachedShaderNames", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#afc378f43c0d403dd1688d504a3e63104", null ],
-    [ "getPassTransformStates", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a2f509156ec76f5b54c7e0aca9f4eb11a", null ],
-    [ "getPassSurfaceAndLightStates", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a28b225e304a73b0e76c31fb757b6873d", null ],
-    [ "getPassFogStates", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#ac26187e3cbe7e999a7769a5b9d62d177", null ],
     [ "attachChildShader", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a4031a3af7b1cc8d680b52ca500780615", null ],
     [ "setColumnMajorMatrices", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a0c93bb9ce6492b684cc9eb457fab5594", null ],
     [ "getColumnMajorMatrices", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a64fbcab1f1063a9ba4589ece3901d535", null ],
-    [ "getInputOperationType", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#aeb96d5db3a5588a14d78f959f11f139b", null ],
-    [ "getOutputOperationType", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a53d631e6b72a9962479872ee3fb5c7b7", null ],
-    [ "getMaxOutputVertices", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#aea94746c39cdef9762bbc9b028a0ac93", null ],
-    [ "setInputOperationType", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#aa401c4a8410f8f980846ddb67c8992ac", null ],
-    [ "setOutputOperationType", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a9b3f737b4f430227a3ca446dc3b6dd16", null ],
-    [ "setMaxOutputVertices", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#ac11b7adff52d8cfc1e3b82f59afbcaa3", null ],
     [ "isLinked", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a9ad361fe5f780aa899f325e92fdd1ef5", null ],
     [ "setLinked", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a3c431c12d08cf28a3dd1c8b4e4913f55", null ],
     [ "getShaderID", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a0017ab8a5cd351aa085fa74c25c215e8", null ],
@@ -67,6 +58,7 @@ var class_ogre_1_1_g_l_s_l_e_s_cg_program =
     [ "getConstantDefinitions", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#ac281d547b47b872fe35e1e60fe07612a", null ],
     [ "setPreprocessorDefines", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#abf8f87f03e2d3b147b7f28c76c1307a7", null ],
     [ "getPreprocessorDefines", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#ad37956c9bababb03b8ce7aaf13d0f39b", null ],
+    [ "_resolveIncludes", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a827096909b3c5ef1ff46b880e1606b76", null ],
     [ "getProgramTypeName", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a74fe58cd0a7dcfcc55902fc3d9890b82", null ],
     [ "setSourceFile", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a8d265ebc2472f77cf9675dec005a123a", null ],
     [ "setSource", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#af0194bcb85a757f23cd8681c4611a4fb", null ],
@@ -92,6 +84,9 @@ var class_ogre_1_1_g_l_s_l_e_s_cg_program =
     [ "getComputeGroupDimensions", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a39e694fafadbf623d7e865bc30b3362b", null ],
     [ "getDefaultParameters", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a04675a861df66c30e431f95aa84320f5", null ],
     [ "hasDefaultParameters", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a466348cfefa74a767ed8b813e2caec6f", null ],
+    [ "getPassSurfaceAndLightStates", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#af843c9fdc4918e9201e8381ed2a1617e", null ],
+    [ "getPassFogStates", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a0f581ec108f9fe82dd89539a0aba4336", null ],
+    [ "getPassTransformStates", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a64cdfefb7694f74a93c299454d40692d", null ],
     [ "hasCompileError", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a41ca5ed671aeded51032646285f0a756", null ],
     [ "resetCompileError", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a2443ed18b880eb939123bb8daf9165c7", null ],
     [ "setManualNamedConstants", "class_ogre_1_1_g_l_s_l_e_s_cg_program.html#a25757132c8ee96c8e7ffef209ddfb078", null ],
