@@ -10,7 +10,7 @@ var class_ogre_1_1_mesh_manager =
     [ "_initialise", "class_ogre_1_1_mesh_manager.html#ac37cc73db16b7202456b49e08cb9e7e7", null ],
     [ "getByName", "class_ogre_1_1_mesh_manager.html#a29b6df3bde14f09005ab4c67d91642a5", null ],
     [ "create", "class_ogre_1_1_mesh_manager.html#acd142135740c3298d88efdcd81b127e8", null ],
-    [ "createOrRetrieve", "class_ogre_1_1_mesh_manager.html#a211310a8e1e7bb153246b2f9b8cd88e3", null ],
+    [ "createOrRetrieve", "class_ogre_1_1_mesh_manager.html#a28f7b2f14daa62019deb05c042c5a987", null ],
     [ "prepare", "class_ogre_1_1_mesh_manager.html#af230f37a344d6f1e23c63e84d4ede63f", null ],
     [ "load", "class_ogre_1_1_mesh_manager.html#a07fd12eda070c66d93fe696ab3899492", null ],
     [ "createManual", "class_ogre_1_1_mesh_manager.html#ad99f5f2e2d045e5a4af301974e45c918", null ],
@@ -28,7 +28,6 @@ var class_ogre_1_1_mesh_manager =
     [ "setBoundsPaddingFactor", "class_ogre_1_1_mesh_manager.html#a06f3acca8ad8c5f12cfc8232e57eb2e4", null ],
     [ "setListener", "class_ogre_1_1_mesh_manager.html#ae08f3de5d1ff19a3aa63ccfc2d140c97", null ],
     [ "getListener", "class_ogre_1_1_mesh_manager.html#a09f89dd999fe6fbe9b79b92ddde6aa9f", null ],
-    [ "loadResource", "class_ogre_1_1_mesh_manager.html#ab9db84516cdc6a681c3c491b259c35cd", null ],
     [ "createOrRetrieve", "class_ogre_1_1_mesh_manager.html#ac3f365e1d71fbe328637a681171d7acd", null ],
     [ "createResource", "class_ogre_1_1_mesh_manager.html#a700088a63eabb0f6cb1fac96686db464", null ],
     [ "createOrRetrieve", "class_ogre_1_1_mesh_manager.html#ac3f365e1d71fbe328637a681171d7acd", null ],
@@ -68,6 +67,5 @@ var class_ogre_1_1_mesh_manager =
     [ "destroyResourcePool", "class_ogre_1_1_mesh_manager.html#a00a7fe59aaaa4acdfda07edc704516ee", null ],
     [ "destroyAllResourcePools", "class_ogre_1_1_mesh_manager.html#a7913c36c02ef03007ff1a1c76ddf7710", null ],
     [ "getResourceIterator", "class_ogre_1_1_mesh_manager.html#a4d3289d4636168230da11c1c9794db59", null ],
-    [ "prepareResource", "class_ogre_1_1_mesh_manager.html#a7b4afd007622d165efbcc362e5566922", null ],
     [ "OGRE_AUTO_MUTEX", "class_ogre_1_1_mesh_manager.html#abbb523a827bc6ea90d3b5ec80f0cf770", null ]
 ];
\ No newline at end of file
