@@ -6,24 +6,28 @@ var class_ogre_1_1_render_system =
     [ "RenderSystem", "class_ogre_1_1_render_system.html#a3391b683d588628272d8d9de633e472e", null ],
     [ "~RenderSystem", "class_ogre_1_1_render_system.html#a785f83ff8a4ee8fb21a11c9d6fe5c928", null ],
     [ "getName", "class_ogre_1_1_render_system.html#a19b810b6fe61b526010812e9af80bf63", null ],
-    [ "getConfigOptions", "class_ogre_1_1_render_system.html#a4415ece805ed62ee16c8343c96766231", null ],
+    [ "getConfigOptions", "class_ogre_1_1_render_system.html#aca550d0c75935c7f11b1b8ef6ae0a69b", null ],
     [ "setConfigOption", "class_ogre_1_1_render_system.html#a606200a27a8adebfa62b3e388a49cf39", null ],
+    [ "getRenderWindowDescription", "class_ogre_1_1_render_system.html#aa6e8e2994c6b93d4a075e93223d2def1", null ],
     [ "createHardwareOcclusionQuery", "class_ogre_1_1_render_system.html#a2b7725995f951adff614db3874c8566c", null ],
     [ "destroyHardwareOcclusionQuery", "class_ogre_1_1_render_system.html#ac4c60bf4c5d4347fd2b9346a90545e2b", null ],
     [ "validateConfigOptions", "class_ogre_1_1_render_system.html#ab19828ac45b10a64357d8b9fc0918351", null ],
-    [ "_initialise", "class_ogre_1_1_render_system.html#aad26b5af908674412c89242003f5991e", null ],
+    [ "_initialise", "class_ogre_1_1_render_system.html#a6900425dd940a48bd1d74c3afe48b4b3", null ],
     [ "isStaticBufferLockable", "class_ogre_1_1_render_system.html#a319564dc746b19bb9a1490a473227b20", null ],
     [ "createRenderSystemCapabilities", "class_ogre_1_1_render_system.html#a4cd432497387d2c630a95ad9c0cd9772", null ],
     [ "getMutableCapabilities", "class_ogre_1_1_render_system.html#ab0aa0cedf1898f8cc70e290703b428c7", null ],
     [ "useCustomRenderSystemCapabilities", "class_ogre_1_1_render_system.html#afc69e09f59064b79f3bfd4402617d07a", null ],
     [ "reinitialise", "class_ogre_1_1_render_system.html#a32e21b240c7b6c75eab05cbc870f9868", null ],
     [ "shutdown", "class_ogre_1_1_render_system.html#a987cf400154a21403b4ff5192d423971", null ],
-    [ "setAmbientLight", "class_ogre_1_1_render_system.html#af0237b668f88b5f31d17f830dfe78cac", null ],
-    [ "setAmbientLight", "class_ogre_1_1_render_system.html#af2364f8648585cd4fb7bb16761b35b2d", null ],
+    [ "getFixedFunctionParams", "class_ogre_1_1_render_system.html#acdad3c2838c8607b0f8416fb92b95df4", null ],
+    [ "_setProjectionMatrix", "class_ogre_1_1_render_system.html#a12183f0e2538e4c65e0ec775eeafde68", null ],
+    [ "_setViewMatrix", "class_ogre_1_1_render_system.html#acf464521f1b593f9c1bc89467e195691", null ],
+    [ "_setWorldMatrix", "class_ogre_1_1_render_system.html#a3b31342c80388e10155c5e6e4d91fc2d", null ],
+    [ "_setFog", "class_ogre_1_1_render_system.html#a07c349edc8c94711ff3c6869eefbcbf5", null ],
+    [ "_setSceneBlending", "class_ogre_1_1_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
+    [ "applyFixedFunctionParams", "class_ogre_1_1_render_system.html#a5821d9920dedc3760ce5733aa8e34a8a", null ],
     [ "setShadingType", "class_ogre_1_1_render_system.html#a9eb67835b105be674c152a95ca83b631", null ],
     [ "setLightingEnabled", "class_ogre_1_1_render_system.html#ad461073e0f430324258f136da3f281c5", null ],
-    [ "setWBufferEnabled", "class_ogre_1_1_render_system.html#a01c339f6e89d82b526fb7725424a4263", null ],
-    [ "getWBufferEnabled", "class_ogre_1_1_render_system.html#a644d2fd38872cf323c50f63148d27d02", null ],
     [ "_createRenderWindow", "class_ogre_1_1_render_system.html#aaf156b9f935396e6c17f532f6e6c847e", null ],
     [ "_createRenderWindows", "class_ogre_1_1_render_system.html#a203cb728002804209829a563902f73d5", null ],
     [ "createMultiRenderTarget", "class_ogre_1_1_render_system.html#a857191a1acd18fd25498517bf183efe2", null ],
@@ -41,19 +45,13 @@ var class_ogre_1_1_render_system =
     [ "getGlobalNumberOfInstances", "class_ogre_1_1_render_system.html#af41e08cc1bc54e34d0314f4c9ffa58f6", null ],
     [ "setGlobalNumberOfInstances", "class_ogre_1_1_render_system.html#a3e31b243ba86e2114925a99b2c2825e1", null ],
     [ "setDepthBufferFor", "class_ogre_1_1_render_system.html#a63c23bbd80d6862a54d471754d9bccf0", null ],
-    [ "_useLights", "class_ogre_1_1_render_system.html#afe87000fc9e5619f4f17fd77b37a212f", null ],
-    [ "areFixedFunctionLightsInViewSpace", "class_ogre_1_1_render_system.html#a008131b65568c0bf072ae3a96203d6c0", null ],
-    [ "_setWorldMatrix", "class_ogre_1_1_render_system.html#ae8d7a587d3a8d15102f73b65bbceb56e", null ],
-    [ "_setViewMatrix", "class_ogre_1_1_render_system.html#a1a7926fe7b59598fdb7b7e743efdae6c", null ],
-    [ "_setProjectionMatrix", "class_ogre_1_1_render_system.html#ab72ff6224be9aebbc957b49919edf271", null ],
+    [ "_useLights", "class_ogre_1_1_render_system.html#a17c2108d7e7efac07fe235a6ab3f70b0", null ],
     [ "_setTextureUnitSettings", "class_ogre_1_1_render_system.html#ad504623eff0678f9f79b075f32673414", null ],
     [ "_setSampler", "class_ogre_1_1_render_system.html#a7475c99df40ff3c2a7edf6a15ad6c460", null ],
-    [ "_setBindingType", "class_ogre_1_1_render_system.html#ae197c344b0b2dce1739e3c566c280f8c", null ],
     [ "_disableTextureUnit", "class_ogre_1_1_render_system.html#a058d6805142fce7ec095a018447cbe33", null ],
     [ "_disableTextureUnitsFrom", "class_ogre_1_1_render_system.html#a68e0ecb23c3eba58b5aeb06d646ce4cd", null ],
-    [ "_setSurfaceParams", "class_ogre_1_1_render_system.html#aac94d165075a7431fcac95c95a430b4e", null ],
     [ "_setPointSpritesEnabled", "class_ogre_1_1_render_system.html#a0bf5a91059d6da3b9dc4cebaf3284d23", null ],
-    [ "_setPointParameters", "class_ogre_1_1_render_system.html#ae6da7b41093d1a7b7acc7af4c686b1cd", null ],
+    [ "_setPointParameters", "class_ogre_1_1_render_system.html#a018624e558a652005ee4bbdbd3bb6330", null ],
     [ "_setLineWidth", "class_ogre_1_1_render_system.html#a40f99785cb4f728763712169cec19f29", null ],
     [ "_setTexture", "class_ogre_1_1_render_system.html#a2cb551bfdd04b7426f73a84cbcbc93f7", null ],
     [ "_setVertexTexture", "class_ogre_1_1_render_system.html#af40bfb084b051d8433b0893921613ba7", null ],
@@ -62,15 +60,9 @@ var class_ogre_1_1_render_system =
     [ "_setTextureBlendMode", "class_ogre_1_1_render_system.html#ac3e1b9a4c8499932b010d531b21e20ac", null ],
     [ "_setTextureUnitFiltering", "class_ogre_1_1_render_system.html#a1f0f550def3f4caa1173ed6eb0d09031", null ],
     [ "_setTextureUnitFiltering", "class_ogre_1_1_render_system.html#adbc64c669661f87ee2f8db8dd18a0fe5", null ],
-    [ "_setTextureUnitCompareEnabled", "class_ogre_1_1_render_system.html#ad935b875abb352407242ea15bf92324b", null ],
-    [ "_setTextureUnitCompareFunction", "class_ogre_1_1_render_system.html#a58be1a70bee1dcaa9e177e02b64b5885", null ],
-    [ "_setTextureLayerAnisotropy", "class_ogre_1_1_render_system.html#aba523c0055a520d25fd7f08683e3c98e", null ],
     [ "_setTextureAddressingMode", "class_ogre_1_1_render_system.html#a1ed6aa9eadc930c59d2e6ac9015a6f14", null ],
-    [ "_setTextureBorderColour", "class_ogre_1_1_render_system.html#ad771e198662c3316b13b2c86caff6f2e", null ],
-    [ "_setTextureMipmapBias", "class_ogre_1_1_render_system.html#a99f92ad60c2da38c7dfcf3f429e65572", null ],
     [ "_setTextureMatrix", "class_ogre_1_1_render_system.html#a6512839a2f001e463c0d46e07993192c", null ],
     [ "setColourBlendState", "class_ogre_1_1_render_system.html#a46abac034b2217b91ae66b334e1ca42f", null ],
-    [ "_setSceneBlending", "class_ogre_1_1_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
     [ "_setSeparateSceneBlending", "class_ogre_1_1_render_system.html#a00289b710ac8817153afd820827cd49a", null ],
     [ "_setAlphaRejectSettings", "class_ogre_1_1_render_system.html#a6a3facdc0f1b8c68af65598fd3fd34aa", null ],
     [ "_setTextureProjectionRelativeTo", "class_ogre_1_1_render_system.html#a91e7ee7dd1f244ffa9a0681efb6fae6c", null ],
@@ -90,7 +82,6 @@ var class_ogre_1_1_render_system =
     [ "_setDepthBufferFunction", "class_ogre_1_1_render_system.html#a577ced6409b614ab393ca377052a385f", null ],
     [ "_setColourBufferWriteEnabled", "class_ogre_1_1_render_system.html#a14f37eed62a9283df3f83241f7c0991a", null ],
     [ "_setDepthBias", "class_ogre_1_1_render_system.html#a56beb1cebbf7f1ac372c666657a151cb", null ],
-    [ "_setFog", "class_ogre_1_1_render_system.html#abdf6101c5d6cc993b8cd160b174ddca1", null ],
     [ "_beginGeometryCount", "class_ogre_1_1_render_system.html#a385581061b5d8d9af914d0439392aa62", null ],
     [ "_getFaceCount", "class_ogre_1_1_render_system.html#abef8777c6302b9747a0caa97482a87f4", null ],
     [ "_getBatchCount", "class_ogre_1_1_render_system.html#ac419ed21d6b2427b142a81fbfcde2be3", null ],
@@ -98,10 +89,6 @@ var class_ogre_1_1_render_system =
     [ "convertColourValue", "class_ogre_1_1_render_system.html#a324d50e3fc58177d8d9f05c5cfc7e3e8", null ],
     [ "getColourVertexElementType", "class_ogre_1_1_render_system.html#a71bc0ec1bf3837dbcf7f4aa39849bb40", null ],
     [ "_convertProjectionMatrix", "class_ogre_1_1_render_system.html#adedbeb77d3def3967ee1a55c32d16a2b", null ],
-    [ "_makeProjectionMatrix", "class_ogre_1_1_render_system.html#ad401520ec851d8a1577b97d9ba3924e1", null ],
-    [ "_makeProjectionMatrix", "class_ogre_1_1_render_system.html#aa2bd398cb2fef4d6e68c251fab6a80da", null ],
-    [ "_makeOrthoMatrix", "class_ogre_1_1_render_system.html#aa18aad4d16f0448f1fa5a4fcdb224e4a", null ],
-    [ "_applyObliqueDepthProjection", "class_ogre_1_1_render_system.html#a877089932688a144c6979f648d8768fc", null ],
     [ "_setPolygonMode", "class_ogre_1_1_render_system.html#a175e831e73f7c539f843907971836125", null ],
     [ "setStencilCheckEnabled", "class_ogre_1_1_render_system.html#a4b259bf4d4e5878ae8066e073d859287", null ],
     [ "setStencilBufferParams", "class_ogre_1_1_render_system.html#ae921e432a4c8123b1571982ed8900105", null ],
@@ -118,8 +105,6 @@ var class_ogre_1_1_render_system =
     [ "isGpuProgramBound", "class_ogre_1_1_render_system.html#a6077b61e7511ae56887c67498f5282a1", null ],
     [ "getNativeShadingLanguageVersion", "class_ogre_1_1_render_system.html#a9d89d5e2e2f0c2c30e72032eae4482ec", null ],
     [ "setClipPlanes", "class_ogre_1_1_render_system.html#a23cc0a7d87b77ec3d0a34e92335bec1a", null ],
-    [ "addClipPlane", "class_ogre_1_1_render_system.html#abe36b06513ccdd9daca4c6443144bcfc", null ],
-    [ "resetClipPlanes", "class_ogre_1_1_render_system.html#a844d233fa4ba66a95e56c086f76287f9", null ],
     [ "_initRenderTargets", "class_ogre_1_1_render_system.html#aacdaca375b0736ea8b9fe660f17405ab", null ],
     [ "_notifyCameraRemoved", "class_ogre_1_1_render_system.html#aad4ebe6f669319f83fc44cf9d5a8f9cc", null ],
     [ "_updateAllRenderTargets", "class_ogre_1_1_render_system.html#a8ef6bbe5a63769cfe73319ac418624a8", null ],
@@ -148,7 +133,6 @@ var class_ogre_1_1_render_system =
     [ "beginProfileEvent", "class_ogre_1_1_render_system.html#acdcb8c0f6316a444b592882e1b7bb6c6", null ],
     [ "endProfileEvent", "class_ogre_1_1_render_system.html#a1b6abe6712afe1a695d015216ae96459", null ],
     [ "markProfileEvent", "class_ogre_1_1_render_system.html#aaafa1dfb6fcf978786add8ee2b02dfb5", null ],
-    [ "hasAnisotropicMipMapFilter", "class_ogre_1_1_render_system.html#a2532f63fc0d0c2e76b6b61c804829628", null ],
     [ "getCustomAttribute", "class_ogre_1_1_render_system.html#a97e2c11d3822c064ccb8ef0b52acf289", null ],
     [ "setDrawBuffer", "class_ogre_1_1_render_system.html#a8c143a89eb5a32e49a0ad0b136acdf56", null ]
 ];
\ No newline at end of file
