@@ -9,7 +9,7 @@ var group___direct3_d11 =
       [ "initRenderSystem", "class_ogre_1_1_d3_d11_render_system.html#a4ae0f324bcc1a167b3dd11228df11369", null ],
       [ "initConfigOptions", "class_ogre_1_1_d3_d11_render_system.html#a4f47299e13e65c4ef9125513d18ffb1f", null ],
       [ "validateConfigOptions", "class_ogre_1_1_d3_d11_render_system.html#a388a2ebc61589e3c612ee2942d56ab16", null ],
-      [ "_initialise", "class_ogre_1_1_d3_d11_render_system.html#acc1d8d487d8cc4bcbf145c3922af3235", null ],
+      [ "_initialise", "class_ogre_1_1_d3_d11_render_system.html#a2524e7d1a1f41da885564b6fbcc94a2a", null ],
       [ "_createRenderWindow", "class_ogre_1_1_d3_d11_render_system.html#a90e36e366546c9effe6def873a43db8f", null ],
       [ "_updateAllRenderTargets", "class_ogre_1_1_d3_d11_render_system.html#afb364a6e94c8c25af9f4698b5a0dd5b9", null ],
       [ "_swapAllRenderTargetBuffers", "class_ogre_1_1_d3_d11_render_system.html#a90a9f028b882d803180667923e173e08", null ],
@@ -39,8 +39,6 @@ var group___direct3_d11 =
       [ "_setTexture", "class_ogre_1_1_d3_d11_render_system.html#afb472cf1a180d18cf28258ab7b1aa700", null ],
       [ "_setSampler", "class_ogre_1_1_d3_d11_render_system.html#a49d1e995e5b6d9088ded6a4c74a3f51e", null ],
       [ "_setTextureAddressingMode", "class_ogre_1_1_d3_d11_render_system.html#a36d2adc20d779463e6ad37d1088c7e49", null ],
-      [ "_setTextureBorderColour", "class_ogre_1_1_d3_d11_render_system.html#abbfd42d04ce1b977676821f3ab0e8539", null ],
-      [ "_setTextureMipmapBias", "class_ogre_1_1_d3_d11_render_system.html#a460969a00700c596d11a5d169975ea5b", null ],
       [ "_setSeparateSceneBlending", "class_ogre_1_1_d3_d11_render_system.html#a5bb10398eda8986d56fbc24fd7064176", null ],
       [ "_setAlphaRejectSettings", "class_ogre_1_1_d3_d11_render_system.html#aa71e8588f6870ec5b4e0a29153436c5e", null ],
       [ "_setViewport", "class_ogre_1_1_d3_d11_render_system.html#a0ee4de38af33586f78359947e28dd733", null ],
@@ -55,15 +53,8 @@ var group___direct3_d11 =
       [ "_setDepthBufferFunction", "class_ogre_1_1_d3_d11_render_system.html#ac24bed40404d02ae304bbb321bde5005", null ],
       [ "_setDepthBias", "class_ogre_1_1_d3_d11_render_system.html#a66c552c73f38986e0257aa0100e0c285", null ],
       [ "_convertProjectionMatrix", "class_ogre_1_1_d3_d11_render_system.html#a7ef86fdea6938caa41e5bb4e78f59471", null ],
-      [ "_makeProjectionMatrix", "class_ogre_1_1_d3_d11_render_system.html#a56ef43340674f07f9b6e13830fae132d", null ],
-      [ "_makeProjectionMatrix", "class_ogre_1_1_d3_d11_render_system.html#a4eb6c4f7d3208d7598ef68b5e195f350", null ],
-      [ "_makeOrthoMatrix", "class_ogre_1_1_d3_d11_render_system.html#a4642d3b99b089c09628cdb8dbd73f37c", null ],
-      [ "_applyObliqueDepthProjection", "class_ogre_1_1_d3_d11_render_system.html#abd68ad9f085f2e18333f56a13b06737e", null ],
       [ "_setPolygonMode", "class_ogre_1_1_d3_d11_render_system.html#a9a8017417f83d38894518eb3e698247b", null ],
       [ "_setTextureUnitFiltering", "class_ogre_1_1_d3_d11_render_system.html#a64c9bd7874df33ab1c512c6d3248c23d", null ],
-      [ "_setTextureUnitCompareFunction", "class_ogre_1_1_d3_d11_render_system.html#a89cdd10a53bafef9794eaeccd91890cc", null ],
-      [ "_setTextureUnitCompareEnabled", "class_ogre_1_1_d3_d11_render_system.html#a8d501a1999bd3400ff6463397bc550b1", null ],
-      [ "_setTextureLayerAnisotropy", "class_ogre_1_1_d3_d11_render_system.html#afd0fe448394939914126a8d3d057a33e", null ],
       [ "setVertexDeclaration", "class_ogre_1_1_d3_d11_render_system.html#aa56f6aa7c14a7455f5a25798101b1881", null ],
       [ "setVertexDeclaration", "class_ogre_1_1_d3_d11_render_system.html#ad14beb0abdda7765c3157e6bf78d06dc", null ],
       [ "setVertexBufferBinding", "class_ogre_1_1_d3_d11_render_system.html#a0638f394c2b2a1b3035af3da58951317", null ],
@@ -88,7 +79,6 @@ var group___direct3_d11 =
       [ "_setRenderTarget", "class_ogre_1_1_d3_d11_render_system.html#ac5d750346fad8fb6e9406adbab3dcea1", null ],
       [ "determineFSAASettings", "class_ogre_1_1_d3_d11_render_system.html#a46f4c0a27d96185210ca7de1018af78e", null ],
       [ "getDisplayMonitorCount", "class_ogre_1_1_d3_d11_render_system.html#a8d9a996201d2fdbd5db0b69c5f70c5a4", null ],
-      [ "hasAnisotropicMipMapFilter", "class_ogre_1_1_d3_d11_render_system.html#a193ab39d966862d2d10afde502fb356a", null ],
       [ "_getDevice", "class_ogre_1_1_d3_d11_render_system.html#afd58a20fc530467210747dbd715de8fa", null ],
       [ "_getFeatureLevel", "class_ogre_1_1_d3_d11_render_system.html#aa7e43dffc65f93ba22f51268a218d7f1", null ],
       [ "setSubroutine", "class_ogre_1_1_d3_d11_render_system.html#a86d5c9fc07860291152c63770e3b52ef", null ],
@@ -97,17 +87,21 @@ var group___direct3_d11 =
       [ "endProfileEvent", "class_ogre_1_1_d3_d11_render_system.html#aab0676ba6ae8c9713630cb30b54d467b", null ],
       [ "markProfileEvent", "class_ogre_1_1_d3_d11_render_system.html#a7342cb7a73ff462a89189aebf8035017", null ],
       [ "setDrawBuffer", "class_ogre_1_1_d3_d11_render_system.html#a6189c0e3a731d0234a6448ee0f706945", null ],
-      [ "getConfigOptions", "class_ogre_1_1_d3_d11_render_system.html#a4415ece805ed62ee16c8343c96766231", null ],
+      [ "getConfigOptions", "class_ogre_1_1_d3_d11_render_system.html#aca550d0c75935c7f11b1b8ef6ae0a69b", null ],
+      [ "getRenderWindowDescription", "class_ogre_1_1_d3_d11_render_system.html#aa6e8e2994c6b93d4a075e93223d2def1", null ],
       [ "destroyHardwareOcclusionQuery", "class_ogre_1_1_d3_d11_render_system.html#ac4c60bf4c5d4347fd2b9346a90545e2b", null ],
       [ "isStaticBufferLockable", "class_ogre_1_1_d3_d11_render_system.html#a319564dc746b19bb9a1490a473227b20", null ],
       [ "getMutableCapabilities", "class_ogre_1_1_d3_d11_render_system.html#ab0aa0cedf1898f8cc70e290703b428c7", null ],
       [ "useCustomRenderSystemCapabilities", "class_ogre_1_1_d3_d11_render_system.html#afc69e09f59064b79f3bfd4402617d07a", null ],
-      [ "setAmbientLight", "class_ogre_1_1_d3_d11_render_system.html#af0237b668f88b5f31d17f830dfe78cac", null ],
-      [ "setAmbientLight", "class_ogre_1_1_d3_d11_render_system.html#af2364f8648585cd4fb7bb16761b35b2d", null ],
+      [ "getFixedFunctionParams", "class_ogre_1_1_d3_d11_render_system.html#acdad3c2838c8607b0f8416fb92b95df4", null ],
+      [ "_setProjectionMatrix", "class_ogre_1_1_d3_d11_render_system.html#a12183f0e2538e4c65e0ec775eeafde68", null ],
+      [ "_setViewMatrix", "class_ogre_1_1_d3_d11_render_system.html#acf464521f1b593f9c1bc89467e195691", null ],
+      [ "_setWorldMatrix", "class_ogre_1_1_d3_d11_render_system.html#a3b31342c80388e10155c5e6e4d91fc2d", null ],
+      [ "_setFog", "class_ogre_1_1_d3_d11_render_system.html#a07c349edc8c94711ff3c6869eefbcbf5", null ],
+      [ "_setSceneBlending", "class_ogre_1_1_d3_d11_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
+      [ "applyFixedFunctionParams", "class_ogre_1_1_d3_d11_render_system.html#a5821d9920dedc3760ce5733aa8e34a8a", null ],
       [ "setShadingType", "class_ogre_1_1_d3_d11_render_system.html#a9eb67835b105be674c152a95ca83b631", null ],
       [ "setLightingEnabled", "class_ogre_1_1_d3_d11_render_system.html#ad461073e0f430324258f136da3f281c5", null ],
-      [ "setWBufferEnabled", "class_ogre_1_1_d3_d11_render_system.html#a01c339f6e89d82b526fb7725424a4263", null ],
-      [ "getWBufferEnabled", "class_ogre_1_1_d3_d11_render_system.html#a644d2fd38872cf323c50f63148d27d02", null ],
       [ "_createRenderWindows", "class_ogre_1_1_d3_d11_render_system.html#a203cb728002804209829a563902f73d5", null ],
       [ "destroyRenderWindow", "class_ogre_1_1_d3_d11_render_system.html#a65ddf1db4aa3f463e0479c240ffc3dc5", null ],
       [ "destroyRenderTexture", "class_ogre_1_1_d3_d11_render_system.html#a354ceaa02574d1cf68dcb5999b34df50", null ],
@@ -121,18 +115,12 @@ var group___direct3_d11 =
       [ "getGlobalNumberOfInstances", "class_ogre_1_1_d3_d11_render_system.html#af41e08cc1bc54e34d0314f4c9ffa58f6", null ],
       [ "setGlobalNumberOfInstances", "class_ogre_1_1_d3_d11_render_system.html#a3e31b243ba86e2114925a99b2c2825e1", null ],
       [ "setDepthBufferFor", "class_ogre_1_1_d3_d11_render_system.html#a63c23bbd80d6862a54d471754d9bccf0", null ],
-      [ "_useLights", "class_ogre_1_1_d3_d11_render_system.html#afe87000fc9e5619f4f17fd77b37a212f", null ],
-      [ "areFixedFunctionLightsInViewSpace", "class_ogre_1_1_d3_d11_render_system.html#a008131b65568c0bf072ae3a96203d6c0", null ],
-      [ "_setWorldMatrix", "class_ogre_1_1_d3_d11_render_system.html#ae8d7a587d3a8d15102f73b65bbceb56e", null ],
-      [ "_setViewMatrix", "class_ogre_1_1_d3_d11_render_system.html#a1a7926fe7b59598fdb7b7e743efdae6c", null ],
-      [ "_setProjectionMatrix", "class_ogre_1_1_d3_d11_render_system.html#ab72ff6224be9aebbc957b49919edf271", null ],
+      [ "_useLights", "class_ogre_1_1_d3_d11_render_system.html#a17c2108d7e7efac07fe235a6ab3f70b0", null ],
       [ "_setTextureUnitSettings", "class_ogre_1_1_d3_d11_render_system.html#ad504623eff0678f9f79b075f32673414", null ],
-      [ "_setBindingType", "class_ogre_1_1_d3_d11_render_system.html#ae197c344b0b2dce1739e3c566c280f8c", null ],
       [ "_disableTextureUnit", "class_ogre_1_1_d3_d11_render_system.html#a058d6805142fce7ec095a018447cbe33", null ],
       [ "_disableTextureUnitsFrom", "class_ogre_1_1_d3_d11_render_system.html#a68e0ecb23c3eba58b5aeb06d646ce4cd", null ],
-      [ "_setSurfaceParams", "class_ogre_1_1_d3_d11_render_system.html#aac94d165075a7431fcac95c95a430b4e", null ],
       [ "_setPointSpritesEnabled", "class_ogre_1_1_d3_d11_render_system.html#a0bf5a91059d6da3b9dc4cebaf3284d23", null ],
-      [ "_setPointParameters", "class_ogre_1_1_d3_d11_render_system.html#ae6da7b41093d1a7b7acc7af4c686b1cd", null ],
+      [ "_setPointParameters", "class_ogre_1_1_d3_d11_render_system.html#a018624e558a652005ee4bbdbd3bb6330", null ],
       [ "_setLineWidth", "class_ogre_1_1_d3_d11_render_system.html#a40f99785cb4f728763712169cec19f29", null ],
       [ "_setVertexTexture", "class_ogre_1_1_d3_d11_render_system.html#af40bfb084b051d8433b0893921613ba7", null ],
       [ "_setTextureCoordSet", "class_ogre_1_1_d3_d11_render_system.html#addfea71a41353277fa57585cda4d6627", null ],
@@ -141,14 +129,12 @@ var group___direct3_d11 =
       [ "_setTextureUnitFiltering", "class_ogre_1_1_d3_d11_render_system.html#adbc64c669661f87ee2f8db8dd18a0fe5", null ],
       [ "_setTextureMatrix", "class_ogre_1_1_d3_d11_render_system.html#a6512839a2f001e463c0d46e07993192c", null ],
       [ "setColourBlendState", "class_ogre_1_1_d3_d11_render_system.html#a46abac034b2217b91ae66b334e1ca42f", null ],
-      [ "_setSceneBlending", "class_ogre_1_1_d3_d11_render_system.html#afd5d05521034b0e901ba0ff7f653d1e7", null ],
       [ "_setTextureProjectionRelativeTo", "class_ogre_1_1_d3_d11_render_system.html#a91e7ee7dd1f244ffa9a0681efb6fae6c", null ],
       [ "_cleanupDepthBuffers", "class_ogre_1_1_d3_d11_render_system.html#a568dd8e5d75fc7eef649dda6d14d447d", null ],
       [ "_pauseFrame", "class_ogre_1_1_d3_d11_render_system.html#a9893de6903d77fe231da1135f5ee00db", null ],
       [ "_resumeFrame", "class_ogre_1_1_d3_d11_render_system.html#abe9b7d178eb5d0ea90c7b9a35f612f91", null ],
       [ "_getViewport", "class_ogre_1_1_d3_d11_render_system.html#aa0cf9dc2df0748f3076c5f8f1f8064db", null ],
       [ "_getCullingMode", "class_ogre_1_1_d3_d11_render_system.html#acc15a085c3fc5970d5c028c79eadead3", null ],
-      [ "_setFog", "class_ogre_1_1_d3_d11_render_system.html#abdf6101c5d6cc993b8cd160b174ddca1", null ],
       [ "_beginGeometryCount", "class_ogre_1_1_d3_d11_render_system.html#a385581061b5d8d9af914d0439392aa62", null ],
       [ "_getFaceCount", "class_ogre_1_1_d3_d11_render_system.html#abef8777c6302b9747a0caa97482a87f4", null ],
       [ "_getBatchCount", "class_ogre_1_1_d3_d11_render_system.html#ac419ed21d6b2427b142a81fbfcde2be3", null ],
@@ -161,8 +147,6 @@ var group___direct3_d11 =
       [ "isGpuProgramBound", "class_ogre_1_1_d3_d11_render_system.html#a6077b61e7511ae56887c67498f5282a1", null ],
       [ "getNativeShadingLanguageVersion", "class_ogre_1_1_d3_d11_render_system.html#a9d89d5e2e2f0c2c30e72032eae4482ec", null ],
       [ "setClipPlanes", "class_ogre_1_1_d3_d11_render_system.html#a23cc0a7d87b77ec3d0a34e92335bec1a", null ],
-      [ "addClipPlane", "class_ogre_1_1_d3_d11_render_system.html#abe36b06513ccdd9daca4c6443144bcfc", null ],
-      [ "resetClipPlanes", "class_ogre_1_1_d3_d11_render_system.html#a844d233fa4ba66a95e56c086f76287f9", null ],
       [ "_initRenderTargets", "class_ogre_1_1_d3_d11_render_system.html#aacdaca375b0736ea8b9fe660f17405ab", null ],
       [ "_notifyCameraRemoved", "class_ogre_1_1_d3_d11_render_system.html#aad4ebe6f669319f83fc44cf9d5a8f9cc", null ],
       [ "setInvertVertexWinding", "class_ogre_1_1_d3_d11_render_system.html#a697f9a8c12f2d08ccc6185cd7992c238", null ],
