@@ -110,8 +110,8 @@ var group___octree =
       [ "getRealDirection", "class_ogre_1_1_octree_camera.html#a1f6379966878f5fb34e34434597e51fd", null ],
       [ "getRealUp", "class_ogre_1_1_octree_camera.html#a40785781854c0ef26b7ee2ac064bd601", null ],
       [ "getRealRight", "class_ogre_1_1_octree_camera.html#aa8ad036fb057cc7914a8c58018cb37a1", null ],
-      [ "getWorldTransforms", "class_ogre_1_1_octree_camera.html#a3dfba1df265c925df680ba2f0724dfa2", null ],
-      [ "getMovableType", "class_ogre_1_1_octree_camera.html#a296999e9eb1ced7ad2e119168a90e099", null ],
+      [ "getWorldTransforms", "class_ogre_1_1_octree_camera.html#a9e4fc72f1b725bebf8701aefc9ca2e30", null ],
+      [ "getMovableType", "class_ogre_1_1_octree_camera.html#ac0283b1d90affdff7f1f7776396e3b5c", null ],
       [ "setAutoTracking", "class_ogre_1_1_octree_camera.html#aea10ac162479ea92dfe24875ba9c6b13", null ],
       [ "setLodBias", "class_ogre_1_1_octree_camera.html#a774bb70a2ba898f3db3c9e663ec88919", null ],
       [ "getLodBias", "class_ogre_1_1_octree_camera.html#a00d4b6eb852e11325a4a237625c5de85", null ],
@@ -127,7 +127,7 @@ var group___octree =
       [ "resetWindow", "class_ogre_1_1_octree_camera.html#afdef5a2d632790d7c72f14ff672d4f54", null ],
       [ "isWindowSet", "class_ogre_1_1_octree_camera.html#a6f6d4353cdb639a8a4a360e1aa33b01a", null ],
       [ "getWindowPlanes", "class_ogre_1_1_octree_camera.html#ad2602f6ce21eb24e12ed44217932fcdb", null ],
-      [ "getBoundingRadius", "class_ogre_1_1_octree_camera.html#ab48ce5ed0b884ec773a9faeaaa89fb74", null ],
+      [ "getBoundingRadius", "class_ogre_1_1_octree_camera.html#aee8574bec9a61eb59584b897f15ce1ff", null ],
       [ "getAutoTrackTarget", "class_ogre_1_1_octree_camera.html#a08d005383a93a20e7a3b62bce04aa89b", null ],
       [ "getAutoTrackOffset", "class_ogre_1_1_octree_camera.html#ad671242389680c2078827b788189f0e1", null ],
       [ "getViewport", "class_ogre_1_1_octree_camera.html#a6875789ff50479516e455838bd8e556b", null ],
@@ -180,15 +180,15 @@ var group___octree =
       [ "setCustomProjectionMatrix", "class_ogre_1_1_octree_camera.html#a7edabdda7a22df8dcd6d4366b9f26268", null ],
       [ "isCustomProjectionMatrixEnabled", "class_ogre_1_1_octree_camera.html#a1c386af468d7d5462c8b95aef8d19020", null ],
       [ "getFrustumPlanes", "class_ogre_1_1_octree_camera.html#a855def6097624986a528a35dbb93f7cc", null ],
-      [ "getTypeFlags", "class_ogre_1_1_octree_camera.html#ab012dd76458cc87526c21ea69fdd0597", null ],
-      [ "getBoundingBox", "class_ogre_1_1_octree_camera.html#aa9d9cde952de15449650fc200cd9a675", null ],
-      [ "_updateRenderQueue", "class_ogre_1_1_octree_camera.html#a00feb96b1e042a61dddf23955fb1a5d0", null ],
-      [ "_notifyCurrentCamera", "class_ogre_1_1_octree_camera.html#acc9600b98b04f28b28b3a05c1c352829", null ],
+      [ "getTypeFlags", "class_ogre_1_1_octree_camera.html#ae5ae790cb1608c78e9791f1d8918d02d", null ],
+      [ "getBoundingBox", "class_ogre_1_1_octree_camera.html#abc3d2d6ac815088129163ed5cd040516", null ],
+      [ "_updateRenderQueue", "class_ogre_1_1_octree_camera.html#a5fc070f8c3b68a15c5c9c15fa78e0667", null ],
+      [ "_notifyCurrentCamera", "class_ogre_1_1_octree_camera.html#a139bdab72bf57abcee42ffefc404e421", null ],
       [ "setMaterial", "class_ogre_1_1_octree_camera.html#a696f5e20e2cafe6146ef6b00294cd8b1", null ],
-      [ "getMaterial", "class_ogre_1_1_octree_camera.html#a2a54dff8ade9ab6838c1517062f0eb98", null ],
-      [ "getRenderOperation", "class_ogre_1_1_octree_camera.html#ac5c36a072555e23b20d4039ef1895cd7", null ],
-      [ "getSquaredViewDepth", "class_ogre_1_1_octree_camera.html#a69e7a45502ce0a025c92db0162d8b727", null ],
-      [ "getLights", "class_ogre_1_1_octree_camera.html#a9db86db319a2a48e165274701e534821", null ],
+      [ "getMaterial", "class_ogre_1_1_octree_camera.html#af31f1095812cd5fe300cd176bbde969e", null ],
+      [ "getRenderOperation", "class_ogre_1_1_octree_camera.html#a35ed28308c5441d99bca5b3e44ff7a60", null ],
+      [ "getSquaredViewDepth", "class_ogre_1_1_octree_camera.html#ae14768f06c5c0a1c8b720323bbffe9a1", null ],
+      [ "getLights", "class_ogre_1_1_octree_camera.html#af5110d09a7c8646bb3dd25ab77815397", null ],
       [ "setProjectionType", "class_ogre_1_1_octree_camera.html#abf9929f83ec3ad3a0ffc1b5fdd249994", null ],
       [ "getProjectionType", "class_ogre_1_1_octree_camera.html#a8cfd78c1f87c5941dea4c380e140ad22", null ],
       [ "setOrthoWindow", "class_ogre_1_1_octree_camera.html#aedd3649674196da49a4ba44c4486d0df", null ],
@@ -266,8 +266,8 @@ var group___octree =
       [ "getEdgeList", "class_ogre_1_1_octree_camera.html#a60b24cd45c8df45654dcfa14a1293a3b", null ],
       [ "hasEdgeList", "class_ogre_1_1_octree_camera.html#ab7c2a8be6a9bd59e6c69ee2d76945500", null ],
       [ "getShadowVolumeRenderableIterator", "class_ogre_1_1_octree_camera.html#ab630117b036dfadbb08aab2b51c22e6c", null ],
-      [ "getLightCapBounds", "class_ogre_1_1_octree_camera.html#adfbba62eccb34cf9dcbea2231b2b311f", null ],
-      [ "getDarkCapBounds", "class_ogre_1_1_octree_camera.html#ae5f087cc4afdf47f980a5777db16bb97", null ],
+      [ "getLightCapBounds", "class_ogre_1_1_octree_camera.html#abbd832fa10445f3f47900304be5a44d8", null ],
+      [ "getDarkCapBounds", "class_ogre_1_1_octree_camera.html#a5fb2e0899e7a2b7cb3c20120fe7ad429", null ],
       [ "setCastShadows", "class_ogre_1_1_octree_camera.html#acbfc4840224e8b6ed6e27849d3341675", null ],
       [ "getCastShadows", "class_ogre_1_1_octree_camera.html#a015c3801632c98bca5dbb5aa3da1aa24", null ],
       [ "getReceivesShadows", "class_ogre_1_1_octree_camera.html#a8f2627b8d1658838a7c79c82148c6303", null ],
@@ -519,6 +519,15 @@ var group___octree =
       [ "CameraIterator", "class_ogre_1_1_octree_scene_manager.html#a22fcb8a9ddb7efe79d053a975a685111", null ],
       [ "AnimationIterator", "class_ogre_1_1_octree_scene_manager.html#a3a720414f68274bb9c5026911e27135d", null ],
       [ "MovableObjectIterator", "class_ogre_1_1_octree_scene_manager.html#a4249682ae2a69255ed225383d930aec1", null ],
+      [ "QueryTypeMask", "class_ogre_1_1_octree_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638a", [
+        [ "WORLD_GEOMETRY_TYPE_MASK", "class_ogre_1_1_octree_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aabf31f2e39287202aaf433b4f4eca2ba9", null ],
+        [ "ENTITY_TYPE_MASK", "class_ogre_1_1_octree_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aa7b1c9dfb3ee3bf4224e445b9417193e0", null ],
+        [ "FX_TYPE_MASK", "class_ogre_1_1_octree_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aa58f7504dd6f56b3e699c552e3a5edb55", null ],
+        [ "STATICGEOMETRY_TYPE_MASK", "class_ogre_1_1_octree_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aa1a7c8356b383826010f83e88f89ae258", null ],
+        [ "LIGHT_TYPE_MASK", "class_ogre_1_1_octree_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aa8e038bbc4c20e0b165a93456aceccac1", null ],
+        [ "FRUSTUM_TYPE_MASK", "class_ogre_1_1_octree_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aafa4ca767da4b4d17cb62d1f68a5dd614", null ],
+        [ "USER_TYPE_MASK_LIMIT", "class_ogre_1_1_octree_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aa5c2b2136e910fcade606b7ff99359acc", null ]
+      ] ],
       [ "IlluminationRenderStage", "class_ogre_1_1_octree_scene_manager.html#a51db39cc4fa15b28086a1793d42fc827", [
         [ "IRS_NONE", "class_ogre_1_1_octree_scene_manager.html#a51db39cc4fa15b28086a1793d42fc827a8fd3e7fb8fab382a9d29e6e081ae556a", null ],
         [ "IRS_RENDER_TO_TEXTURE", "class_ogre_1_1_octree_scene_manager.html#a51db39cc4fa15b28086a1793d42fc827a8f99da7404ae8c16199dde8d34367b1a", null ],
@@ -594,7 +603,7 @@ var group___octree =
       [ "createSceneNode", "class_ogre_1_1_octree_scene_manager.html#a73c42645ea3b064ca6e0822a8f702cd4", null ],
       [ "destroySceneNode", "class_ogre_1_1_octree_scene_manager.html#aa613e5ffb08b95a90644a61ac10c9b5c", null ],
       [ "getRootSceneNode", "class_ogre_1_1_octree_scene_manager.html#a854ef69f989aadd1da0bd79a61f88f9e", null ],
-      [ "getSceneNode", "class_ogre_1_1_octree_scene_manager.html#ad9d1a1bfe27c7ba67e5f1aa75219529f", null ],
+      [ "getSceneNode", "class_ogre_1_1_octree_scene_manager.html#aa28915596c70c1e69692a3c0a51c06be", null ],
       [ "hasSceneNode", "class_ogre_1_1_octree_scene_manager.html#a15bd8a3d9cb33ddaf37598af5c2f534f", null ],
       [ "createEntity", "class_ogre_1_1_octree_scene_manager.html#afb393cca49de8b928f7dd60838047185", null ],
       [ "createEntity", "class_ogre_1_1_octree_scene_manager.html#a3fa030af76918893a3a7ed139781dc36", null ],
@@ -736,8 +745,9 @@ var group___octree =
       [ "setShadowIndexBufferSize", "class_ogre_1_1_octree_scene_manager.html#a39c2c5902cd0eb7e86f272ed421cb408", null ],
       [ "getShadowIndexBufferSize", "class_ogre_1_1_octree_scene_manager.html#a5dce576ae8d38b4ed712991115cf1067", null ],
       [ "setShadowTextureSize", "class_ogre_1_1_octree_scene_manager.html#aa55e7f4482a2860c6378d97d8b5dfb57", null ],
-      [ "setShadowTextureConfig", "class_ogre_1_1_octree_scene_manager.html#aca9528b8e3b25370a12173afcd65e8c8", null ],
+      [ "setShadowTextureConfig", "class_ogre_1_1_octree_scene_manager.html#adcbf0f49de53a7b67574481703d4fc03", null ],
       [ "setShadowTextureConfig", "class_ogre_1_1_octree_scene_manager.html#a5e3389a02ae12fc67f999bf16495010b", null ],
+      [ "getShadowTextureConfigList", "class_ogre_1_1_octree_scene_manager.html#a6d9c78e43a7779188bf8d376b20090a3", null ],
       [ "getShadowTextureConfigIterator", "class_ogre_1_1_octree_scene_manager.html#aeca662aaa6dc25f7115ef1c675e34485", null ],
       [ "setShadowTexturePixelFormat", "class_ogre_1_1_octree_scene_manager.html#a3f2c4ffe2ab173848c0cff67789d530e", null ],
       [ "setShadowTextureFSAA", "class_ogre_1_1_octree_scene_manager.html#af32fab74832905ca7c206f81c88f24fa", null ],
@@ -745,7 +755,7 @@ var group___octree =
       [ "getShadowTextureCount", "class_ogre_1_1_octree_scene_manager.html#a2b993e97d08dd4534ce1288c8de183e0", null ],
       [ "setShadowTextureCountPerLightType", "class_ogre_1_1_octree_scene_manager.html#a70f8eddf9b8617783fb7d0995b985a9a", null ],
       [ "getShadowTextureCountPerLightType", "class_ogre_1_1_octree_scene_manager.html#af6c350b864e2bca3132abfd05b9a4b5e", null ],
-      [ "setShadowTextureSettings", "class_ogre_1_1_octree_scene_manager.html#a109998d26eb59115dc023f3a23360304", null ],
+      [ "setShadowTextureSettings", "class_ogre_1_1_octree_scene_manager.html#a6dab744863b85b65d0c0ca7f6fb0a06e", null ],
       [ "getShadowTexture", "class_ogre_1_1_octree_scene_manager.html#ad977a4b406ff9e941ad212fee9f46802", null ],
       [ "setShadowDirLightTextureOffset", "class_ogre_1_1_octree_scene_manager.html#a3596ae101fe86d686cc67e9b3aad58cb", null ],
       [ "getShadowDirLightTextureOffset", "class_ogre_1_1_octree_scene_manager.html#a43c5ca986d31852a89c6e2d06a025ee3", null ],
@@ -841,14 +851,7 @@ var group___octree =
       [ "OctreeSphereSceneQuery", "class_ogre_1_1_octree_scene_manager.html#ab66516b2e14303107c84391597b67968", null ],
       [ "OctreeAxisAlignedBoxSceneQuery", "class_ogre_1_1_octree_scene_manager.html#a243bfcbde15261e4b7ea331e5e4ec021", null ],
       [ "OctreePlaneBoundedVolumeListSceneQuery", "class_ogre_1_1_octree_scene_manager.html#a4fb1ff532ec205e8562ce7fa8d17f93d", null ],
-      [ "intersect_call", "class_ogre_1_1_octree_scene_manager.html#a5b617b19d082e55559c5879e7376382a", null ],
-      [ "WORLD_GEOMETRY_TYPE_MASK", "class_ogre_1_1_octree_scene_manager.html#ada8f4ecc06b8ffe99834d8e1db66c123", null ],
-      [ "ENTITY_TYPE_MASK", "class_ogre_1_1_octree_scene_manager.html#a43d0ee887419ee93d24975b906eb2783", null ],
-      [ "FX_TYPE_MASK", "class_ogre_1_1_octree_scene_manager.html#ac036d861c2df264375b88e9f3a407b1e", null ],
-      [ "STATICGEOMETRY_TYPE_MASK", "class_ogre_1_1_octree_scene_manager.html#a369ad7a1b8e0455052ea0bca0383942e", null ],
-      [ "LIGHT_TYPE_MASK", "class_ogre_1_1_octree_scene_manager.html#aeb00e5cde673e9bcf74ec69027cf8039", null ],
-      [ "FRUSTUM_TYPE_MASK", "class_ogre_1_1_octree_scene_manager.html#ae0f8858848acb8c595f495db753facb9", null ],
-      [ "USER_TYPE_MASK_LIMIT", "class_ogre_1_1_octree_scene_manager.html#a01d4bf3c6e81fddcfc96ec3f2714c8ac", null ]
+      [ "intersect_call", "class_ogre_1_1_octree_scene_manager.html#a5b617b19d082e55559c5879e7376382a", null ]
     ] ],
     [ "OctreeSceneManagerFactory", "class_ogre_1_1_octree_scene_manager_factory.html", [
       [ "OctreeSceneManagerFactory", "class_ogre_1_1_octree_scene_manager_factory.html#adde692f6a535caba1e49b7b63a86726a", null ],
