@@ -1,11 +1,9 @@
 var namespace_ogre =
 [
-    [ "EmitterCommands", "namespace_ogre_1_1_emitter_commands.html", "namespace_ogre_1_1_emitter_commands" ],
     [ "GLSL", "namespace_ogre_1_1_g_l_s_l.html", "namespace_ogre_1_1_g_l_s_l" ],
     [ "OverlayElementCommands", "namespace_ogre_1_1_overlay_element_commands.html", "namespace_ogre_1_1_overlay_element_commands" ],
     [ "RTShader", "namespace_ogre_1_1_r_t_shader.html", "namespace_ogre_1_1_r_t_shader" ],
     [ "Volume", "namespace_ogre_1_1_volume.html", "namespace_ogre_1_1_volume" ],
-    [ "_ConfigOption", "struct_ogre_1_1___config_option.html", "struct_ogre_1_1___config_option" ],
     [ "AbsolutePixelCountLodStrategy", "class_ogre_1_1_absolute_pixel_count_lod_strategy.html", "class_ogre_1_1_absolute_pixel_count_lod_strategy" ],
     [ "AbstractNode", "class_ogre_1_1_abstract_node.html", "class_ogre_1_1_abstract_node" ],
     [ "Affine3", "class_ogre_1_1_affine3.html", "class_ogre_1_1_affine3" ],
@@ -92,6 +90,7 @@ var namespace_ogre =
     [ "ConcreteNode", "struct_ogre_1_1_concrete_node.html", "struct_ogre_1_1_concrete_node" ],
     [ "ConfigDialog", "class_ogre_1_1_config_dialog.html", "class_ogre_1_1_config_dialog" ],
     [ "ConfigFile", "class_ogre_1_1_config_file.html", "class_ogre_1_1_config_file" ],
+    [ "ConfigOption", "struct_ogre_1_1_config_option.html", "struct_ogre_1_1_config_option" ],
     [ "ConstMapIterator", "class_ogre_1_1_const_map_iterator.html", "class_ogre_1_1_const_map_iterator" ],
     [ "ConstVectorIterator", "class_ogre_1_1_const_vector_iterator.html", "class_ogre_1_1_const_vector_iterator" ],
     [ "Controller", "class_ogre_1_1_controller.html", "class_ogre_1_1_controller" ],
@@ -115,7 +114,6 @@ var namespace_ogre =
     [ "D3D11DeviceResourceManager", "class_ogre_1_1_d3_d11_device_resource_manager.html", "class_ogre_1_1_d3_d11_device_resource_manager" ],
     [ "D3D11Driver", "class_ogre_1_1_d3_d11_driver.html", "class_ogre_1_1_d3_d11_driver" ],
     [ "D3D11DriverList", "class_ogre_1_1_d3_d11_driver_list.html", "class_ogre_1_1_d3_d11_driver_list" ],
-    [ "D3D11GpuProgramManager", "class_ogre_1_1_d3_d11_gpu_program_manager.html", "class_ogre_1_1_d3_d11_gpu_program_manager" ],
     [ "D3D11HardwareBuffer", "class_ogre_1_1_d3_d11_hardware_buffer.html", "class_ogre_1_1_d3_d11_hardware_buffer" ],
     [ "D3D11HardwareBufferManager", "class_ogre_1_1_d3_d11_hardware_buffer_manager.html", "class_ogre_1_1_d3_d11_hardware_buffer_manager" ],
     [ "D3D11HardwareIndexBuffer", "class_ogre_1_1_d3_d11_hardware_index_buffer.html", "class_ogre_1_1_d3_d11_hardware_index_buffer" ],
@@ -193,6 +191,7 @@ var namespace_ogre =
     [ "DefaultSceneManagerFactory", "class_ogre_1_1_default_scene_manager_factory.html", "class_ogre_1_1_default_scene_manager_factory" ],
     [ "DefaultShadowCameraSetup", "class_ogre_1_1_default_shadow_camera_setup.html", "class_ogre_1_1_default_shadow_camera_setup" ],
     [ "DefaultSphereSceneQuery", "class_ogre_1_1_default_sphere_scene_query.html", "class_ogre_1_1_default_sphere_scene_query" ],
+    [ "DefaultTextureManager", "class_ogre_1_1_default_texture_manager.html", "class_ogre_1_1_default_texture_manager" ],
     [ "DefaultWorkQueue", "class_ogre_1_1_default_work_queue.html", "class_ogre_1_1_default_work_queue" ],
     [ "DefaultWorkQueueBase", "class_ogre_1_1_default_work_queue_base.html", "class_ogre_1_1_default_work_queue_base" ],
     [ "DefaultZone", "class_ogre_1_1_default_zone.html", "class_ogre_1_1_default_zone" ],
@@ -214,6 +213,7 @@ var namespace_ogre =
     [ "DynLibManager", "class_ogre_1_1_dyn_lib_manager.html", "class_ogre_1_1_dyn_lib_manager" ],
     [ "EdgeData", "class_ogre_1_1_edge_data.html", "class_ogre_1_1_edge_data" ],
     [ "EdgeListBuilder", "class_ogre_1_1_edge_list_builder.html", "class_ogre_1_1_edge_list_builder" ],
+    [ "ElementTranslator", "struct_ogre_1_1_element_translator.html", "struct_ogre_1_1_element_translator" ],
     [ "EllipsoidEmitter", "class_ogre_1_1_ellipsoid_emitter.html", "class_ogre_1_1_ellipsoid_emitter" ],
     [ "EllipsoidEmitterFactory", "class_ogre_1_1_ellipsoid_emitter_factory.html", "class_ogre_1_1_ellipsoid_emitter_factory" ],
     [ "EmbeddedZipArchiveFactory", "class_ogre_1_1_embedded_zip_archive_factory.html", "class_ogre_1_1_embedded_zip_archive_factory" ],
@@ -243,7 +243,7 @@ var namespace_ogre =
     [ "FrameListener", "class_ogre_1_1_frame_listener.html", "class_ogre_1_1_frame_listener" ],
     [ "FrameTimeControllerValue", "class_ogre_1_1_frame_time_controller_value.html", "class_ogre_1_1_frame_time_controller_value" ],
     [ "FreeImageCodec", "class_ogre_1_1_free_image_codec.html", "class_ogre_1_1_free_image_codec" ],
-    [ "FreeImagePlugin", "class_ogre_1_1_free_image_plugin.html", null ],
+    [ "FreeImagePlugin", "class_ogre_1_1_free_image_plugin.html", "class_ogre_1_1_free_image_plugin" ],
     [ "Frustum", "class_ogre_1_1_frustum.html", "class_ogre_1_1_frustum" ],
     [ "GL3PlusDepthBuffer", "class_ogre_1_1_g_l3_plus_depth_buffer.html", "class_ogre_1_1_g_l3_plus_depth_buffer" ],
     [ "GL3PlusFBOManager", "class_ogre_1_1_g_l3_plus_f_b_o_manager.html", "class_ogre_1_1_g_l3_plus_f_b_o_manager" ],
@@ -275,12 +275,12 @@ var namespace_ogre =
     [ "GLCopyingRenderTexture", "class_ogre_1_1_g_l_copying_render_texture.html", "class_ogre_1_1_g_l_copying_render_texture" ],
     [ "GLCopyingRTTManager", "class_ogre_1_1_g_l_copying_r_t_t_manager.html", "class_ogre_1_1_g_l_copying_r_t_t_manager" ],
     [ "GLDepthBuffer", "class_ogre_1_1_g_l_depth_buffer.html", "class_ogre_1_1_g_l_depth_buffer" ],
+    [ "GLDepthBufferCommon", "class_ogre_1_1_g_l_depth_buffer_common.html", "class_ogre_1_1_g_l_depth_buffer_common" ],
     [ "GLES2DepthBuffer", "class_ogre_1_1_g_l_e_s2_depth_buffer.html", "class_ogre_1_1_g_l_e_s2_depth_buffer" ],
     [ "GLES2FBOManager", "class_ogre_1_1_g_l_e_s2_f_b_o_manager.html", "class_ogre_1_1_g_l_e_s2_f_b_o_manager" ],
     [ "GLES2FBOMultiRenderTarget", "class_ogre_1_1_g_l_e_s2_f_b_o_multi_render_target.html", "class_ogre_1_1_g_l_e_s2_f_b_o_multi_render_target" ],
     [ "GLES2FBORenderTexture", "class_ogre_1_1_g_l_e_s2_f_b_o_render_texture.html", "class_ogre_1_1_g_l_e_s2_f_b_o_render_texture" ],
     [ "GLES2FrameBufferObject", "class_ogre_1_1_g_l_e_s2_frame_buffer_object.html", "class_ogre_1_1_g_l_e_s2_frame_buffer_object" ],
-    [ "GLES2GpuProgramManager", "class_ogre_1_1_g_l_e_s2_gpu_program_manager.html", "class_ogre_1_1_g_l_e_s2_gpu_program_manager" ],
     [ "GLES2HardwareBuffer", "class_ogre_1_1_g_l_e_s2_hardware_buffer.html", "class_ogre_1_1_g_l_e_s2_hardware_buffer" ],
     [ "GLES2HardwareBufferManager", "class_ogre_1_1_g_l_e_s2_hardware_buffer_manager.html", "class_ogre_1_1_g_l_e_s2_hardware_buffer_manager" ],
     [ "GLES2HardwareIndexBuffer", "class_ogre_1_1_g_l_e_s2_hardware_index_buffer.html", "class_ogre_1_1_g_l_e_s2_hardware_index_buffer" ],
@@ -341,7 +341,6 @@ var namespace_ogre =
     [ "GLSLShader", "class_ogre_1_1_g_l_s_l_shader.html", "class_ogre_1_1_g_l_s_l_shader" ],
     [ "GLSLShaderCommon", "class_ogre_1_1_g_l_s_l_shader_common.html", "class_ogre_1_1_g_l_s_l_shader_common" ],
     [ "GLSLShaderFactory", "class_ogre_1_1_g_l_s_l_shader_factory.html", "class_ogre_1_1_g_l_s_l_shader_factory" ],
-    [ "GLSLShaderManager", "class_ogre_1_1_g_l_s_l_shader_manager.html", "class_ogre_1_1_g_l_s_l_shader_manager" ],
     [ "GLStateCacheManager", "class_ogre_1_1_g_l_state_cache_manager.html", "class_ogre_1_1_g_l_state_cache_manager" ],
     [ "GLStateCacheManagerCommon", "class_ogre_1_1_g_l_state_cache_manager_common.html", "class_ogre_1_1_g_l_state_cache_manager_common" ],
     [ "GLSurfaceDesc", "struct_ogre_1_1_g_l_surface_desc.html", "struct_ogre_1_1_g_l_surface_desc" ],
@@ -527,6 +526,7 @@ var namespace_ogre =
     [ "OverlayManager", "class_ogre_1_1_overlay_manager.html", "class_ogre_1_1_overlay_manager" ],
     [ "OverlayProfileSessionListener", "class_ogre_1_1_overlay_profile_session_listener.html", "class_ogre_1_1_overlay_profile_session_listener" ],
     [ "OverlaySystem", "class_ogre_1_1_overlay_system.html", "class_ogre_1_1_overlay_system" ],
+    [ "OverlayTranslator", "struct_ogre_1_1_overlay_translator.html", "struct_ogre_1_1_overlay_translator" ],
     [ "OverlayTranslatorManager", "class_ogre_1_1_overlay_translator_manager.html", "class_ogre_1_1_overlay_translator_manager" ],
     [ "Page", "class_ogre_1_1_page.html", "class_ogre_1_1_page" ],
     [ "PageContent", "class_ogre_1_1_page_content.html", "class_ogre_1_1_page_content" ],
@@ -599,7 +599,6 @@ var namespace_ogre =
     [ "PortalFactory", "class_ogre_1_1_portal_factory.html", "class_ogre_1_1_portal_factory" ],
     [ "Pose", "class_ogre_1_1_pose.html", "class_ogre_1_1_pose" ],
     [ "PreApplyTextureAliasesScriptCompilerEvent", "class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html", "class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event" ],
-    [ "PrefabFactory", "class_ogre_1_1_prefab_factory.html", "class_ogre_1_1_prefab_factory" ],
     [ "ProcessNameExclusionScriptCompilerEvent", "class_ogre_1_1_process_name_exclusion_script_compiler_event.html", "class_ogre_1_1_process_name_exclusion_script_compiler_event" ],
     [ "ProcessResourceNameScriptCompilerEvent", "class_ogre_1_1_process_resource_name_script_compiler_event.html", "class_ogre_1_1_process_resource_name_script_compiler_event" ],
     [ "Profile", "class_ogre_1_1_profile.html", "class_ogre_1_1_profile" ],
@@ -697,8 +696,8 @@ var namespace_ogre =
     [ "set", "struct_ogre_1_1set.html", "struct_ogre_1_1set" ],
     [ "ShaderGenerator", "class_ogre_1_1_shader_generator.html", "class_ogre_1_1_shader_generator" ],
     [ "ShaderHelper", "class_ogre_1_1_shader_helper.html", "class_ogre_1_1_shader_helper" ],
-    [ "ShaderHelperCg", "class_ogre_1_1_shader_helper_cg.html", "class_ogre_1_1_shader_helper_cg" ],
-    [ "ShaderHelperGLSL", "class_ogre_1_1_shader_helper_g_l_s_l.html", "class_ogre_1_1_shader_helper_g_l_s_l" ],
+    [ "ShaderHelperCg", "struct_ogre_1_1_shader_helper_cg.html", "struct_ogre_1_1_shader_helper_cg" ],
+    [ "ShaderHelperGLSL", "struct_ogre_1_1_shader_helper_g_l_s_l.html", "struct_ogre_1_1_shader_helper_g_l_s_l" ],
     [ "ShaderManager", "class_ogre_1_1_shader_manager.html", "class_ogre_1_1_shader_manager" ],
     [ "ShaderPiecesManager", "class_ogre_1_1_shader_pieces_manager.html", "class_ogre_1_1_shader_pieces_manager" ],
     [ "ShaderTemplate", "class_ogre_1_1_shader_template.html", "class_ogre_1_1_shader_template" ],
@@ -706,7 +705,6 @@ var namespace_ogre =
     [ "ShadowCaster", "class_ogre_1_1_shadow_caster.html", "class_ogre_1_1_shadow_caster" ],
     [ "ShadowRenderable", "class_ogre_1_1_shadow_renderable.html", "class_ogre_1_1_shadow_renderable" ],
     [ "ShadowTextureConfig", "struct_ogre_1_1_shadow_texture_config.html", "struct_ogre_1_1_shadow_texture_config" ],
-    [ "ShadowTextureManager", "class_ogre_1_1_shadow_texture_manager.html", "class_ogre_1_1_shadow_texture_manager" ],
     [ "SharedPtr", "class_ogre_1_1_shared_ptr.html", "class_ogre_1_1_shared_ptr" ],
     [ "SimplePageContentCollection", "class_ogre_1_1_simple_page_content_collection.html", "class_ogre_1_1_simple_page_content_collection" ],
     [ "SimplePageContentCollectionFactory", "class_ogre_1_1_simple_page_content_collection_factory.html", "class_ogre_1_1_simple_page_content_collection_factory" ],
@@ -732,7 +730,7 @@ var namespace_ogre =
     [ "StaticFaceGroup", "struct_ogre_1_1_static_face_group.html", "struct_ogre_1_1_static_face_group" ],
     [ "StaticGeometry", "class_ogre_1_1_static_geometry.html", "class_ogre_1_1_static_geometry" ],
     [ "STBIImageCodec", "class_ogre_1_1_s_t_b_i_image_codec.html", "class_ogre_1_1_s_t_b_i_image_codec" ],
-    [ "STBIPlugin", "class_ogre_1_1_s_t_b_i_plugin.html", null ],
+    [ "STBIPlugin", "class_ogre_1_1_s_t_b_i_plugin.html", "class_ogre_1_1_s_t_b_i_plugin" ],
     [ "StreamSerialiser", "class_ogre_1_1_stream_serialiser.html", "class_ogre_1_1_stream_serialiser" ],
     [ "StringConverter", "class_ogre_1_1_string_converter.html", "class_ogre_1_1_string_converter" ],
     [ "StringInterface", "class_ogre_1_1_string_interface.html", "class_ogre_1_1_string_interface" ],
@@ -769,6 +767,7 @@ var namespace_ogre =
     [ "TimeIndex", "class_ogre_1_1_time_index.html", "class_ogre_1_1_time_index" ],
     [ "Timer", "class_ogre_1_1_timer.html", "class_ogre_1_1_timer" ],
     [ "TransformBase", "class_ogre_1_1_transform_base.html", "class_ogre_1_1_transform_base" ],
+    [ "TransformBaseReal", "struct_ogre_1_1_transform_base_real.html", "struct_ogre_1_1_transform_base_real" ],
     [ "TransformKeyFrame", "class_ogre_1_1_transform_key_frame.html", "class_ogre_1_1_transform_key_frame" ],
     [ "TRect", "struct_ogre_1_1_t_rect.html", "struct_ogre_1_1_t_rect" ],
     [ "UnifiedHighLevelGpuProgram", "class_ogre_1_1_unified_high_level_gpu_program.html", "class_ogre_1_1_unified_high_level_gpu_program" ],
