@@ -1,18 +1,5 @@
 var NAVTREEINDEX11 =
 {
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a9654b843fa2ea996172993c389ce6f3a":[5,0,8,0,2],
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html#ab0ebdeda7a7d199507fb11d3ca191d71":[5,0,8,0,4],
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html#adb0ee59458754e564ec38d868fe2982f":[5,0,8,0,3],
-"class_ogre_1_1_a_s_t_c_codec.html":[5,0,3,0],
-"class_ogre_1_1_a_s_t_c_codec.html#a02c09d20cedebbd768784f4a07b1d528":[5,0,3,0,9],
-"class_ogre_1_1_a_s_t_c_codec.html#a06fa1827bc57846191e27849555b76e7":[5,0,3,0,11],
-"class_ogre_1_1_a_s_t_c_codec.html#a113b5f2d31e4ab38817b3cae401e9b44":[5,0,3,0,4],
-"class_ogre_1_1_a_s_t_c_codec.html#a19214cb3ea9412e615c59f055b311afe":[5,0,3,0,6],
-"class_ogre_1_1_a_s_t_c_codec.html#a217e39b5c41d63eb4a800352485e1306":[5,0,3,0,3],
-"class_ogre_1_1_a_s_t_c_codec.html#a21f4b8a16d070793d576f827c9fee218":[5,0,3,0,1],
-"class_ogre_1_1_a_s_t_c_codec.html#a270be35471eb9ef28fdbd4b7dced21b9":[5,0,3,0,21],
-"class_ogre_1_1_a_s_t_c_codec.html#a29e31ad112b08ea7fb648b63f426ff1f":[5,0,3,0,0],
-"class_ogre_1_1_a_s_t_c_codec.html#a3a70a9e70e1f0e2a4b6b0e249242fedf":[5,0,3,0,5],
 "class_ogre_1_1_a_s_t_c_codec.html#a3d41ee013b8d13485188f3b43de8a3c5":[5,0,3,0,10],
 "class_ogre_1_1_a_s_t_c_codec.html#a55bf1d49e91958f8e412a583666bbd58":[5,0,3,0,17],
 "class_ogre_1_1_a_s_t_c_codec.html#a6092324fd74dd0221f7c63ca8bec4fc1":[5,0,3,0,18],
@@ -26,70 +13,70 @@ var NAVTREEINDEX11 =
 "class_ogre_1_1_a_s_t_c_codec.html#ad9072a8530d43873924eb02ebae91569":[5,0,3,0,8],
 "class_ogre_1_1_a_s_t_c_codec.html#ad9edeb74111f2f4a8efcbf7ed7f3be74":[5,0,3,0,12],
 "class_ogre_1_1_a_s_t_c_codec.html#ae5b74cfd0cb797a2ac139b4adb7ac557":[5,0,3,0,15],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html":[7,0,0,6],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a0834dd85d740a9f6783e10a70dfccc1b":[7,0,0,6,4],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a0ccfb0445484d40af5e3d5fb346e1bdd":[7,0,0,6,0],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a0cf2f9d97bc32d32674038b112b405d1":[7,0,0,6,7],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a4c359b8fd0935b31bfc3a0eb61bd61e8":[7,0,0,6,5],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a60e9908806b839380729aae13b9a959a":[7,0,0,6,10],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a6ffe63d24cfcaf5c0d6028fe61baa80e":[7,0,0,6,13],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#aa2d73aba1ed139a1a83c0dcdd889a492":[7,0,0,6,2],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ab3a486ff7212d5175828e4fef82ca37c":[7,0,0,6,12],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ac2237491a332c7214c70648df44810ee":[7,0,0,6,8],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ac42ff485cbc07a6f48ad1cbc8347270e":[7,0,0,6,1],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ad3f99e9040b94b0ce0cb13ab3deb6efd":[7,0,0,6,3],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#adeb7d40e283838e2f04139fc183c95d0":[7,0,0,6,11],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ae422502cd853439e1c61851f7029a5d2":[7,0,0,6,6],
-"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ae7a96f04b4c52cbe332501ca87539b40":[7,0,0,6,9],
-"class_ogre_1_1_abstract_node.html":[5,0,2,1],
-"class_ogre_1_1_abstract_node.html#a0a7c192e205a9597db0c48ab65e5ce2c":[5,0,2,1,3],
-"class_ogre_1_1_abstract_node.html#a25d905239cc4b086edcfe91bc51f7bfb":[5,0,2,1,7],
-"class_ogre_1_1_abstract_node.html#a3923e8e9bf17ddce22b45ff5b085cca8":[5,0,2,1,2],
-"class_ogre_1_1_abstract_node.html#ab2cbfa72f106771005b1644a3f8b1b23":[5,0,2,1,1],
-"class_ogre_1_1_abstract_node.html#acf394c05aecb3cb258a28c19e1969ff2":[5,0,2,1,8],
-"class_ogre_1_1_abstract_node.html#ad12982998ed96d3b0b99a1b74ae1360b":[5,0,2,1,4],
-"class_ogre_1_1_abstract_node.html#ad2e2e1cc95ee64cd9632cc63e4ca3234":[5,0,2,1,5],
-"class_ogre_1_1_abstract_node.html#aea6ae47cf7842e94eb9a179381b9eb29":[5,0,2,1,0],
-"class_ogre_1_1_abstract_node.html#af05272e6472ec8283d7bdf304cd9ef14":[5,0,2,1,6],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html":[7,0,0,4],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a0834dd85d740a9f6783e10a70dfccc1b":[7,0,0,4,4],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a0ccfb0445484d40af5e3d5fb346e1bdd":[7,0,0,4,0],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a0cf2f9d97bc32d32674038b112b405d1":[7,0,0,4,7],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a4c359b8fd0935b31bfc3a0eb61bd61e8":[7,0,0,4,5],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a60e9908806b839380729aae13b9a959a":[7,0,0,4,10],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#a6ffe63d24cfcaf5c0d6028fe61baa80e":[7,0,0,4,13],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#aa2d73aba1ed139a1a83c0dcdd889a492":[7,0,0,4,2],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ab3a486ff7212d5175828e4fef82ca37c":[7,0,0,4,12],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ac2237491a332c7214c70648df44810ee":[7,0,0,4,8],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ac42ff485cbc07a6f48ad1cbc8347270e":[7,0,0,4,1],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ad3f99e9040b94b0ce0cb13ab3deb6efd":[7,0,0,4,3],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#adeb7d40e283838e2f04139fc183c95d0":[7,0,0,4,11],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ae422502cd853439e1c61851f7029a5d2":[7,0,0,4,6],
+"class_ogre_1_1_absolute_pixel_count_lod_strategy.html#ae7a96f04b4c52cbe332501ca87539b40":[7,0,0,4,9],
+"class_ogre_1_1_abstract_node.html":[5,0,2,0],
+"class_ogre_1_1_abstract_node.html#a0a7c192e205a9597db0c48ab65e5ce2c":[5,0,2,0,3],
+"class_ogre_1_1_abstract_node.html#a25d905239cc4b086edcfe91bc51f7bfb":[5,0,2,0,7],
+"class_ogre_1_1_abstract_node.html#a3923e8e9bf17ddce22b45ff5b085cca8":[5,0,2,0,2],
+"class_ogre_1_1_abstract_node.html#ab2cbfa72f106771005b1644a3f8b1b23":[5,0,2,0,1],
+"class_ogre_1_1_abstract_node.html#acf394c05aecb3cb258a28c19e1969ff2":[5,0,2,0,8],
+"class_ogre_1_1_abstract_node.html#ad12982998ed96d3b0b99a1b74ae1360b":[5,0,2,0,4],
+"class_ogre_1_1_abstract_node.html#ad2e2e1cc95ee64cd9632cc63e4ca3234":[5,0,2,0,5],
+"class_ogre_1_1_abstract_node.html#aea6ae47cf7842e94eb9a179381b9eb29":[5,0,2,0,0],
+"class_ogre_1_1_abstract_node.html#af05272e6472ec8283d7bdf304cd9ef14":[5,0,2,0,6],
 "class_ogre_1_1_affine3.html":[5,0,6,0],
-"class_ogre_1_1_affine3.html#a0ea806400969075b54313aed739cdce6":[5,0,6,0,12],
-"class_ogre_1_1_affine3.html#a23c6bb6170cd619be269bec8ed434ef4":[5,0,6,0,2],
-"class_ogre_1_1_affine3.html#a2511bc98e0348413c8fc00712086b8c5":[5,0,6,0,4],
-"class_ogre_1_1_affine3.html#a2a5aa7dda4dbac2401fb251f22b9b038":[5,0,6,0,20],
-"class_ogre_1_1_affine3.html#a2a72dd6d84a4f57a881f94de62bc8a34":[5,0,6,0,8],
+"class_ogre_1_1_affine3.html#a0ea806400969075b54313aed739cdce6":[5,0,6,0,13],
+"class_ogre_1_1_affine3.html#a23c6bb6170cd619be269bec8ed434ef4":[5,0,6,0,3],
+"class_ogre_1_1_affine3.html#a2511bc98e0348413c8fc00712086b8c5":[5,0,6,0,5],
+"class_ogre_1_1_affine3.html#a2a72dd6d84a4f57a881f94de62bc8a34":[5,0,6,0,9],
 "class_ogre_1_1_affine3.html#a30b0a43638d438c54c335453a3bf4636":[5,0,6,0,0],
-"class_ogre_1_1_affine3.html#a44f73afce352e88d8b8463475baf6b5a":[5,0,6,0,6],
-"class_ogre_1_1_affine3.html#a46525728e27cbc3aeb2cbf1c75912174":[5,0,6,0,17],
-"class_ogre_1_1_affine3.html#a4cce7fb866e2a35fc2c425f897d03ca2":[5,0,6,0,9],
-"class_ogre_1_1_affine3.html#a4fce454d3b27bb2ebc5e3cabf4b931eb":[5,0,6,0,23],
-"class_ogre_1_1_affine3.html#a54652722d399be755ebfd3fa1af886f1":[5,0,6,0,21],
+"class_ogre_1_1_affine3.html#a3f43524c27cb439313bd081ae280642c":[5,0,6,0,19],
+"class_ogre_1_1_affine3.html#a44f73afce352e88d8b8463475baf6b5a":[5,0,6,0,7],
+"class_ogre_1_1_affine3.html#a4cce7fb866e2a35fc2c425f897d03ca2":[5,0,6,0,10],
+"class_ogre_1_1_affine3.html#a4f62949a39d5c9e1b6003e3bfbb7c2f2":[5,0,6,0,2],
 "class_ogre_1_1_affine3.html#a5ce74f781c8c3ce99976c31fba9a6eb0":[5,0,6,0,1],
-"class_ogre_1_1_affine3.html#a633f5ace5a3b3870d60d1b3d08dc1477":[5,0,6,0,24],
-"class_ogre_1_1_affine3.html#a7703077c23c37d7eb1889f9c9f5197c0":[5,0,6,0,18],
-"class_ogre_1_1_affine3.html#a7fea969b4c39eb571b5798a7ff23d16e":[5,0,6,0,26],
-"class_ogre_1_1_affine3.html#a804a6a6e44386202d103a516149eb4be":[5,0,6,0,29],
-"class_ogre_1_1_affine3.html#a84c9eb0fd3027630e299615e9ea6efb0":[5,0,6,0,25],
-"class_ogre_1_1_affine3.html#a9115cefcc7321c90659b976bcce542f3":[5,0,6,0,28],
+"class_ogre_1_1_affine3.html#a8cb72d4aa4fcb719ea6110758bb6e89e":[5,0,6,0,25],
+"class_ogre_1_1_affine3.html#a92260a3e504b84292acac6d600c9ef36":[5,0,6,0,28],
+"class_ogre_1_1_affine3.html#a99c2bd12bee6aedcb27fcd4cd70e1a6b":[5,0,6,0,18],
 "class_ogre_1_1_affine3.html#a9a771b8258d88c5a37f58494de1b0597":[5,0,6,0,30],
-"class_ogre_1_1_affine3.html#a9fcc18e98ded8a18261e66f92fc2dfe8":[5,0,6,0,13],
-"class_ogre_1_1_affine3.html#aa21a63d88ef4ffc429f2c8edbabe1a1f":[5,0,6,0,15],
-"class_ogre_1_1_affine3.html#aa9ab6eb8ff75222d1154f14bdd3d2a8e":[5,0,6,0,10],
-"class_ogre_1_1_affine3.html#aad8e3b12ac04a0229d5a2af84f358883":[5,0,6,0,7],
-"class_ogre_1_1_affine3.html#aadd0be612b9026d71e25c667123c38fd":[5,0,6,0,14],
-"class_ogre_1_1_affine3.html#aadd0be612b9026d71e25c667123c38fd":[5,0,6,0,22],
-"class_ogre_1_1_affine3.html#ad5400b5a490eb1df3e80d7d5d193b2aa":[5,0,6,0,19],
-"class_ogre_1_1_affine3.html#ad6af815a07b45f0459cc223b7aab8d21":[5,0,6,0,16],
-"class_ogre_1_1_affine3.html#ae0ff2f252c8642916d15316ff0e2107c":[5,0,6,0,5],
-"class_ogre_1_1_affine3.html#ae45c5a41dd3e6b752e406a5597a1990d":[5,0,6,0,11],
+"class_ogre_1_1_affine3.html#a9abae638b21413a41bc5b004ecacecd4":[5,0,6,0,21],
+"class_ogre_1_1_affine3.html#a9fcc18e98ded8a18261e66f92fc2dfe8":[5,0,6,0,14],
+"class_ogre_1_1_affine3.html#aa0f27bb6d140ca1d09a03c9e27c5f96c":[5,0,6,0,16],
+"class_ogre_1_1_affine3.html#aa9ab6eb8ff75222d1154f14bdd3d2a8e":[5,0,6,0,11],
+"class_ogre_1_1_affine3.html#aad8e3b12ac04a0229d5a2af84f358883":[5,0,6,0,8],
+"class_ogre_1_1_affine3.html#ab5d6ffc4f1604d59552be2c4d9f4a01a":[5,0,6,0,15],
+"class_ogre_1_1_affine3.html#abf2a16142c5dfd6360fb5e697fbf578d":[5,0,6,0,24],
+"class_ogre_1_1_affine3.html#ac029df849f85850a59921e5f361927c4":[5,0,6,0,29],
+"class_ogre_1_1_affine3.html#acd424a976abe0bd586dd6b46876dc235":[5,0,6,0,27],
+"class_ogre_1_1_affine3.html#ad58c2d3fb3345558228fe3bafdf1b732":[5,0,6,0,23],
+"class_ogre_1_1_affine3.html#ae0ff2f252c8642916d15316ff0e2107c":[5,0,6,0,6],
+"class_ogre_1_1_affine3.html#ae45c5a41dd3e6b752e406a5597a1990d":[5,0,6,0,12],
+"class_ogre_1_1_affine3.html#aebf4846bf9c86970bc9569d132892708":[5,0,6,0,17],
+"class_ogre_1_1_affine3.html#aef6aefde7236f81a2343af8a1d81da50":[5,0,6,0,20],
 "class_ogre_1_1_affine3.html#af37f4f9d112151323e0f53d135c13612":[5,0,6,0,31],
-"class_ogre_1_1_affine3.html#aff614a967fe24db7a8059be148f9c8a1":[5,0,6,0,3],
-"class_ogre_1_1_affine3.html#ga1e597cc58a82b0966165b5cf783ed852":[5,0,6,0,27],
-"class_ogre_1_1_aligned_memory.html":[5,0,2,3],
-"class_ogre_1_1_aligned_memory.html#a63bd1c2f3f55b989331a04fccc07356a":[5,0,2,3,0],
-"class_ogre_1_1_aligned_memory.html#ad13640994e404f2befc9b7eb72f8659c":[5,0,2,3,1],
-"class_ogre_1_1_aligned_memory.html#aec9665c128b282869284a6025520adee":[5,0,2,3,2],
-"class_ogre_1_1_alloc_policy.html":[7,0,0,12],
-"class_ogre_1_1_allocated_object.html":[7,0,0,11],
+"class_ogre_1_1_affine3.html#afbc5442e28735144fe9e1f41daa89c3a":[5,0,6,0,26],
+"class_ogre_1_1_affine3.html#aff614a967fe24db7a8059be148f9c8a1":[5,0,6,0,4],
+"class_ogre_1_1_affine3.html#gaebc7c568cc1d6f13405a756be1af73fa":[5,0,6,0,22],
+"class_ogre_1_1_aligned_memory.html":[5,0,2,2],
+"class_ogre_1_1_aligned_memory.html#a63bd1c2f3f55b989331a04fccc07356a":[5,0,2,2,0],
+"class_ogre_1_1_aligned_memory.html#ad13640994e404f2befc9b7eb72f8659c":[5,0,2,2,1],
+"class_ogre_1_1_aligned_memory.html#aec9665c128b282869284a6025520adee":[5,0,2,2,2],
+"class_ogre_1_1_alloc_policy.html":[7,0,0,10],
+"class_ogre_1_1_allocated_object.html":[7,0,0,9],
 "class_ogre_1_1_angle.html":[5,0,6,1],
 "class_ogre_1_1_angle.html#ab54f1fbb916c5fd0964ea89ff1d069a2":[5,0,6,1,0],
 "class_ogre_1_1_animable_object.html":[5,0,0,0],
@@ -218,12 +205,12 @@ var NAVTREEINDEX11 =
 "class_ogre_1_1_animation_container.html#abf8658873fe91d6010482248819740e8":[5,0,0,3,6],
 "class_ogre_1_1_animation_container.html#ac1469c7aff1e39df3e99a69ba99ff61f":[5,0,0,3,4],
 "class_ogre_1_1_animation_container.html#ae31ca8ef4dfaa0904a9f5aa05e12e455":[5,0,0,3,5],
-"class_ogre_1_1_animation_controller_function.html":[5,0,2,4],
-"class_ogre_1_1_animation_controller_function.html#a4f3ff1b57eba7e774d10b833273ec137":[5,0,2,4,2],
-"class_ogre_1_1_animation_controller_function.html#a6185e4121c1ba411a09834d3950be32e":[5,0,2,4,4],
-"class_ogre_1_1_animation_controller_function.html#a960ce93c9ad39f7a1eec98d0fce5c6c8":[5,0,2,4,0],
-"class_ogre_1_1_animation_controller_function.html#ae5b3c53fb3ffea9f2dba73272e2a7b45":[5,0,2,4,1],
-"class_ogre_1_1_animation_controller_function.html#aee7d37308bff5172e3b7e58a7d31627a":[5,0,2,4,3],
+"class_ogre_1_1_animation_controller_function.html":[5,0,2,3],
+"class_ogre_1_1_animation_controller_function.html#a4f3ff1b57eba7e774d10b833273ec137":[5,0,2,3,2],
+"class_ogre_1_1_animation_controller_function.html#a6185e4121c1ba411a09834d3950be32e":[5,0,2,3,4],
+"class_ogre_1_1_animation_controller_function.html#a960ce93c9ad39f7a1eec98d0fce5c6c8":[5,0,2,3,0],
+"class_ogre_1_1_animation_controller_function.html#ae5b3c53fb3ffea9f2dba73272e2a7b45":[5,0,2,3,1],
+"class_ogre_1_1_animation_controller_function.html#aee7d37308bff5172e3b7e58a7d31627a":[5,0,2,3,3],
 "class_ogre_1_1_animation_state.html":[5,0,0,4],
 "class_ogre_1_1_animation_state.html#a06594a53335afbe8ccb67331e35a32fd":[5,0,0,4,20],
 "class_ogre_1_1_animation_state.html#a0a78387f3637ec52d9eda6614adbf479":[5,0,0,4,1],
@@ -249,5 +236,18 @@ var NAVTREEINDEX11 =
 "class_ogre_1_1_animation_state.html#ae4b159b5488a0ddb7d10f0d2a4208cf5":[5,0,0,4,8],
 "class_ogre_1_1_animation_state.html#ae4fd5f5523ac2428599220ab2ff0bd59":[5,0,0,4,24],
 "class_ogre_1_1_animation_state.html#ae69ff5a068d086be7ecc048a71ed8efc":[5,0,0,4,5],
-"class_ogre_1_1_animation_state.html#aeb2b66c49de14384860c6599db5b7f30":[5,0,0,4,3]
+"class_ogre_1_1_animation_state.html#aeb2b66c49de14384860c6599db5b7f30":[5,0,0,4,3],
+"class_ogre_1_1_animation_state.html#aeb306a097ff05af022b8d55a660812f2":[5,0,0,4,17],
+"class_ogre_1_1_animation_state.html#af1910e8bbaebe61359ac7edb638e5cbc":[5,0,0,4,7],
+"class_ogre_1_1_animation_state.html#af8670094f9bedeea874ca9997982829b":[5,0,0,4,12],
+"class_ogre_1_1_animation_state_controller_value.html":[5,0,0,5],
+"class_ogre_1_1_animation_state_controller_value.html#a3bebc064f309a92a4ec5e6d251d8ee46":[5,0,0,5,1],
+"class_ogre_1_1_animation_state_controller_value.html#a86fae07d933638c3dfc1fd5751c4a469":[5,0,0,5,2],
+"class_ogre_1_1_animation_state_controller_value.html#a91cba7b97509704127ccbbb712a5df6c":[5,0,0,5,3],
+"class_ogre_1_1_animation_state_controller_value.html#a9cf37f160c78eb346f6b3f070d57fbe5":[5,0,0,5,0],
+"class_ogre_1_1_animation_state_set.html":[5,0,0,6],
+"class_ogre_1_1_animation_state_set.html#a146fea0c5c0ccca83e70e9b0de2c5291":[5,0,0,6,1],
+"class_ogre_1_1_animation_state_set.html#a22d9922ebdb8b3b3d70ca7e58acbd95d":[5,0,0,6,5],
+"class_ogre_1_1_animation_state_set.html#a3651ad254b49b98e8d590da1bc22735a":[5,0,0,6,6],
+"class_ogre_1_1_animation_state_set.html#a49af4b5b62648c598fe631fda6984ea4":[5,0,0,6,7]
 };
