@@ -1,20 +1,5 @@
 var NAVTREEINDEX22 =
 {
-"class_ogre_1_1_cg_program.html#a463bffd1f68fc8ae3c29d64402e9ca8d":[5,2,1,1,46],
-"class_ogre_1_1_cg_program.html#a5016aec1762b026997ddd346775879ef":[5,2,1,1,57],
-"class_ogre_1_1_cg_program.html#a5513ffce404b14cff72846318b018d32":[5,2,1,1,70],
-"class_ogre_1_1_cg_program.html#a5b9074b10dd674d98666fee888cd6bb3":[5,2,1,1,12],
-"class_ogre_1_1_cg_program.html#a60ce96525ac730a0f7b466ed287beef3":[5,2,1,1,67],
-"class_ogre_1_1_cg_program.html#a62ecd906ba236975ddec42c62d0b4e2b":[5,2,1,1,30],
-"class_ogre_1_1_cg_program.html#a65a32235ed550af62066095e5e7735b5":[5,2,1,1,6],
-"class_ogre_1_1_cg_program.html#a65a86c6f911a8ac4b0c6d7366fb44f26":[5,2,1,1,26],
-"class_ogre_1_1_cg_program.html#a699d1c851f494a8d5d23d23b695ceb47":[5,2,1,1,56],
-"class_ogre_1_1_cg_program.html#a6e4126e3d4bdc85eb3bfb4530c8e8249":[5,2,1,1,48],
-"class_ogre_1_1_cg_program.html#a74138c0203835513613af73cdb08890d":[5,2,1,1,64],
-"class_ogre_1_1_cg_program.html#a74fe58cd0a7dcfcc55902fc3d9890b82":[5,2,1,1,33],
-"class_ogre_1_1_cg_program.html#a7b7db741c7eab2838fd53149c41357e5":[5,2,1,1,36],
-"class_ogre_1_1_cg_program.html#a7ce0be99072f2ffd6055cd3bbd20b625":[5,2,1,1,25],
-"class_ogre_1_1_cg_program.html#a7e248a1cca0662418d4ab3f63c2e7cf6":[5,2,1,1,76],
 "class_ogre_1_1_cg_program.html#a843c706f65d219c1d04b8aeacc4bd3c8":[5,2,1,1,43],
 "class_ogre_1_1_cg_program.html#a848bf4164963cf8c0435c972eb717e0f":[5,2,1,1,44],
 "class_ogre_1_1_cg_program.html#a84c3904bfaeeb1166dbca41e0c9f3b29":[5,2,1,1,49],
@@ -37,11 +22,11 @@ var NAVTREEINDEX22 =
 "class_ogre_1_1_cg_program.html#aaf3746937cd11864f53bc1c3b4437541":[5,2,1,1,81],
 "class_ogre_1_1_cg_program.html#aaf63d096584ac7d97fe1d1b0226c9561":[5,2,1,1,80],
 "class_ogre_1_1_cg_program.html#ab6e377a3964d566ea112fe63bf1d7678":[5,2,1,1,74],
-"class_ogre_1_1_cg_program.html#abf8f87f03e2d3b147b7f28c76c1307a7":[5,2,1,1,31],
-"class_ogre_1_1_cg_program.html#ac281d547b47b872fe35e1e60fe07612a":[5,2,1,1,29],
+"class_ogre_1_1_cg_program.html#abf8f87f03e2d3b147b7f28c76c1307a7":[5,2,1,1,30],
+"class_ogre_1_1_cg_program.html#ac281d547b47b872fe35e1e60fe07612a":[5,2,1,1,28],
 "class_ogre_1_1_cg_program.html#ac7b2745e88eabb52b640a77f03e0f896":[5,2,1,1,37],
 "class_ogre_1_1_cg_program.html#acd74bfad569b567e99cfe44cb2bb99ad":[5,2,1,1,10],
-"class_ogre_1_1_cg_program.html#ad37956c9bababb03b8ce7aaf13d0f39b":[5,2,1,1,32],
+"class_ogre_1_1_cg_program.html#ad37956c9bababb03b8ce7aaf13d0f39b":[5,2,1,1,31],
 "class_ogre_1_1_cg_program.html#ad4b984bfbf148ddb3310b3d0ba8a9d5d":[5,2,1,1,84],
 "class_ogre_1_1_cg_program.html#ade85e4d5579519e4117a84789c0ae8fd":[5,2,1,1,77],
 "class_ogre_1_1_cg_program.html#ae0630743f8c509bc341d294ebfc433f4":[5,2,1,1,53],
@@ -72,28 +57,28 @@ var NAVTREEINDEX22 =
 "class_ogre_1_1_cg_program_factory.html#a981698847d227ebfdc30a1ed3cc1dd61":[5,2,1,2,4],
 "class_ogre_1_1_cg_program_factory.html#ab4e67b062cc70d29df7e7d169bb88e71":[5,2,1,2,3],
 "class_ogre_1_1_cg_program_factory.html#abf5b3712c5577401d085544a045ce549":[5,2,1,2,2],
-"class_ogre_1_1_codec.html":[5,0,2,9],
-"class_ogre_1_1_codec.html#a1eae89f8ca897b68ba6473e7b3d058f4":[5,0,2,9,14],
-"class_ogre_1_1_codec.html#a21f4b8a16d070793d576f827c9fee218":[5,0,2,9,2],
-"class_ogre_1_1_codec.html#a270be35471eb9ef28fdbd4b7dced21b9":[5,0,2,9,17],
-"class_ogre_1_1_codec.html#a29e31ad112b08ea7fb648b63f426ff1f":[5,0,2,9,1],
-"class_ogre_1_1_codec.html#a4134526fadbb63af778e17a8d6301c3c":[5,0,2,9,12],
-"class_ogre_1_1_codec.html#a55bf1d49e91958f8e412a583666bbd58":[5,0,2,9,8],
-"class_ogre_1_1_codec.html#a6092324fd74dd0221f7c63ca8bec4fc1":[5,0,2,9,9],
-"class_ogre_1_1_codec.html#a60f445cc6919df56af6611fd14eec47d":[5,0,2,9,5],
-"class_ogre_1_1_codec.html#a7aa2599cd9db05e590fb7f7786076852":[5,0,2,9,7],
-"class_ogre_1_1_codec.html#a8cc81c85bd7d4e25393aa153c5e01454":[5,0,2,9,3],
-"class_ogre_1_1_codec.html#aa8c8c94007bd13ccab9ca54fb3e8bf81":[5,0,2,9,13],
-"class_ogre_1_1_codec.html#ac8775b1052fb8ba72abdfb55df20a6af":[5,0,2,9,11],
-"class_ogre_1_1_codec.html#acc4ee751f92b6e54051393e74e0a2884":[5,0,2,9,10],
-"class_ogre_1_1_codec.html#ada1a5477ab6a563565f1b3599d7b806a":[5,0,2,9,15],
-"class_ogre_1_1_codec.html#ae5b74cfd0cb797a2ac139b4adb7ac557":[5,0,2,9,6],
-"class_ogre_1_1_codec.html#aeb344d293259ec352c308d81fdf3e94c":[5,0,2,9,16],
-"class_ogre_1_1_codec.html#aee7d2a1126a22bbf3da40088495cb00b":[5,0,2,9,4],
-"class_ogre_1_1_codec.html#af90756f690827353e18347d328bc5180":[5,0,2,9,18],
-"class_ogre_1_1_codec_1_1_codec_data.html":[5,0,2,9,0],
-"class_ogre_1_1_codec_1_1_codec_data.html#a2e83b5d12864adb8acf31b439713105b":[5,0,2,9,0,1],
-"class_ogre_1_1_codec_1_1_codec_data.html#a8d1d3dc4a466a4e992aad72c14bf81eb":[5,0,2,9,0,0],
+"class_ogre_1_1_codec.html":[5,0,2,8],
+"class_ogre_1_1_codec.html#a1eae89f8ca897b68ba6473e7b3d058f4":[5,0,2,8,14],
+"class_ogre_1_1_codec.html#a21f4b8a16d070793d576f827c9fee218":[5,0,2,8,2],
+"class_ogre_1_1_codec.html#a270be35471eb9ef28fdbd4b7dced21b9":[5,0,2,8,17],
+"class_ogre_1_1_codec.html#a29e31ad112b08ea7fb648b63f426ff1f":[5,0,2,8,1],
+"class_ogre_1_1_codec.html#a4134526fadbb63af778e17a8d6301c3c":[5,0,2,8,12],
+"class_ogre_1_1_codec.html#a55bf1d49e91958f8e412a583666bbd58":[5,0,2,8,8],
+"class_ogre_1_1_codec.html#a6092324fd74dd0221f7c63ca8bec4fc1":[5,0,2,8,9],
+"class_ogre_1_1_codec.html#a60f445cc6919df56af6611fd14eec47d":[5,0,2,8,5],
+"class_ogre_1_1_codec.html#a7aa2599cd9db05e590fb7f7786076852":[5,0,2,8,7],
+"class_ogre_1_1_codec.html#a8cc81c85bd7d4e25393aa153c5e01454":[5,0,2,8,3],
+"class_ogre_1_1_codec.html#aa8c8c94007bd13ccab9ca54fb3e8bf81":[5,0,2,8,13],
+"class_ogre_1_1_codec.html#ac8775b1052fb8ba72abdfb55df20a6af":[5,0,2,8,11],
+"class_ogre_1_1_codec.html#acc4ee751f92b6e54051393e74e0a2884":[5,0,2,8,10],
+"class_ogre_1_1_codec.html#ada1a5477ab6a563565f1b3599d7b806a":[5,0,2,8,15],
+"class_ogre_1_1_codec.html#ae5b74cfd0cb797a2ac139b4adb7ac557":[5,0,2,8,6],
+"class_ogre_1_1_codec.html#aeb344d293259ec352c308d81fdf3e94c":[5,0,2,8,16],
+"class_ogre_1_1_codec.html#aee7d2a1126a22bbf3da40088495cb00b":[5,0,2,8,4],
+"class_ogre_1_1_codec.html#af90756f690827353e18347d328bc5180":[5,0,2,8,18],
+"class_ogre_1_1_codec_1_1_codec_data.html":[5,0,2,8,0],
+"class_ogre_1_1_codec_1_1_codec_data.html#a2e83b5d12864adb8acf31b439713105b":[5,0,2,8,0,1],
+"class_ogre_1_1_codec_1_1_codec_data.html#a8d1d3dc4a466a4e992aad72c14bf81eb":[5,0,2,8,0,0],
 "class_ogre_1_1_colour_fader_affector.html":[5,2,6,2],
 "class_ogre_1_1_colour_fader_affector.html#a08d117bf25f011f96d81f1f4ecb25113":[5,2,6,2,20],
 "class_ogre_1_1_colour_fader_affector.html#a0f55da0550a7e1ab70a1c8bf598a3e20":[5,2,6,2,18],
@@ -201,53 +186,68 @@ var NAVTREEINDEX22 =
 "class_ogre_1_1_colour_fader_affector_1_1_cmd_red_adjust.html":[5,2,6,2,3],
 "class_ogre_1_1_colour_fader_affector_1_1_cmd_red_adjust.html#a642964b6d6530d4808866bb0d56e5b83":[5,2,6,2,3,0],
 "class_ogre_1_1_colour_fader_affector_1_1_cmd_red_adjust.html#ae1a6474819a56265737e7bfd49b680db":[5,2,6,2,3,1],
-"class_ogre_1_1_colour_fader_affector_factory.html":[7,0,0,73],
-"class_ogre_1_1_colour_fader_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,73,0],
-"class_ogre_1_1_colour_fader_affector_factory2.html":[7,0,0,74],
-"class_ogre_1_1_colour_fader_affector_factory2.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,74,0],
-"class_ogre_1_1_colour_image_affector.html":[7,0,0,75],
-"class_ogre_1_1_colour_image_affector.html#a08d117bf25f011f96d81f1f4ecb25113":[7,0,0,75,10],
-"class_ogre_1_1_colour_image_affector.html#a0f55da0550a7e1ab70a1c8bf598a3e20":[7,0,0,75,8],
-"class_ogre_1_1_colour_image_affector.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[7,0,0,75,14],
-"class_ogre_1_1_colour_image_affector.html#a1d078304c38a9f85d483fc8ed0cdf1fe":[7,0,0,75,12],
-"class_ogre_1_1_colour_image_affector.html#a1f75f89834ef18b62b909b4682e6a812":[7,0,0,75,15],
-"class_ogre_1_1_colour_image_affector.html#a2fb5b54b08efe8a456d4e57dfa7860d4":[7,0,0,75,4],
-"class_ogre_1_1_colour_image_affector.html#a52df9990e8c3cdeda702bcefc77f67d6":[7,0,0,75,5],
-"class_ogre_1_1_colour_image_affector.html#a7118e0cf5c7cefcbbf004580add48ae5":[7,0,0,75,1],
-"class_ogre_1_1_colour_image_affector.html#a984fc468041419661aa75af91d0d2757":[7,0,0,75,2],
-"class_ogre_1_1_colour_image_affector.html#a9aac32f93bd149a34b809a57a9f01f8f":[7,0,0,75,11],
-"class_ogre_1_1_colour_image_affector.html#a9c00c2785abad52b3c006988196a2cd4":[7,0,0,75,3],
-"class_ogre_1_1_colour_image_affector.html#aad68d8b18faad14e8286a67527094654":[7,0,0,75,13],
-"class_ogre_1_1_colour_image_affector.html#ab38dc9df81b23a9b041b56d7329cb5b9":[7,0,0,75,6],
-"class_ogre_1_1_colour_image_affector.html#ad4b984bfbf148ddb3310b3d0ba8a9d5d":[7,0,0,75,9],
-"class_ogre_1_1_colour_image_affector.html#ae3e13925bde11db245f6c9bbf5031a93":[7,0,0,75,7],
-"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html":[7,0,0,75,0],
-"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html#a73b813ac40e8327d3e67d33aeb7264c9":[7,0,0,75,0,0],
-"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html#a974c2899b3b9e87f09cc583c11f7be99":[7,0,0,75,0,1],
-"class_ogre_1_1_colour_image_affector_factory.html":[7,0,0,76],
-"class_ogre_1_1_colour_image_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,76,0],
-"class_ogre_1_1_colour_interpolator_affector.html":[7,0,0,77],
-"class_ogre_1_1_colour_interpolator_affector.html#a055f5f5bbe49e66d40c84c257e78b340":[7,0,0,77,19],
-"class_ogre_1_1_colour_interpolator_affector.html#a08d117bf25f011f96d81f1f4ecb25113":[7,0,0,77,14],
-"class_ogre_1_1_colour_interpolator_affector.html#a0f55da0550a7e1ab70a1c8bf598a3e20":[7,0,0,77,12],
-"class_ogre_1_1_colour_interpolator_affector.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[7,0,0,77,18],
-"class_ogre_1_1_colour_interpolator_affector.html#a1d078304c38a9f85d483fc8ed0cdf1fe":[7,0,0,77,16],
-"class_ogre_1_1_colour_interpolator_affector.html#a23342275feed700c10a601e5edb17152":[7,0,0,77,3],
-"class_ogre_1_1_colour_interpolator_affector.html#a28d59576dcb488c86373eb74d6f0e1ed":[7,0,0,77,4],
-"class_ogre_1_1_colour_interpolator_affector.html#a3534e0793f6d1aa89477c58e16a822a9":[7,0,0,77,5],
-"class_ogre_1_1_colour_interpolator_affector.html#a4ebe10757356bf52a3debdfffa4c9b80":[7,0,0,77,7],
-"class_ogre_1_1_colour_interpolator_affector.html#a5f401d9023e7bb484ff3ff49e70c9510":[7,0,0,77,9],
-"class_ogre_1_1_colour_interpolator_affector.html#a7f3dfd3656eb976353b98ed34319d60a":[7,0,0,77,8],
-"class_ogre_1_1_colour_interpolator_affector.html#a9aac32f93bd149a34b809a57a9f01f8f":[7,0,0,77,15],
-"class_ogre_1_1_colour_interpolator_affector.html#aad68d8b18faad14e8286a67527094654":[7,0,0,77,17],
-"class_ogre_1_1_colour_interpolator_affector.html#ab38dc9df81b23a9b041b56d7329cb5b9":[7,0,0,77,10],
-"class_ogre_1_1_colour_interpolator_affector.html#ad49b2e241fcbe4e8061135e58b3d6bf3":[7,0,0,77,20],
-"class_ogre_1_1_colour_interpolator_affector.html#ad4b984bfbf148ddb3310b3d0ba8a9d5d":[7,0,0,77,13],
-"class_ogre_1_1_colour_interpolator_affector.html#ae3e13925bde11db245f6c9bbf5031a93":[7,0,0,77,11],
-"class_ogre_1_1_colour_interpolator_affector.html#ae62b5c03df14079e3c375612efb823fc":[7,0,0,77,6],
-"class_ogre_1_1_colour_interpolator_affector.html#af0805a4befafbcdd9e26f53095639683a8bf32ea3e3c96b8616c44bdf5d47fb28":[7,0,0,77,2],
-"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_colour_adjust.html":[7,0,0,77,0],
-"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_colour_adjust.html#a2c63d0f346cb31156d7fccc5029e9724":[7,0,0,77,0,2],
-"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_colour_adjust.html#a374c2c852858ed7d95de755b6e31fbe8":[7,0,0,77,0,0],
-"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_colour_adjust.html#a9e638b6b97f5c2a7013738d9636b0e4f":[7,0,0,77,0,1]
+"class_ogre_1_1_colour_fader_affector_factory.html":[7,0,0,71],
+"class_ogre_1_1_colour_fader_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,71,0],
+"class_ogre_1_1_colour_fader_affector_factory2.html":[7,0,0,72],
+"class_ogre_1_1_colour_fader_affector_factory2.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,72,0],
+"class_ogre_1_1_colour_image_affector.html":[7,0,0,73],
+"class_ogre_1_1_colour_image_affector.html#a08d117bf25f011f96d81f1f4ecb25113":[7,0,0,73,10],
+"class_ogre_1_1_colour_image_affector.html#a0f55da0550a7e1ab70a1c8bf598a3e20":[7,0,0,73,8],
+"class_ogre_1_1_colour_image_affector.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[7,0,0,73,14],
+"class_ogre_1_1_colour_image_affector.html#a1d078304c38a9f85d483fc8ed0cdf1fe":[7,0,0,73,12],
+"class_ogre_1_1_colour_image_affector.html#a1f75f89834ef18b62b909b4682e6a812":[7,0,0,73,15],
+"class_ogre_1_1_colour_image_affector.html#a2fb5b54b08efe8a456d4e57dfa7860d4":[7,0,0,73,4],
+"class_ogre_1_1_colour_image_affector.html#a52df9990e8c3cdeda702bcefc77f67d6":[7,0,0,73,5],
+"class_ogre_1_1_colour_image_affector.html#a7118e0cf5c7cefcbbf004580add48ae5":[7,0,0,73,1],
+"class_ogre_1_1_colour_image_affector.html#a984fc468041419661aa75af91d0d2757":[7,0,0,73,2],
+"class_ogre_1_1_colour_image_affector.html#a9aac32f93bd149a34b809a57a9f01f8f":[7,0,0,73,11],
+"class_ogre_1_1_colour_image_affector.html#a9c00c2785abad52b3c006988196a2cd4":[7,0,0,73,3],
+"class_ogre_1_1_colour_image_affector.html#aad68d8b18faad14e8286a67527094654":[7,0,0,73,13],
+"class_ogre_1_1_colour_image_affector.html#ab38dc9df81b23a9b041b56d7329cb5b9":[7,0,0,73,6],
+"class_ogre_1_1_colour_image_affector.html#ad4b984bfbf148ddb3310b3d0ba8a9d5d":[7,0,0,73,9],
+"class_ogre_1_1_colour_image_affector.html#ae3e13925bde11db245f6c9bbf5031a93":[7,0,0,73,7],
+"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html":[7,0,0,73,0],
+"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html#a73b813ac40e8327d3e67d33aeb7264c9":[7,0,0,73,0,0],
+"class_ogre_1_1_colour_image_affector_1_1_cmd_image_adjust.html#a974c2899b3b9e87f09cc583c11f7be99":[7,0,0,73,0,1],
+"class_ogre_1_1_colour_image_affector_factory.html":[7,0,0,74],
+"class_ogre_1_1_colour_image_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,74,0],
+"class_ogre_1_1_colour_interpolator_affector.html":[7,0,0,75],
+"class_ogre_1_1_colour_interpolator_affector.html#a055f5f5bbe49e66d40c84c257e78b340":[7,0,0,75,19],
+"class_ogre_1_1_colour_interpolator_affector.html#a08d117bf25f011f96d81f1f4ecb25113":[7,0,0,75,14],
+"class_ogre_1_1_colour_interpolator_affector.html#a0f55da0550a7e1ab70a1c8bf598a3e20":[7,0,0,75,12],
+"class_ogre_1_1_colour_interpolator_affector.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[7,0,0,75,18],
+"class_ogre_1_1_colour_interpolator_affector.html#a1d078304c38a9f85d483fc8ed0cdf1fe":[7,0,0,75,16],
+"class_ogre_1_1_colour_interpolator_affector.html#a23342275feed700c10a601e5edb17152":[7,0,0,75,3],
+"class_ogre_1_1_colour_interpolator_affector.html#a28d59576dcb488c86373eb74d6f0e1ed":[7,0,0,75,4],
+"class_ogre_1_1_colour_interpolator_affector.html#a3534e0793f6d1aa89477c58e16a822a9":[7,0,0,75,5],
+"class_ogre_1_1_colour_interpolator_affector.html#a4ebe10757356bf52a3debdfffa4c9b80":[7,0,0,75,7],
+"class_ogre_1_1_colour_interpolator_affector.html#a5f401d9023e7bb484ff3ff49e70c9510":[7,0,0,75,9],
+"class_ogre_1_1_colour_interpolator_affector.html#a7f3dfd3656eb976353b98ed34319d60a":[7,0,0,75,8],
+"class_ogre_1_1_colour_interpolator_affector.html#a9aac32f93bd149a34b809a57a9f01f8f":[7,0,0,75,15],
+"class_ogre_1_1_colour_interpolator_affector.html#aad68d8b18faad14e8286a67527094654":[7,0,0,75,17],
+"class_ogre_1_1_colour_interpolator_affector.html#ab38dc9df81b23a9b041b56d7329cb5b9":[7,0,0,75,10],
+"class_ogre_1_1_colour_interpolator_affector.html#ad49b2e241fcbe4e8061135e58b3d6bf3":[7,0,0,75,20],
+"class_ogre_1_1_colour_interpolator_affector.html#ad4b984bfbf148ddb3310b3d0ba8a9d5d":[7,0,0,75,13],
+"class_ogre_1_1_colour_interpolator_affector.html#ae3e13925bde11db245f6c9bbf5031a93":[7,0,0,75,11],
+"class_ogre_1_1_colour_interpolator_affector.html#ae62b5c03df14079e3c375612efb823fc":[7,0,0,75,6],
+"class_ogre_1_1_colour_interpolator_affector.html#af0805a4befafbcdd9e26f53095639683a8bf32ea3e3c96b8616c44bdf5d47fb28":[7,0,0,75,2],
+"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_colour_adjust.html":[7,0,0,75,0],
+"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_colour_adjust.html#a2c63d0f346cb31156d7fccc5029e9724":[7,0,0,75,0,2],
+"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_colour_adjust.html#a374c2c852858ed7d95de755b6e31fbe8":[7,0,0,75,0,0],
+"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_colour_adjust.html#a9e638b6b97f5c2a7013738d9636b0e4f":[7,0,0,75,0,1],
+"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_time_adjust.html":[7,0,0,75,1],
+"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_time_adjust.html#a2864f03f51a1402c01eaa9e84a9e6fbd":[7,0,0,75,1,2],
+"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_time_adjust.html#a582c637990caf9c9d7230ff6fb5b36c0":[7,0,0,75,1,0],
+"class_ogre_1_1_colour_interpolator_affector_1_1_cmd_time_adjust.html#ac0ebafd72c0d0809494fa5fa224c97be":[7,0,0,75,1,1],
+"class_ogre_1_1_colour_interpolator_affector_factory.html":[7,0,0,76],
+"class_ogre_1_1_colour_interpolator_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,76,0],
+"class_ogre_1_1_colour_value.html":[5,0,2,9],
+"class_ogre_1_1_colour_value.html#a00384a789ac354ea8dd252c62cb17aa4":[5,0,2,9,36],
+"class_ogre_1_1_colour_value.html#a11c1455b2d4bc0bb0fc4fb20ba6fa099":[5,0,2,9,28],
+"class_ogre_1_1_colour_value.html#a122a85bcbd72a99321225fc0decd9e6e":[5,0,2,9,31],
+"class_ogre_1_1_colour_value.html#a13fbd050af26b8bd549ccb46aa699e07":[5,0,2,9,39],
+"class_ogre_1_1_colour_value.html#a14d1ddd5186e7322466ea3d9c89c3f9d":[5,0,2,9,18],
+"class_ogre_1_1_colour_value.html#a170729634175d1cea8bd8c882bdde71e":[5,0,2,9,5],
+"class_ogre_1_1_colour_value.html#a1cf6b673afb17fe889e4255a938c3cbb":[5,0,2,9,6],
+"class_ogre_1_1_colour_value.html#a21875c1d92c3ad0cba9cafd5776f42a0":[5,0,2,9,11]
 };
