@@ -1,73 +1,21 @@
 var NAVTREEINDEX41 =
 {
-"class_ogre_1_1_default_zone.html#a7e6935861f6ea1af3ddb74ba2f695a15":[7,0,0,195,6],
-"class_ogre_1_1_default_zone.html#a7f34e962772ab3549074c7324536e288":[7,0,0,195,24],
-"class_ogre_1_1_default_zone.html#a8ff931ac282027f2d1d786b128a92a94":[7,0,0,195,25],
-"class_ogre_1_1_default_zone.html#a906103ca899487a8348a2c9f6d4d3030":[7,0,0,195,4],
-"class_ogre_1_1_default_zone.html#a920deb3e4af6031aab2c70b328926c4b":[7,0,0,195,22],
-"class_ogre_1_1_default_zone.html#a93e8f7a50cdea269e209fd15f87c557d":[7,0,0,195,45],
-"class_ogre_1_1_default_zone.html#a96b17eec6ef2530b6d981427fd1f75e1":[7,0,0,195,17],
-"class_ogre_1_1_default_zone.html#a9d4996ed40b3fe5f3ada3d677683623f":[7,0,0,195,10],
-"class_ogre_1_1_default_zone.html#aa1363a02d2cf5526fb11c86b836707d1":[7,0,0,195,40],
-"class_ogre_1_1_default_zone.html#aa136881b59ba17acf60c5c792f57e1be":[7,0,0,195,20],
-"class_ogre_1_1_default_zone.html#aa1b0c4809cffb26dd257dd82c97adee8":[7,0,0,195,37],
-"class_ogre_1_1_default_zone.html#aa89fe9c71d0e86e61d70ea5684cc83d2":[7,0,0,195,27],
-"class_ogre_1_1_default_zone.html#aae81008aaba331d75d78ce12f741acf4":[7,0,0,195,35],
-"class_ogre_1_1_default_zone.html#aaf68e536e6d17124c59628ac9ecb592d":[7,0,0,195,8],
-"class_ogre_1_1_default_zone.html#aafb8aa342ed1f865aeaef12ac5ef6f12":[7,0,0,195,3],
-"class_ogre_1_1_default_zone.html#ab6ecad657b5c528554153b425d1961db":[7,0,0,195,41],
-"class_ogre_1_1_default_zone.html#abc8ebac2f46f22bb525856ec91be771e":[7,0,0,195,42],
-"class_ogre_1_1_default_zone.html#abf2c82ac1e74ccd3852d3a332a8c4c99":[7,0,0,195,44],
-"class_ogre_1_1_default_zone.html#ac1fa831a0caf1f7defd52047322434f0":[7,0,0,195,28],
-"class_ogre_1_1_default_zone.html#ac4955afa0014db1b4ab2a8aa3745f99e":[7,0,0,195,38],
-"class_ogre_1_1_default_zone.html#accc5449350478d04f943d3a313704198":[7,0,0,195,34],
-"class_ogre_1_1_default_zone.html#acd3a9d0ba7a59f8697021195fd4925ef":[7,0,0,195,11],
-"class_ogre_1_1_default_zone.html#acfc4de41d78f2a75d3a569e26196a5fe":[7,0,0,195,31],
-"class_ogre_1_1_default_zone.html#ad1cc272698022165a64f85b5e6669917":[7,0,0,195,36],
-"class_ogre_1_1_default_zone.html#ad28042ef5f4b4eb1ad574ee15625f92a":[7,0,0,195,19],
-"class_ogre_1_1_default_zone.html#ada07deb5c12753fb1bf81d5d92a1e912":[7,0,0,195,29],
-"class_ogre_1_1_default_zone.html#ada5403814b6ba8a1284e80ab97d08f71":[7,0,0,195,39],
-"class_ogre_1_1_default_zone.html#ae9210b537407fadb23e46c30fd884d9a":[7,0,0,195,32],
-"class_ogre_1_1_default_zone.html#afc08c8f6125210cd27e1d59b635bfc0b":[7,0,0,195,9],
-"class_ogre_1_1_default_zone.html#afc7272dc83ed42cc5c742556c4550bc5":[7,0,0,195,30],
-"class_ogre_1_1_default_zone_factory.html":[7,0,0,196],
-"class_ogre_1_1_default_zone_factory.html#a05c74bc425f9a0a309720832e456c8d4":[7,0,0,196,4],
-"class_ogre_1_1_default_zone_factory.html#a44a9fb26ef3b9c538e7b62c5c7cb8c3b":[7,0,0,196,0],
-"class_ogre_1_1_default_zone_factory.html#a57f913a822bf769fb355eca67cd64fc5":[7,0,0,196,1],
-"class_ogre_1_1_default_zone_factory.html#a63e2e87d0081e84b9319c1d797f536a6":[7,0,0,196,2],
-"class_ogre_1_1_default_zone_factory.html#a7dca9c18fd44fcf9ddb9230d64d117eb":[7,0,0,196,3],
-"class_ogre_1_1_default_zone_factory.html#afb863ab16a3cfebe70c9d4abb629b7e2":[7,0,0,196,5],
-"class_ogre_1_1_deflate_stream.html":[7,0,0,197],
-"class_ogre_1_1_deflate_stream.html#a022f49c9313deffc5da4383d59d1f32d":[7,0,0,197,21],
-"class_ogre_1_1_deflate_stream.html#a3a99b8b9b4ce6cce64322ba89ea45e43":[7,0,0,197,16],
-"class_ogre_1_1_deflate_stream.html#a3bf53c73a9933c5e6e1ae215cba72845":[7,0,0,197,2],
-"class_ogre_1_1_deflate_stream.html#a4486e6a49b36dc62ea4a948214e6d6f2":[7,0,0,197,11],
-"class_ogre_1_1_deflate_stream.html#a49bfe5809b50735b5ce49e7df9615e5a":[7,0,0,197,18],
-"class_ogre_1_1_deflate_stream.html#a560b07ced4d47d31315d8d7f51638a8f":[7,0,0,197,15],
-"class_ogre_1_1_deflate_stream.html#a5ba171261e6c5d8c2f2880e99ca5c141":[7,0,0,197,6],
-"class_ogre_1_1_deflate_stream.html#a5e46b5304e48aeee7403230c9f270769":[7,0,0,197,22],
-"class_ogre_1_1_deflate_stream.html#a74192c2a217b0093f1e05d1ce4db12a4":[7,0,0,197,19],
-"class_ogre_1_1_deflate_stream.html#a76b15d2fcdfe255aefb0c28c444cfde0":[7,0,0,197,12],
-"class_ogre_1_1_deflate_stream.html#a7ab66addcbf428322b1caea1d9c88cea":[7,0,0,197,5],
-"class_ogre_1_1_deflate_stream.html#a7ebd86825f86b7114024d168e9751395":[7,0,0,197,14],
-"class_ogre_1_1_deflate_stream.html#a81856582e643b4a560e6c3d3ad05e08c":[7,0,0,197,1],
-"class_ogre_1_1_deflate_stream.html#a81856582e643b4a560e6c3d3ad05e08ca8e221ca82d405d21d275997fbd3eb900":[7,0,0,197,1,1],
-"class_ogre_1_1_deflate_stream.html#a81856582e643b4a560e6c3d3ad05e08cac5f9d1587e9cc7dd1577af114dcba50e":[7,0,0,197,1,0],
-"class_ogre_1_1_deflate_stream.html#a86d2ff5dff63ce4b689dd1d486d3243f":[7,0,0,197,20],
-"class_ogre_1_1_deflate_stream.html#a90494a018545804a60686ad179555822":[7,0,0,197,4],
-"class_ogre_1_1_deflate_stream.html#a917342711b195ccbad40c65ad82e440c":[7,0,0,197,3],
-"class_ogre_1_1_deflate_stream.html#a9d5b5224e17b9fc9d9756d8156a77a5c":[7,0,0,197,23],
-"class_ogre_1_1_deflate_stream.html#a9f6e5c9b9e494733cc80f691de787362":[7,0,0,197,7],
-"class_ogre_1_1_deflate_stream.html#aa0006ee4213a6af6e0aae98f59332d1d":[7,0,0,197,8],
-"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908c":[7,0,0,197,0],
-"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908ca6d7007604fcbeb05fd8f27baac7eed9b":[7,0,0,197,0,3],
-"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908ca855b85480a0c741d3cb3e10c83a35838":[7,0,0,197,0,0],
-"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908caab547cd040a3b61b6df82af4cf202692":[7,0,0,197,0,2],
-"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908cad3be223c328c7637519421e4ce552ef1":[7,0,0,197,0,1],
-"class_ogre_1_1_deflate_stream.html#aaf00e810593e4c47647f3565ab06a849":[7,0,0,197,10],
-"class_ogre_1_1_deflate_stream.html#af142a9dab933b2ff36a12ae5016d59c8":[7,0,0,197,9],
-"class_ogre_1_1_deflate_stream.html#afd205aacbca957108898ce799603bf3f":[7,0,0,197,13],
-"class_ogre_1_1_deflate_stream.html#aff0243c8ad8f5de00bf8e0887d0f034f":[7,0,0,197,17],
+"class_ogre_1_1_deflate_stream.html#a86d2ff5dff63ce4b689dd1d486d3243f":[7,0,0,196,20],
+"class_ogre_1_1_deflate_stream.html#a90494a018545804a60686ad179555822":[7,0,0,196,4],
+"class_ogre_1_1_deflate_stream.html#a917342711b195ccbad40c65ad82e440c":[7,0,0,196,3],
+"class_ogre_1_1_deflate_stream.html#a9d5b5224e17b9fc9d9756d8156a77a5c":[7,0,0,196,23],
+"class_ogre_1_1_deflate_stream.html#a9f6e5c9b9e494733cc80f691de787362":[7,0,0,196,7],
+"class_ogre_1_1_deflate_stream.html#aa0006ee4213a6af6e0aae98f59332d1d":[7,0,0,196,8],
+"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908c":[7,0,0,196,0],
+"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908ca6d7007604fcbeb05fd8f27baac7eed9b":[7,0,0,196,0,3],
+"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908ca855b85480a0c741d3cb3e10c83a35838":[7,0,0,196,0,0],
+"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908caab547cd040a3b61b6df82af4cf202692":[7,0,0,196,0,2],
+"class_ogre_1_1_deflate_stream.html#aa0d681e30262c74b6c1f2ecacc85908cad3be223c328c7637519421e4ce552ef1":[7,0,0,196,0,1],
+"class_ogre_1_1_deflate_stream.html#aaf00e810593e4c47647f3565ab06a849":[7,0,0,196,10],
+"class_ogre_1_1_deflate_stream.html#aedc53a8cff5334563283a4557d423b25":[7,0,0,196,19],
+"class_ogre_1_1_deflate_stream.html#af142a9dab933b2ff36a12ae5016d59c8":[7,0,0,196,9],
+"class_ogre_1_1_deflate_stream.html#afd205aacbca957108898ce799603bf3f":[7,0,0,196,13],
+"class_ogre_1_1_deflate_stream.html#aff0243c8ad8f5de00bf8e0887d0f034f":[7,0,0,196,17],
 "class_ogre_1_1_deflector_plane_affector.html":[5,2,6,5],
 "class_ogre_1_1_deflector_plane_affector.html#a08d117bf25f011f96d81f1f4ecb25113":[5,2,6,5,16],
 "class_ogre_1_1_deflector_plane_affector.html#a0f55da0550a7e1ab70a1c8bf598a3e20":[5,2,6,5,14],
@@ -99,37 +47,37 @@ var NAVTREEINDEX41 =
 "class_ogre_1_1_deflector_plane_affector_1_1_cmd_plane_point.html":[5,2,6,5,2],
 "class_ogre_1_1_deflector_plane_affector_1_1_cmd_plane_point.html#a52b5cbd25de810b071ccad4bb7337d79":[5,2,6,5,2,0],
 "class_ogre_1_1_deflector_plane_affector_1_1_cmd_plane_point.html#afbedbb3f0f59ebc61cfb8f7edca6ea6c":[5,2,6,5,2,1],
-"class_ogre_1_1_deflector_plane_affector_factory.html":[7,0,0,199],
-"class_ogre_1_1_deflector_plane_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,199,0],
+"class_ogre_1_1_deflector_plane_affector_factory.html":[7,0,0,198],
+"class_ogre_1_1_deflector_plane_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,198,0],
 "class_ogre_1_1_degree.html":[5,0,6,5],
 "class_ogre_1_1_degree.html#a0487bcf629d0f637293a6e23d3542ad6":[5,0,6,5,11],
-"class_ogre_1_1_degree.html#a133b76b6d58f5ce8f8e8ea55c04932e0":[5,0,6,5,16],
 "class_ogre_1_1_degree.html#a1b21b5dd134a959f2ff0b4fc36bf2519":[5,0,6,5,23],
+"class_ogre_1_1_degree.html#a1eab9cfd30060b8a85292b254074bf3e":[5,0,6,5,16],
 "class_ogre_1_1_degree.html#a1fa8bd1b85a6346de4570c8c7580988f":[5,0,6,5,3],
-"class_ogre_1_1_degree.html#a243c563d71d979f97a734412e6dc63b0":[5,0,6,5,18],
 "class_ogre_1_1_degree.html#a2e68606c59ced916ad55cf4a3158692a":[5,0,6,5,21],
+"class_ogre_1_1_degree.html#a3529ac07f8aa280de00a70eb15dfeebe":[5,0,6,5,20],
 "class_ogre_1_1_degree.html#a38f343d7b34d2239c9c5ec7270639b86":[5,0,6,5,1],
-"class_ogre_1_1_degree.html#a3948efcffa54a0ebd12753acd96c1594":[5,0,6,5,13],
-"class_ogre_1_1_degree.html#a3985fcbd2b8eb22a9d369a6b6ebe5763":[5,0,6,5,26],
 "class_ogre_1_1_degree.html#a4d92f99a2ca02eed47f3e274a8a37239":[5,0,6,5,29],
-"class_ogre_1_1_degree.html#a501f79ce69c3a73d5c07c945c3251097":[5,0,6,5,28],
 "class_ogre_1_1_degree.html#a502f121976cd95de2817ddb9b9ac1730":[5,0,6,5,22],
 "class_ogre_1_1_degree.html#a58a04cfaf38cca2eff31bfa35c7e47db":[5,0,6,5,12],
 "class_ogre_1_1_degree.html#a61b3c145fcc93dfca4b447dee0e66ecd":[5,0,6,5,8],
-"class_ogre_1_1_degree.html#a6f72e59f38d57cd7e680a49b9cb9d2c0":[5,0,6,5,20],
+"class_ogre_1_1_degree.html#a66b0e7e8389bee4da705c653eb17f428":[5,0,6,5,14],
+"class_ogre_1_1_degree.html#a6c75b928707ec2b866cb15b7ddce1a99":[5,0,6,5,15],
 "class_ogre_1_1_degree.html#a70c2e6332981d0932d3ee75b8460cb7d":[5,0,6,5,2],
 "class_ogre_1_1_degree.html#a77fbb11439e3b9f3ce56af331737484d":[5,0,6,5,10],
 "class_ogre_1_1_degree.html#a7bc078c3f3df2ec10ac2d058d29e6e7d":[5,0,6,5,25],
-"class_ogre_1_1_degree.html#a830559610ea7662565d6ea1107952e51":[5,0,6,5,15],
 "class_ogre_1_1_degree.html#a88066c650a6e3e2033a9d74820569063":[5,0,6,5,4],
+"class_ogre_1_1_degree.html#a8864630977bc2be88e8d499805a6bcba":[5,0,6,5,13],
 "class_ogre_1_1_degree.html#a8aed655684943ae384e45378b65da36a":[5,0,6,5,9],
-"class_ogre_1_1_degree.html#a8ccdef2435d0a205feb54763d8be5fc9":[5,0,6,5,19],
+"class_ogre_1_1_degree.html#a8b5290e54aa8c2e7fa5e3f494e6d4487":[5,0,6,5,26],
+"class_ogre_1_1_degree.html#a922fe61cced7958633dd603605a9dfc1":[5,0,6,5,19],
 "class_ogre_1_1_degree.html#aa8919fdf01749e0e692842be2a7c4a8e":[5,0,6,5,0],
-"class_ogre_1_1_degree.html#aae5eef4a46d40d762e159610a9905c9f":[5,0,6,5,27],
 "class_ogre_1_1_degree.html#ace8f3be58aeb1dcb44fe9d9865fb47c6":[5,0,6,5,24],
-"class_ogre_1_1_degree.html#adb219a3126dceab35444e0d792108ce9":[5,0,6,5,17],
-"class_ogre_1_1_degree.html#af2441af959738661a1a2251eb16e54bb":[5,0,6,5,14],
+"class_ogre_1_1_degree.html#ad18b75fe130f80de8946468beb0738ca":[5,0,6,5,27],
+"class_ogre_1_1_degree.html#ad6fd2c59190866c208e989b3ecf64a82":[5,0,6,5,18],
 "class_ogre_1_1_degree.html#af39ef1bfdbea08127ca79334c7a921bd":[5,0,6,5,5],
+"class_ogre_1_1_degree.html#af9f3b93a8be21133aa565d213626a2c3":[5,0,6,5,28],
+"class_ogre_1_1_degree.html#afc1cbe72d20a853f2885a161ca89f41e":[5,0,6,5,17],
 "class_ogre_1_1_depth_buffer.html":[5,0,7,6],
 "class_ogre_1_1_direction_randomiser_affector.html":[5,2,6,6],
 "class_ogre_1_1_direction_randomiser_affector.html#a08d117bf25f011f96d81f1f4ecb25113":[5,2,6,6,13],
@@ -145,8 +93,8 @@ var NAVTREEINDEX41 =
 "class_ogre_1_1_direction_randomiser_affector_1_1_cmd_keep_velocity.html":[5,2,6,7],
 "class_ogre_1_1_direction_randomiser_affector_1_1_cmd_randomness.html":[5,2,6,8],
 "class_ogre_1_1_direction_randomiser_affector_1_1_cmd_scope.html":[5,2,6,9],
-"class_ogre_1_1_direction_randomiser_affector_factory.html":[7,0,0,204],
-"class_ogre_1_1_direction_randomiser_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,204,0],
+"class_ogre_1_1_direction_randomiser_affector_factory.html":[7,0,0,203],
+"class_ogre_1_1_direction_randomiser_affector_factory.html#a073f267f4efff156cac2d0a2ef40f7dd":[7,0,0,203,0],
 "class_ogre_1_1_distance_lod_box_strategy.html":[5,0,4,0],
 "class_ogre_1_1_distance_lod_box_strategy.html#a0de7722e986cdcca067bc1773feb6065":[5,0,4,0,12],
 "class_ogre_1_1_distance_lod_box_strategy.html#a28bf7af2f635feb42ba86a43cee253f6":[5,0,4,0,3],
@@ -207,6 +155,7 @@ var NAVTREEINDEX41 =
 "class_ogre_1_1_dual_quaternion.html#a19ebc1fe6a5f0577f13bbdae952d5a03":[5,0,6,6,11],
 "class_ogre_1_1_dual_quaternion.html#a1afbb66b83f2085f452bb663ceafc9dc":[5,0,6,6,20],
 "class_ogre_1_1_dual_quaternion.html#a303afd76b65bd34a28accdb6eb0c024c":[5,0,6,6,4],
+"class_ogre_1_1_dual_quaternion.html#a3476931480b61677cb439059250c9ed1":[5,0,6,6,5],
 "class_ogre_1_1_dual_quaternion.html#a410cb35a3ac7a805f4628c9e62ad46f9":[5,0,6,6,7],
 "class_ogre_1_1_dual_quaternion.html#a43375b322ae7a0b7f5d03318bfa33f17":[5,0,6,6,21],
 "class_ogre_1_1_dual_quaternion.html#a488ce81a7866d481169647cff04dc17c":[5,0,6,6,24],
@@ -218,7 +167,7 @@ var NAVTREEINDEX41 =
 "class_ogre_1_1_dual_quaternion.html#a829e80b909334ea343c106c5fcc29fd5":[5,0,6,6,13],
 "class_ogre_1_1_dual_quaternion.html#a845da9e63d380d8b71ea6f740b7fd4a1":[5,0,6,6,1],
 "class_ogre_1_1_dual_quaternion.html#aa7459724aaeaf956e29b08dad3986c39":[5,0,6,6,18],
-"class_ogre_1_1_dual_quaternion.html#aac4241fa632d45ee6ae2d155914ddff7":[5,0,6,6,5],
+"class_ogre_1_1_dual_quaternion.html#ab00ebb979da637bdb4de0713b2a6634b":[5,0,6,6,6],
 "class_ogre_1_1_dual_quaternion.html#ab208a261f08d2fc8e95025f294a305c1":[5,0,6,6,15],
 "class_ogre_1_1_dual_quaternion.html#ab9a8e9b8ced4f48e624f12097a5a21f0":[5,0,6,6,2],
 "class_ogre_1_1_dual_quaternion.html#aca62cb2fb2eeab0637b35bc920a7cae4":[5,0,6,6,22],
@@ -226,7 +175,6 @@ var NAVTREEINDEX41 =
 "class_ogre_1_1_dual_quaternion.html#ad753b864d41eab164118718b27a46425":[5,0,6,6,14],
 "class_ogre_1_1_dual_quaternion.html#ae0fb2ddae4bd51a155b310543dcaa161":[5,0,6,6,16],
 "class_ogre_1_1_dual_quaternion.html#aef3bbc49149643d5bfc3dbde4064dde3":[5,0,6,6,23],
-"class_ogre_1_1_dual_quaternion.html#af666d1865aa8b3467648b96e8c597217":[5,0,6,6,6],
 "class_ogre_1_1_dyn_lib.html":[5,0,2,26],
 "class_ogre_1_1_dyn_lib.html#a038546cd3a5b9d9385b14aa3e0a8179b":[5,0,2,26,2],
 "class_ogre_1_1_dyn_lib.html#a2d7af9ece40f8965e36870948427f972":[5,0,2,26,3],
@@ -249,5 +197,57 @@ var NAVTREEINDEX41 =
 "class_ogre_1_1_e_t_c_codec.html#a21f4b8a16d070793d576f827c9fee218":[5,0,3,2,1],
 "class_ogre_1_1_e_t_c_codec.html#a2659d91f78a33815c7d4fcbaa751823e":[5,0,3,2,3],
 "class_ogre_1_1_e_t_c_codec.html#a270be35471eb9ef28fdbd4b7dced21b9":[5,0,3,2,20],
-"class_ogre_1_1_e_t_c_codec.html#a29e31ad112b08ea7fb648b63f426ff1f":[5,0,3,2,0]
+"class_ogre_1_1_e_t_c_codec.html#a29e31ad112b08ea7fb648b63f426ff1f":[5,0,3,2,0],
+"class_ogre_1_1_e_t_c_codec.html#a54cdb649a57838232c4228ced7bcc680":[5,0,3,2,5],
+"class_ogre_1_1_e_t_c_codec.html#a55bf1d49e91958f8e412a583666bbd58":[5,0,3,2,16],
+"class_ogre_1_1_e_t_c_codec.html#a6092324fd74dd0221f7c63ca8bec4fc1":[5,0,3,2,17],
+"class_ogre_1_1_e_t_c_codec.html#a60f445cc6919df56af6611fd14eec47d":[5,0,3,2,13],
+"class_ogre_1_1_e_t_c_codec.html#a6e0750c6f3b1263d0476b1edc7385c24":[5,0,3,2,4],
+"class_ogre_1_1_e_t_c_codec.html#a6e9a3bb697c7249e822725eda274615c":[5,0,3,2,12],
+"class_ogre_1_1_e_t_c_codec.html#a7aa2599cd9db05e590fb7f7786076852":[5,0,3,2,15],
+"class_ogre_1_1_e_t_c_codec.html#a8cc81c85bd7d4e25393aa153c5e01454":[5,0,3,2,2],
+"class_ogre_1_1_e_t_c_codec.html#ac8775b1052fb8ba72abdfb55df20a6af":[5,0,3,2,19],
+"class_ogre_1_1_e_t_c_codec.html#acc4ee751f92b6e54051393e74e0a2884":[5,0,3,2,18],
+"class_ogre_1_1_e_t_c_codec.html#ad1d829b50e089fd5852e3f6c48b14ae0":[5,0,3,2,6],
+"class_ogre_1_1_e_t_c_codec.html#ae5b74cfd0cb797a2ac139b4adb7ac557":[5,0,3,2,14],
+"class_ogre_1_1_e_t_c_codec.html#ae7e50ebd9dfe6376faff3b8b9ac36ad3":[5,0,3,2,8],
+"class_ogre_1_1_e_x_r_codec.html":[5,2,2,0],
+"class_ogre_1_1_e_x_r_codec.html#a15e6dc21ef3b3e6ea388f4c0fcca125a":[5,2,2,0,9],
+"class_ogre_1_1_e_x_r_codec.html#a1adf85669c35cd7a24a13201b22421a0":[5,2,2,0,6],
+"class_ogre_1_1_e_x_r_codec.html#a21f4b8a16d070793d576f827c9fee218":[5,2,2,0,1],
+"class_ogre_1_1_e_x_r_codec.html#a270be35471eb9ef28fdbd4b7dced21b9":[5,2,2,0,18],
+"class_ogre_1_1_e_x_r_codec.html#a29e31ad112b08ea7fb648b63f426ff1f":[5,2,2,0,0],
+"class_ogre_1_1_e_x_r_codec.html#a3e9fc86e03eb15d5a7e4d09f60cf1de9":[5,2,2,0,7],
+"class_ogre_1_1_e_x_r_codec.html#a4eac3e66e0b4c384fc4a6720b73294f8":[5,2,2,0,4],
+"class_ogre_1_1_e_x_r_codec.html#a55bf1d49e91958f8e412a583666bbd58":[5,2,2,0,14],
+"class_ogre_1_1_e_x_r_codec.html#a6092324fd74dd0221f7c63ca8bec4fc1":[5,2,2,0,15],
+"class_ogre_1_1_e_x_r_codec.html#a60f445cc6919df56af6611fd14eec47d":[5,2,2,0,11],
+"class_ogre_1_1_e_x_r_codec.html#a6e9a3bb697c7249e822725eda274615c":[5,2,2,0,10],
+"class_ogre_1_1_e_x_r_codec.html#a7aa2599cd9db05e590fb7f7786076852":[5,2,2,0,13],
+"class_ogre_1_1_e_x_r_codec.html#a840da35f4727b6f90c4d809f0a2c6661":[5,2,2,0,8],
+"class_ogre_1_1_e_x_r_codec.html#a8cc81c85bd7d4e25393aa153c5e01454":[5,2,2,0,2],
+"class_ogre_1_1_e_x_r_codec.html#ac8775b1052fb8ba72abdfb55df20a6af":[5,2,2,0,17],
+"class_ogre_1_1_e_x_r_codec.html#acc4ee751f92b6e54051393e74e0a2884":[5,2,2,0,16],
+"class_ogre_1_1_e_x_r_codec.html#ae5b74cfd0cb797a2ac139b4adb7ac557":[5,2,2,0,12],
+"class_ogre_1_1_e_x_r_codec.html#aeb0b73dd8844f546c80d52d6137a2e47":[5,2,2,0,5],
+"class_ogre_1_1_e_x_r_codec.html#aef23c3ee02eaa7d524cbff3be7248d46":[5,2,2,0,3],
+"class_ogre_1_1_edge_data.html":[5,0,6,7],
+"class_ogre_1_1_edge_data.html#a06f4e92565a4b5334aafc92dd923bd12":[5,0,6,7,10],
+"class_ogre_1_1_edge_data.html#a325ca9f8c825077c2ce6e67d11fd0558":[5,0,6,7,12],
+"class_ogre_1_1_edge_data.html#a40386af98df21e634c60b85d4434684b":[5,0,6,7,4],
+"class_ogre_1_1_edge_data.html#a64e153ea58ec4f80064986f2d9db201d":[5,0,6,7,3],
+"class_ogre_1_1_edge_data.html#a846bb6792590b4a3dc9c9f03845feef3":[5,0,6,7,15],
+"class_ogre_1_1_edge_data.html#a85e8278c626ea184a00081f199d14959":[5,0,6,7,17],
+"class_ogre_1_1_edge_data.html#a87c571c8ebe68b3ca039a003ffbe07ad":[5,0,6,7,16],
+"class_ogre_1_1_edge_data.html#a98e91393c7d803ddc96ba3c6b36625ef":[5,0,6,7,11],
+"class_ogre_1_1_edge_data.html#aa25f4ff55b3a62137c8d74b417a2e127":[5,0,6,7,6],
+"class_ogre_1_1_edge_data.html#abc392e96ecd65467b7e17e56f5b6751d":[5,0,6,7,9],
+"class_ogre_1_1_edge_data.html#aca13bc3f48d35cacaac6fb72834ab649":[5,0,6,7,8],
+"class_ogre_1_1_edge_data.html#ad171b0cbf84c2266e90ccb093485ea9b":[5,0,6,7,14],
+"class_ogre_1_1_edge_data.html#adcd3d9c03ce2bf3a8634b12fe78a9677":[5,0,6,7,13],
+"class_ogre_1_1_edge_data.html#aead5d3649daa5415ad9418859ba1b20d":[5,0,6,7,7],
+"class_ogre_1_1_edge_data.html#afaf35a82abd84227e184cf35be1255b6":[5,0,6,7,5],
+"class_ogre_1_1_edge_list_builder.html":[5,0,6,8],
+"class_ogre_1_1_edge_list_builder.html#a66aa1d48de5385be8233c8733af99186":[5,0,6,8,4],
+"class_ogre_1_1_edge_list_builder.html#a7233d617fe953b3b6c74035636f1d9f0":[5,0,6,8,3]
 };
