@@ -5,5 +5,5 @@ var searchData=
   ['uniformparameter',['UniformParameter',['../class_ogre_1_1_r_t_shader_1_1_uniform_parameter.html',1,'Ogre::RTShader']]],
   ['unimplementedexception',['UnimplementedException',['../class_ogre_1_1_unimplemented_exception.html',1,'Ogre']]],
   ['userobjectbindings',['UserObjectBindings',['../class_ogre_1_1_user_object_bindings.html',1,'Ogre']]],
-  ['uvwaddressingmode',['UVWAddressingMode',['../struct_ogre_1_1_texture_unit_state_1_1_u_v_w_addressing_mode.html',1,'Ogre::TextureUnitState']]]
+  ['uvwaddressingmode',['UVWAddressingMode',['../struct_ogre_1_1_sampler_1_1_u_v_w_addressing_mode.html',1,'Ogre::Sampler']]]
 ];
