@@ -5,11 +5,13 @@ var searchData=
   ['vector_3c_202_2c_20real_20_3e',['Vector&lt; 2, Real &gt;',['../class_ogre_1_1_vector.html',1,'Ogre']]],
   ['vector_3c_203_2c_20int_20_3e',['Vector&lt; 3, int &gt;',['../class_ogre_1_1_vector.html',1,'Ogre']]],
   ['vector_3c_203_2c_20real_20_3e',['Vector&lt; 3, Real &gt;',['../class_ogre_1_1_vector.html',1,'Ogre']]],
+  ['vector_3c_204_2c_20float_20_3e',['Vector&lt; 4, float &gt;',['../class_ogre_1_1_vector.html',1,'Ogre']]],
   ['vector_3c_204_2c_20real_20_3e',['Vector&lt; 4, Real &gt;',['../class_ogre_1_1_vector.html',1,'Ogre']]],
   ['vectorbase',['VectorBase',['../struct_ogre_1_1_vector_base.html',1,'Ogre']]],
   ['vectorbase_3c_202_2c_20real_20_3e',['VectorBase&lt; 2, Real &gt;',['../struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html',1,'Ogre']]],
   ['vectorbase_3c_203_2c_20real_20_3e',['VectorBase&lt; 3, Real &gt;',['../struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html',1,'Ogre']]],
   ['vectorbase_3c_204_2c_20real_20_3e',['VectorBase&lt; 4, Real &gt;',['../struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html',1,'Ogre']]],
+  ['vectorbase_3c_20dims_2c_20float_20_3e',['VectorBase&lt; dims, float &gt;',['../struct_ogre_1_1_vector_base.html',1,'Ogre']]],
   ['vectorbase_3c_20dims_2c_20int_20_3e',['VectorBase&lt; dims, int &gt;',['../struct_ogre_1_1_vector_base.html',1,'Ogre']]],
   ['vectorbase_3c_20dims_2c_20real_20_3e',['VectorBase&lt; dims, Real &gt;',['../struct_ogre_1_1_vector_base.html',1,'Ogre']]],
   ['vectoriterator',['VectorIterator',['../class_ogre_1_1_vector_iterator.html',1,'Ogre']]],
