@@ -2,5 +2,5 @@ var searchData=
 [
   ['d3d9resourcecreationpolicy',['D3D9ResourceCreationPolicy',['../namespace_ogre.html#ae1989b3ea4f950a490576b517adfa511',1,'Ogre']]],
   ['deformfunc',['DeformFunc',['../_ogre_quake3_types_8h.html#a48a11311dd79091d26fbf9aa6ae7efde',1,'OgreQuake3Types.h']]],
-  ['displaymode',['DisplayMode',['../class_ogre_1_1_profile_session_listener.html#a7d8c034deef087a5969bf5cce55334fd',1,'Ogre::ProfileSessionListener']]]
+  ['displaymode',['DisplayMode',['../group___overlays.html#ga8eaf5c62bec83cede8f1608d998bad1a',1,'Ogre::OverlayProfileSessionListener']]]
 ];
