@@ -10,6 +10,7 @@ var searchData=
   ['ogreantiportal_2eh',['OgreAntiPortal.h',['../_ogre_anti_portal_8h.html',1,'']]],
   ['ogreany_2eh',['OgreAny.h',['../_ogre_any_8h.html',1,'']]],
   ['ogreapplicationcontext_2eh',['OgreApplicationContext.h',['../_ogre_application_context_8h.html',1,'']]],
+  ['ogreapplicationcontextbase_2eh',['OgreApplicationContextBase.h',['../_ogre_application_context_base_8h.html',1,'']]],
   ['ogrearchive_2eh',['OgreArchive.h',['../_ogre_archive_8h.html',1,'']]],
   ['ogrearchivefactory_2eh',['OgreArchiveFactory.h',['../_ogre_archive_factory_8h.html',1,'']]],
   ['ogrearchivemanager_2eh',['OgreArchiveManager.h',['../_ogre_archive_manager_8h.html',1,'']]],
@@ -79,7 +80,6 @@ var searchData=
   ['ogred3d11deviceresource_2eh',['OgreD3D11DeviceResource.h',['../_ogre_d3_d11_device_resource_8h.html',1,'']]],
   ['ogred3d11driver_2eh',['OgreD3D11Driver.h',['../_ogre_d3_d11_driver_8h.html',1,'']]],
   ['ogred3d11driverlist_2eh',['OgreD3D11DriverList.h',['../_ogre_d3_d11_driver_list_8h.html',1,'']]],
-  ['ogred3d11gpuprogrammanager_2eh',['OgreD3D11GpuProgramManager.h',['../_ogre_d3_d11_gpu_program_manager_8h.html',1,'']]],
   ['ogred3d11hardwarebuffer_2eh',['OgreD3D11HardwareBuffer.h',['../_ogre_d3_d11_hardware_buffer_8h.html',1,'']]],
   ['ogred3d11hardwarebuffermanager_2eh',['OgreD3D11HardwareBufferManager.h',['../_ogre_d3_d11_hardware_buffer_manager_8h.html',1,'']]],
   ['ogred3d11hardwareindexbuffer_2eh',['OgreD3D11HardwareIndexBuffer.h',['../_ogre_d3_d11_hardware_index_buffer_8h.html',1,'']]],
@@ -195,11 +195,11 @@ var searchData=
   ['ogreglcontext_2eh',['OgreGLContext.h',['../_ogre_g_l_context_8h.html',1,'']]],
   ['ogreglcopyingrendertexture_2eh',['OgreGLCopyingRenderTexture.h',['../_ogre_g_l_copying_render_texture_8h.html',1,'']]],
   ['ogregldepthbuffer_2eh',['OgreGLDepthBuffer.h',['../_ogre_g_l_depth_buffer_8h.html',1,'']]],
+  ['ogregldepthbuffercommon_2eh',['OgreGLDepthBufferCommon.h',['../_ogre_g_l_depth_buffer_common_8h.html',1,'']]],
   ['ogregles2depthbuffer_2eh',['OgreGLES2DepthBuffer.h',['../_ogre_g_l_e_s2_depth_buffer_8h.html',1,'']]],
   ['ogregles2fbomultirendertarget_2eh',['OgreGLES2FBOMultiRenderTarget.h',['../_ogre_g_l_e_s2_f_b_o_multi_render_target_8h.html',1,'']]],
   ['ogregles2fborendertexture_2eh',['OgreGLES2FBORenderTexture.h',['../_ogre_g_l_e_s2_f_b_o_render_texture_8h.html',1,'']]],
   ['ogregles2framebufferobject_2eh',['OgreGLES2FrameBufferObject.h',['../_ogre_g_l_e_s2_frame_buffer_object_8h.html',1,'']]],
-  ['ogregles2gpuprogrammanager_2eh',['OgreGLES2GpuProgramManager.h',['../_ogre_g_l_e_s2_gpu_program_manager_8h.html',1,'']]],
   ['ogregles2hardwarebuffer_2eh',['OgreGLES2HardwareBuffer.h',['../_ogre_g_l_e_s2_hardware_buffer_8h.html',1,'']]],
   ['ogregles2hardwarebuffermanager_2eh',['OgreGLES2HardwareBufferManager.h',['../_ogre_g_l_e_s2_hardware_buffer_manager_8h.html',1,'']]],
   ['ogregles2hardwareindexbuffer_2eh',['OgreGLES2HardwareIndexBuffer.h',['../_ogre_g_l_e_s2_hardware_index_buffer_8h.html',1,'']]],
@@ -262,7 +262,6 @@ var searchData=
   ['ogreglslshader_2eh',['OgreGLSLShader.h',['../_ogre_g_l_s_l_shader_8h.html',1,'']]],
   ['ogreglslshadercommon_2eh',['OgreGLSLShaderCommon.h',['../_ogre_g_l_s_l_shader_common_8h.html',1,'']]],
   ['ogreglslshaderfactory_2eh',['OgreGLSLShaderFactory.h',['../_ogre_g_l_s_l_shader_factory_8h.html',1,'']]],
-  ['ogreglslshadermanager_2eh',['OgreGLSLShaderManager.h',['../_ogre_g_l_s_l_shader_manager_8h.html',1,'']]],
   ['ogreglstatecachemanager_2eh',['OgreGLStateCacheManager.h',['../_ogre_g_l_state_cache_manager_8h.html',1,'']]],
   ['ogreglstatecachemanagercommon_2eh',['OgreGLStateCacheManagerCommon.h',['../_ogre_g_l_state_cache_manager_common_8h.html',1,'']]],
   ['ogregltexture_2eh',['OgreGLTexture.h',['../_ogre_g_l_texture_8h.html',1,'']]],
@@ -409,7 +408,6 @@ var searchData=
   ['ogreparticleaffector_2eh',['OgreParticleAffector.h',['../_ogre_particle_affector_8h.html',1,'']]],
   ['ogreparticleaffectorfactory_2eh',['OgreParticleAffectorFactory.h',['../_ogre_particle_affector_factory_8h.html',1,'']]],
   ['ogreparticleemitter_2eh',['OgreParticleEmitter.h',['../_ogre_particle_emitter_8h.html',1,'']]],
-  ['ogreparticleemittercommands_2eh',['OgreParticleEmitterCommands.h',['../_ogre_particle_emitter_commands_8h.html',1,'']]],
   ['ogreparticleemitterfactory_2eh',['OgreParticleEmitterFactory.h',['../_ogre_particle_emitter_factory_8h.html',1,'']]],
   ['ogreparticlefxplugin_2eh',['OgreParticleFXPlugin.h',['../_ogre_particle_f_x_plugin_8h.html',1,'']]],
   ['ogreparticleiterator_2eh',['OgreParticleIterator.h',['../_ogre_particle_iterator_8h.html',1,'']]],
@@ -443,7 +441,6 @@ var searchData=
   ['ogreportalbase_2eh',['OgrePortalBase.h',['../_ogre_portal_base_8h.html',1,'']]],
   ['ogrepose_2eh',['OgrePose.h',['../_ogre_pose_8h.html',1,'']]],
   ['ogrepredefinedcontrollers_2eh',['OgrePredefinedControllers.h',['../_ogre_predefined_controllers_8h.html',1,'']]],
-  ['ogreprefabfactory_2eh',['OgrePrefabFactory.h',['../_ogre_prefab_factory_8h.html',1,'']]],
   ['ogreprerequisites_2eh',['OgrePrerequisites.h',['../_ogre_prerequisites_8h.html',1,'']]],
   ['ogreprofiler_2eh',['OgreProfiler.h',['../_ogre_profiler_8h.html',1,'']]],
   ['ogreproperty_2eh',['OgreProperty.h',['../_ogre_property_8h.html',1,'']]],
@@ -548,7 +545,6 @@ var searchData=
   ['ogreshadowcamerasetuppssm_2eh',['OgreShadowCameraSetupPSSM.h',['../_ogre_shadow_camera_setup_p_s_s_m_8h.html',1,'']]],
   ['ogreshadowcaster_2eh',['OgreShadowCaster.h',['../_ogre_shadow_caster_8h.html',1,'']]],
   ['ogreshadows_2emd',['OgreShadows.md',['../_ogre_shadows_8md.html',1,'']]],
-  ['ogreshadowtexturemanager_2eh',['OgreShadowTextureManager.h',['../_ogre_shadow_texture_manager_8h.html',1,'']]],
   ['ogresharedptr_2eh',['OgreSharedPtr.h',['../_ogre_shared_ptr_8h.html',1,'']]],
   ['ogresimplepagecontentcollection_2eh',['OgreSimplePageContentCollection.h',['../_ogre_simple_page_content_collection_8h.html',1,'']]],
   ['ogresimplerenderable_2eh',['OgreSimpleRenderable.h',['../_ogre_simple_renderable_8h.html',1,'']]],
