@@ -7,7 +7,7 @@ var indexSectionsWithContent =
   4: "_abcdefghiklmnopqrstuvwxyz~",
   5: "_abcdefghiklmnopqrstuvwxyz",
   6: "_abcdefghiklmnopqrstuvwz",
-  7: "abcdefgilmnoprstuvw",
+  7: "abcdefgilmnopqrstuvw",
   8: "abcdefghiklmnopqrstuvwz",
   9: "abcdefgimoprstw",
   10: "_abcdeghimnopstw",
