@@ -54,7 +54,7 @@ var searchData=
   ['strategymap',['StrategyMap',['../class_ogre_1_1_page_manager.html#a6bc619f289f2ed3491a822ee4abbbd3d',1,'Ogre::PageManager']]],
   ['streamalloc',['StreamAlloc',['../namespace_ogre.html#ab1b4c43359603ea0d0cace50d6fc57ee',1,'Ogre']]],
   ['string',['String',['../namespace_ogre.html#af73bbdc8bed8a3e6fcd56bb8fa188c45',1,'Ogre']]],
-  ['stringstream',['stringstream',['../namespace_ogre.html#a64e76a61ffe0fc66797727c518151d35',1,'Ogre::stringstream()'],['../namespace_ogre.html#a9f14407f349c1ec70ddab871a7806590',1,'Ogre::StringStream()']]],
+  ['stringstream',['StringStream',['../namespace_ogre.html#a9f14407f349c1ec70ddab871a7806590',1,'Ogre::StringStream()'],['../namespace_ogre.html#a64e76a61ffe0fc66797727c518151d35',1,'Ogre::stringstream()']]],
   ['stringvector',['StringVector',['../group___general.html#ga783e5227595f351519627abfb740ec85',1,'Ogre']]],
   ['stringvectorptr',['StringVectorPtr',['../group___general.html#gae6b84ceebcdcc285f37bf9fba216697d',1,'Ogre']]],
   ['strstreamtype',['StrStreamType',['../class_ogre_1_1_string_util.html#a665d79932d54b48b83acff563de7a9e5',1,'Ogre::StringUtil']]],
