@@ -16,7 +16,7 @@ var searchData=
   ['usefullscreen',['useFullScreen',['../struct_ogre_1_1_render_window_description.html#a5809e1727a29bbc2737e090ab338c6a7',1,'Ogre::RenderWindowDescription']]],
   ['useglobalinstancingvertexbufferisavailable',['useGlobalInstancingVertexBufferIsAvailable',['../class_ogre_1_1_render_operation.html#a58effcf80fb468f10360aeab08d3c32e',1,'Ogre::RenderOperation']]],
   ['useindexes',['useIndexes',['../class_ogre_1_1_render_operation.html#ae12d3ff9f224f21738fa50f832484f3d',1,'Ogre::RenderOperation']]],
-  ['user_5ftype_5fmask_5flimit',['USER_TYPE_MASK_LIMIT',['../class_ogre_1_1_scene_manager.html#a01d4bf3c6e81fddcfc96ec3f2714c8ac',1,'Ogre::SceneManager']]],
+  ['userkey',['UserKey',['../class_ogre_1_1_r_t_shader_1_1_target_render_state.html#ad89fc9a3c7ec0c73a5d7805013547c24',1,'Ogre::RTShader::TargetRenderState']]],
   ['uservalue',['userValue',['../struct_ogre_1_1_mesh_lod_usage.html#a114e1bc321b7b64f5bc931a30fea4dfe',1,'Ogre::MeshLodUsage']]],
   ['usesharedvertexbuffer',['useSharedVertexBuffer',['../struct_ogre_1_1_lod_input_buffer_1_1_submesh.html#a575926e31feb1cc9bfebab8a13fded97',1,'Ogre::LodInputBuffer::Submesh']]],
   ['usesharedvertices',['useSharedVertices',['../class_ogre_1_1_sub_mesh.html#a931e3764e3bf1c3ef7431fc852770fb1',1,'Ogre::SubMesh']]],
