@@ -37,6 +37,19 @@ var tutorials =
       [ "Shadow Types", "tut__lights_cameras_shadows.html#ShadowTypes", null ],
       [ "Conclusion", "tut__lights_cameras_shadows.html#Conclusion2", null ]
     ] ],
+    [ "Terrain, Sky and Fog", "tut__terrain_sky_fog.html", [
+      [ "An Introduction to Terrain", "tut__terrain_sky_fog.html#tut_terrain", [
+        [ "Terrain loading overview", "tut__terrain_sky_fog.html#bt3Overview", null ],
+        [ "Terrain appearance", "tut__terrain_sky_fog.html#bt3Appearance", null ],
+        [ "Defining a terrain chunk", "tut__terrain_sky_fog.html#bt3TerrainChunk", null ],
+        [ "Loading a heightmap", "tut__terrain_sky_fog.html#bt3Heightmap", null ],
+        [ "Height based blending", "tut__terrain_sky_fog.html#bt3Blendmap", null ],
+        [ "Terrain Loading Label", "tut__terrain_sky_fog.html#bt3LoadingLabel", null ]
+      ] ],
+      [ "Simulating a sky", "tut__terrain_sky_fog.html#bt3sky", null ],
+      [ "Fog", "tut__terrain_sky_fog.html#tut_fog", null ],
+      [ "Conclusion", "tut__terrain_sky_fog.html#conclusion3", null ]
+    ] ],
     [ "Working with NumPy", "working-with-numpy.html", null ],
     [ "Trays GUI System", "trays.html", [
       [ "Trays", "trays.html#trays-1", null ],
@@ -54,7 +67,13 @@ var tutorials =
       [ "Editing a Volume made from a GridSource", "volume.html#editing", null ]
     ] ],
     [ "Manual mesh creation", "manual-mesh-creation.html", null ],
-    [ "Using the Profiler", "profiler.html", null ],
+    [ "Using the Profiler", "profiler.html", [
+      [ "Reading the Display", "profiler.html#profRead", null ],
+      [ "Features", "profiler.html#profFeatures", null ],
+      [ "Performance and Accuracy", "profiler.html#profAccuracy", null ],
+      [ "Remotery Backend", "profiler.html#profRemotery", null ],
+      [ "Release Version Considerations", "profiler.html#profRelmode", null ]
+    ] ],
     [ "External Texture Sources", "_external-_texture-_sources.html", null ],
     [ "Shadow Mapping in Ogre", "_shadow_mapping_ogre.html", [
       [ "Introduction to the Shadow Mapping Algorithm", "_shadow_mapping_ogre.html#ShadowMappingIntro", [
